// This file is autogenerated. Changes will be overwritten.
#include "MTJHVBGFB2/moc_keyboardcontroller.cpp"
#include "MTJHVBGFB2/moc_keyboarddbusproxy.cpp"
#include "MTJHVBGFB2/moc_keyboardmodel.cpp"
#include "MTJHVBGFB2/moc_keyboardwork.cpp"
#include "MTJHVBGFB2/moc_shortcutmodel.cpp"
