/****************************************************************************
** Meta object code from reading C++ file 'personalizationinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-personalization/operation/personalizationinterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'personalizationinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24PersonalizationInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto PersonalizationInterface::qt_create_metaobjectdata<qt_meta_tag_ZN24PersonalizationInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PersonalizationInterface",
        "currentAppearanceChanged",
        "",
        "appearance",
        "appearanceSwitchModelChanged",
        "QVariantList",
        "model",
        "platformName",
        "handleCmdParam",
        "PersonalizationExport::ModuleType",
        "type",
        "cmdParam",
        "globalThemeModel",
        "ThemeVieweModel*",
        "iconThemeViewModel",
        "cursorThemeViewModel",
        "PersonalizationModel*",
        "worker",
        "PersonalizationWorker*",
        "imageHelper",
        "ImageHelper*",
        "appearanceSwitchModel",
        "currentAppearance"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentAppearanceChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'appearanceSwitchModelChanged'
        QtMocHelpers::SignalData<void(const QVariantList &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'platformName'
        QtMocHelpers::MethodData<QString()>(7, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'handleCmdParam'
        QtMocHelpers::MethodData<void(PersonalizationExport::ModuleType, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::QString, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'globalThemeModel'
        QtMocHelpers::PropertyData<ThemeVieweModel*>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'iconThemeViewModel'
        QtMocHelpers::PropertyData<ThemeVieweModel*>(14, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'cursorThemeViewModel'
        QtMocHelpers::PropertyData<ThemeVieweModel*>(15, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'model'
        QtMocHelpers::PropertyData<PersonalizationModel*>(6, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'worker'
        QtMocHelpers::PropertyData<PersonalizationWorker*>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'imageHelper'
        QtMocHelpers::PropertyData<ImageHelper*>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'appearanceSwitchModel'
        QtMocHelpers::PropertyData<QVariantList>(21, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 1),
        // property 'currentAppearance'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PersonalizationInterface, qt_meta_tag_ZN24PersonalizationInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PersonalizationInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24PersonalizationInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24PersonalizationInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24PersonalizationInterfaceE_t>.metaTypes,
    nullptr
} };

void PersonalizationInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PersonalizationInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentAppearanceChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->appearanceSwitchModelChanged((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1]))); break;
        case 2: { QString _r = _t->platformName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->handleCmdParam((*reinterpret_cast<std::add_pointer_t<PersonalizationExport::ModuleType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PersonalizationInterface::*)(const QString & )>(_a, &PersonalizationInterface::currentAppearanceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationInterface::*)(const QVariantList & )>(_a, &PersonalizationInterface::appearanceSwitchModelChanged, 1))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ImageHelper* >(); break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PersonalizationModel* >(); break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PersonalizationWorker* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<ThemeVieweModel**>(_v) = _t->m_globalThemeViewModel; break;
        case 1: *reinterpret_cast<ThemeVieweModel**>(_v) = _t->m_iconThemeViewModel; break;
        case 2: *reinterpret_cast<ThemeVieweModel**>(_v) = _t->m_cursorThemeViewModel; break;
        case 3: *reinterpret_cast<PersonalizationModel**>(_v) = _t->m_model; break;
        case 4: *reinterpret_cast<PersonalizationWorker**>(_v) = _t->m_work; break;
        case 5: *reinterpret_cast<ImageHelper**>(_v) = _t->m_imageHelper; break;
        case 6: *reinterpret_cast<QVariantList*>(_v) = _t->m_appearanceSwitchModel; break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->m_currentAppearance; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 6:
            if (QtMocHelpers::setProperty(_t->m_appearanceSwitchModel, *reinterpret_cast<QVariantList*>(_v)))
                Q_EMIT _t->appearanceSwitchModelChanged(_t->m_appearanceSwitchModel);
            break;
        case 7:
            if (QtMocHelpers::setProperty(_t->m_currentAppearance, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->currentAppearanceChanged(_t->m_currentAppearance);
            break;
        default: break;
        }
    }
}

const QMetaObject *PersonalizationInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PersonalizationInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24PersonalizationInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PersonalizationInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void PersonalizationInterface::currentAppearanceChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PersonalizationInterface::appearanceSwitchModelChanged(const QVariantList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
