/****************************************************************************
** Meta object code from reading C++ file 'dccobject.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/include/dccobject.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dccobject.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6dccV259DccObjectE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::DccObject::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV259DccObjectE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::DccObject",
        "DefaultProperty",
        "data",
        "active",
        "",
        "cmd",
        "deactive",
        "childAboutToBeAdded",
        "const DccObject*",
        "parent",
        "pos",
        "childAdded",
        "DccObject*",
        "child",
        "childAboutToBeRemoved",
        "childRemoved",
        "childAboutToBeMoved",
        "oldPos",
        "childMoved",
        "childrenChanged",
        "QList<DccObject*>",
        "children",
        "nameChanged",
        "name",
        "parentNameChanged",
        "parentName",
        "weightChanged",
        "weight",
        "displayNameChanged",
        "displayName",
        "descriptionChanged",
        "description",
        "iconChanged",
        "icon",
        "iconSourceChanged",
        "QUrl",
        "iconSource",
        "badgeChanged",
        "badge",
        "visibleChanged",
        "visible",
        "enabledChanged",
        "enabled",
        "visibleToAppChanged",
        "visibleToApp",
        "enabledToAppChanged",
        "enabledToApp",
        "canSearchChanged",
        "canSearch",
        "backgroundTypeChanged",
        "BackgroundTypes",
        "type",
        "currentObjectChanged",
        "obj",
        "pageTypeChanged",
        "pageChanged",
        "QQmlComponent*",
        "page",
        "parentItemChanged",
        "QQuickItem*",
        "item",
        "getSectionItem",
        "backgroundType",
        "currentObject",
        "pageType",
        "parentItem",
        "QQmlListProperty<QObject>",
        "BackgroundType",
        "AutoBg",
        "Normal",
        "Hover",
        "Clickable",
        "Highlight",
        "Warning",
        "ClickStyle",
        "PageType",
        "EditorPage",
        "ItemPage",
        "Menu",
        "MenuEditor",
        "Control",
        "Editor",
        "Item",
        "UserType"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'active'
        QtMocHelpers::SignalData<void(const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'deactive'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'childAboutToBeAdded'
        QtMocHelpers::SignalData<void(const DccObject *, int)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Int, 10 },
        }}),
        // Signal 'childAdded'
        QtMocHelpers::SignalData<void(DccObject *)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'childAboutToBeRemoved'
        QtMocHelpers::SignalData<void(const DccObject *, int)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Int, 10 },
        }}),
        // Signal 'childRemoved'
        QtMocHelpers::SignalData<void(DccObject *)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'childAboutToBeMoved'
        QtMocHelpers::SignalData<void(const DccObject *, int, int)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Int, 10 }, { QMetaType::Int, 17 },
        }}),
        // Signal 'childMoved'
        QtMocHelpers::SignalData<void(DccObject *)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'childrenChanged'
        QtMocHelpers::SignalData<void(const QVector<DccObject*> &)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Signal 'parentNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(24, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Signal 'weightChanged'
        QtMocHelpers::SignalData<void(quint32)>(26, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 27 },
        }}),
        // Signal 'displayNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Signal 'descriptionChanged'
        QtMocHelpers::SignalData<void(const QString &)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Signal 'iconChanged'
        QtMocHelpers::SignalData<void(const QString &)>(32, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 33 },
        }}),
        // Signal 'iconSourceChanged'
        QtMocHelpers::SignalData<void(const QUrl &)>(34, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Signal 'badgeChanged'
        QtMocHelpers::SignalData<void(qint8)>(37, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::SChar, 38 },
        }}),
        // Signal 'visibleChanged'
        QtMocHelpers::SignalData<void(bool)>(39, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void(bool)>(41, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Signal 'visibleToAppChanged'
        QtMocHelpers::SignalData<void(bool)>(43, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 44 },
        }}),
        // Signal 'enabledToAppChanged'
        QtMocHelpers::SignalData<void(bool)>(45, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 46 },
        }}),
        // Signal 'canSearchChanged'
        QtMocHelpers::SignalData<void(bool)>(47, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 48 },
        }}),
        // Signal 'backgroundTypeChanged'
        QtMocHelpers::SignalData<void(BackgroundTypes)>(49, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 50, 51 },
        }}),
        // Signal 'currentObjectChanged'
        QtMocHelpers::SignalData<void(DccObject *)>(52, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 53 },
        }}),
        // Signal 'pageTypeChanged'
        QtMocHelpers::SignalData<void(quint8)>(54, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UChar, 51 },
        }}),
        // Signal 'pageChanged'
        QtMocHelpers::SignalData<void(QQmlComponent *)>(55, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 56, 57 },
        }}),
        // Signal 'parentItemChanged'
        QtMocHelpers::SignalData<void(QQuickItem *)>(58, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 59, 60 },
        }}),
        // Method 'getSectionItem'
        QtMocHelpers::MethodData<QQuickItem *(QObject *)>(61, 4, QMC::AccessPublic, 0x80000000 | 59, {{
            { QMetaType::QObjectStar, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'parentName'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'weight'
        QtMocHelpers::PropertyData<quint32>(27, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'displayName'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'icon'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'iconSource'
        QtMocHelpers::PropertyData<QUrl>(36, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 15),
        // property 'badge'
        QtMocHelpers::PropertyData<qint8>(38, QMetaType::SChar, QMC::Readable | QMC::Writable | QMC::Scriptable | QMC::Stored | QMC::StdCppSet, 16),
        // property 'visible'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::Readable | QMC::Writable | QMC::Scriptable | QMC::Stored | QMC::StdCppSet, 17),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::Readable | QMC::Writable | QMC::Scriptable | QMC::Stored | QMC::StdCppSet, 18),
        // property 'visibleToApp'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags, 19),
        // property 'enabledToApp'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags, 20),
        // property 'canSearch'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::Readable | QMC::Writable | QMC::Scriptable | QMC::Stored | QMC::StdCppSet, 21),
        // property 'backgroundType'
        QtMocHelpers::PropertyData<BackgroundTypes>(62, 0x80000000 | 50, QMC::Readable | QMC::Writable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag | QMC::StdCppSet, 22),
        // property 'currentObject'
        QtMocHelpers::PropertyData<DccObject*>(63, 0x80000000 | 12, QMC::Readable | QMC::Writable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag | QMC::StdCppSet, 23),
        // property 'children'
        QtMocHelpers::PropertyData<QList<DccObject*>>(21, 0x80000000 | 20, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag, 8),
        // property 'pageType'
        QtMocHelpers::PropertyData<quint8>(64, QMetaType::UChar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'page'
        QtMocHelpers::PropertyData<QQmlComponent*>(57, 0x80000000 | 56, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 25),
        // property 'parentItem'
        QtMocHelpers::PropertyData<QQuickItem*>(65, 0x80000000 | 59, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 26),
        // property 'data'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 66, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'BackgroundTypes'
        QtMocHelpers::EnumData<BackgroundTypes>(50, 67, QMC::EnumIsFlag).add({
            {   68, BackgroundType::AutoBg },
            {   69, BackgroundType::Normal },
            {   70, BackgroundType::Hover },
            {   71, BackgroundType::Clickable },
            {   72, BackgroundType::Highlight },
            {   73, BackgroundType::Warning },
            {   74, BackgroundType::ClickStyle },
        }),
        // enum 'PageType'
        QtMocHelpers::EnumData<enum PageType>(75, 75, QMC::EnumFlags{}).add({
            {   76, PageType::EditorPage },
            {   77, PageType::ItemPage },
            {   78, PageType::Menu },
            {   79, PageType::MenuEditor },
            {   80, PageType::Control },
            {   81, PageType::Editor },
            {   82, PageType::Item },
            {   83, PageType::UserType },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DccObject, qt_meta_tag_ZN6dccV259DccObjectE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject dccV25::DccObject::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV259DccObjectE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV259DccObjectE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV259DccObjectE_t>.metaTypes,
    nullptr
} };

void dccV25::DccObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DccObject *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->active((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->deactive(); break;
        case 2: _t->childAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<const DccObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->childAdded((*reinterpret_cast<std::add_pointer_t<DccObject*>>(_a[1]))); break;
        case 4: _t->childAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const DccObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->childRemoved((*reinterpret_cast<std::add_pointer_t<DccObject*>>(_a[1]))); break;
        case 6: _t->childAboutToBeMoved((*reinterpret_cast<std::add_pointer_t<const DccObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 7: _t->childMoved((*reinterpret_cast<std::add_pointer_t<DccObject*>>(_a[1]))); break;
        case 8: _t->childrenChanged((*reinterpret_cast<std::add_pointer_t<QList<DccObject*>>>(_a[1]))); break;
        case 9: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->parentNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->weightChanged((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 12: _t->displayNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->descriptionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->iconChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->iconSourceChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 16: _t->badgeChanged((*reinterpret_cast<std::add_pointer_t<qint8>>(_a[1]))); break;
        case 17: _t->visibleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->enabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->visibleToAppChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->enabledToAppChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->canSearchChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->backgroundTypeChanged((*reinterpret_cast<std::add_pointer_t<BackgroundTypes>>(_a[1]))); break;
        case 23: _t->currentObjectChanged((*reinterpret_cast<std::add_pointer_t<DccObject*>>(_a[1]))); break;
        case 24: _t->pageTypeChanged((*reinterpret_cast<std::add_pointer_t<quint8>>(_a[1]))); break;
        case 25: _t->pageChanged((*reinterpret_cast<std::add_pointer_t<QQmlComponent*>>(_a[1]))); break;
        case 26: _t->parentItemChanged((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1]))); break;
        case 27: { QQuickItem* _r = _t->getSectionItem((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QQuickItem**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DccObject* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DccObject* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DccObject* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<DccObject*> >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DccObject* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQmlComponent* >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickItem* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(const QString & )>(_a, &DccObject::active, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)()>(_a, &DccObject::deactive, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(const DccObject * , int )>(_a, &DccObject::childAboutToBeAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(DccObject * )>(_a, &DccObject::childAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(const DccObject * , int )>(_a, &DccObject::childAboutToBeRemoved, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(DccObject * )>(_a, &DccObject::childRemoved, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(const DccObject * , int , int )>(_a, &DccObject::childAboutToBeMoved, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(DccObject * )>(_a, &DccObject::childMoved, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(const QVector<DccObject*> & )>(_a, &DccObject::childrenChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(const QString & )>(_a, &DccObject::nameChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(const QString & )>(_a, &DccObject::parentNameChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(quint32 )>(_a, &DccObject::weightChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(const QString & )>(_a, &DccObject::displayNameChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(const QString & )>(_a, &DccObject::descriptionChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(const QString & )>(_a, &DccObject::iconChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(const QUrl & )>(_a, &DccObject::iconSourceChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(qint8 )>(_a, &DccObject::badgeChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(bool )>(_a, &DccObject::visibleChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(bool )>(_a, &DccObject::enabledChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(bool )>(_a, &DccObject::visibleToAppChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(bool )>(_a, &DccObject::enabledToAppChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(bool )>(_a, &DccObject::canSearchChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(BackgroundTypes )>(_a, &DccObject::backgroundTypeChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(DccObject * )>(_a, &DccObject::currentObjectChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(quint8 )>(_a, &DccObject::pageTypeChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(QQmlComponent * )>(_a, &DccObject::pageChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccObject::*)(QQuickItem * )>(_a, &DccObject::parentItemChanged, 26))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 14:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DccObject* >(); break;
        case 15:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<DccObject*> >(); break;
        case 17:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
        case 18:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->parentName(); break;
        case 2: *reinterpret_cast<quint32*>(_v) = _t->weight(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->displayName(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->icon(); break;
        case 6: *reinterpret_cast<QUrl*>(_v) = _t->iconSource(); break;
        case 7: *reinterpret_cast<qint8*>(_v) = _t->badge(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isVisible(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isEnabled(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isVisibleToApp(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isEnabledToApp(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->canSearch(); break;
        case 13: QtMocHelpers::assignFlags<BackgroundTypes>(_v, _t->backgroundType()); break;
        case 14: *reinterpret_cast<DccObject**>(_v) = _t->currentObject(); break;
        case 15: *reinterpret_cast<QList<DccObject*>*>(_v) = _t->getChildren(); break;
        case 16: *reinterpret_cast<quint8*>(_v) = _t->pageType(); break;
        case 17: *reinterpret_cast<QQmlComponent**>(_v) = _t->page(); break;
        case 18: *reinterpret_cast<QQuickItem**>(_v) = _t->parentItem(); break;
        case 19: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->data(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setParentName(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setWeight(*reinterpret_cast<quint32*>(_v)); break;
        case 3: _t->setDisplayName(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setDescription(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setIcon(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setBadge(*reinterpret_cast<qint8*>(_v)); break;
        case 8: _t->setVisible(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setCanSearch(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setBackgroundType(*reinterpret_cast<BackgroundTypes*>(_v)); break;
        case 14: _t->setCurrentObject(*reinterpret_cast<DccObject**>(_v)); break;
        case 16: _t->setPageType(*reinterpret_cast<quint8*>(_v)); break;
        case 17: _t->setPage(*reinterpret_cast<QQmlComponent**>(_v)); break;
        case 18: _t->setParentItem(*reinterpret_cast<QQuickItem**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *dccV25::DccObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::DccObject::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV259DccObjectE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dccV25::DccObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void dccV25::DccObject::active(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dccV25::DccObject::deactive()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dccV25::DccObject::childAboutToBeAdded(const DccObject * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void dccV25::DccObject::childAdded(DccObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dccV25::DccObject::childAboutToBeRemoved(const DccObject * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void dccV25::DccObject::childRemoved(DccObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void dccV25::DccObject::childAboutToBeMoved(const DccObject * _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void dccV25::DccObject::childMoved(DccObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void dccV25::DccObject::childrenChanged(const QVector<DccObject*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void dccV25::DccObject::nameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void dccV25::DccObject::parentNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void dccV25::DccObject::weightChanged(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void dccV25::DccObject::displayNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void dccV25::DccObject::descriptionChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void dccV25::DccObject::iconChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void dccV25::DccObject::iconSourceChanged(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void dccV25::DccObject::badgeChanged(qint8 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void dccV25::DccObject::visibleChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void dccV25::DccObject::enabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void dccV25::DccObject::visibleToAppChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void dccV25::DccObject::enabledToAppChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void dccV25::DccObject::canSearchChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void dccV25::DccObject::backgroundTypeChanged(BackgroundTypes _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void dccV25::DccObject::currentObjectChanged(DccObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void dccV25::DccObject::pageTypeChanged(quint8 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void dccV25::DccObject::pageChanged(QQmlComponent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}

// SIGNAL 26
void dccV25::DccObject::parentItemChanged(QQuickItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1);
}
QT_WARNING_POP
