// This file is autogenerated. Changes will be overwritten.
#include "MTJHVBGFB2/moc_ddbusinterface.cpp"
#include "MTJHVBGFB2/moc_ddbusinterface_p.cpp"
#include "MTJHVBGFB2/moc_monitordbusproxy.cpp"
#include "MTJHVBGFB2/moc_touchscreenmatchmodel.cpp"
#include "MTJHVBGFB2/moc_touchscreenmodel.cpp"
#include "MTJHVBGFB2/moc_touchscreenproxy.cpp"
