/****************************************************************************
** Meta object code from reading C++ file 'dockdbusproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-dock/operation/dockdbusproxy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dockdbusproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13DockDBusProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto DockDBusProxy::qt_create_metaobjectdata<qt_meta_tag_ZN13DockDBusProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DockDBusProxy",
        "DisplayModeChanged",
        "",
        "displayMode",
        "PositionChanged",
        "position",
        "HideModeChanged",
        "hideMode",
        "WindowSizeEfficientChanged",
        "windowSizeEfficient",
        "WindowSizeFashionChanged",
        "windowSizeFashion",
        "ShowInPrimaryChanged",
        "showInPrimary",
        "LockedChanged",
        "locked",
        "pluginVisibleChanged",
        "pluginName",
        "visible",
        "showRecentChanged",
        "resizeDock",
        "offset",
        "dragging",
        "GetLoadedPlugins",
        "QDBusPendingReply<QStringList>",
        "getPluginKey",
        "QDBusPendingReply<QString>",
        "getPluginVisible",
        "QDBusPendingReply<bool>",
        "setPluginVisible",
        "QDBusPendingReply<>",
        "SetShowRecent",
        "plugins",
        "QDBusPendingReply<DockItemInfos>",
        "setItemOnDock",
        "settingKey",
        "itemKey",
        "setDisplayMode",
        "mode",
        "setPosition",
        "value",
        "setHideMode",
        "setShowInPrimary",
        "setLocked",
        "DisplayMode",
        "Position",
        "HideMode",
        "WindowSizeEfficient",
        "WindowSizeFashion",
        "ShowRecent"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'DisplayModeChanged'
        QtMocHelpers::SignalData<void(int) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'PositionChanged'
        QtMocHelpers::SignalData<void(int) const>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'HideModeChanged'
        QtMocHelpers::SignalData<void(int) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'WindowSizeEfficientChanged'
        QtMocHelpers::SignalData<void(uint) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 9 },
        }}),
        // Signal 'WindowSizeFashionChanged'
        QtMocHelpers::SignalData<void(uint) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 11 },
        }}),
        // Signal 'ShowInPrimaryChanged'
        QtMocHelpers::SignalData<void(bool) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'LockedChanged'
        QtMocHelpers::SignalData<void(bool) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Signal 'pluginVisibleChanged'
        QtMocHelpers::SignalData<void(const QString &, bool) const>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::Bool, 18 },
        }}),
        // Signal 'showRecentChanged'
        QtMocHelpers::SignalData<void(bool) const>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'resizeDock'
        QtMocHelpers::SlotData<void(int, bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { QMetaType::Bool, 22 },
        }}),
        // Slot 'GetLoadedPlugins'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(23, 2, QMC::AccessPublic, 0x80000000 | 24),
        // Slot 'getPluginKey'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(25, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'getPluginVisible'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(27, 2, QMC::AccessPublic, 0x80000000 | 28, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'setPluginVisible'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, bool)>(29, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::QString, 17 }, { QMetaType::Bool, 18 },
        }}),
        // Slot 'SetShowRecent'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(31, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::Bool, 18 },
        }}),
        // Slot 'plugins'
        QtMocHelpers::SlotData<QDBusPendingReply<DockItemInfos>()>(32, 2, QMC::AccessPublic, 0x80000000 | 33),
        // Slot 'setItemOnDock'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString, const QString &, bool)>(34, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::QString, 35 }, { QMetaType::QString, 36 }, { QMetaType::Bool, 18 },
        }}),
        // Method 'setDisplayMode'
        QtMocHelpers::MethodData<void(int)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 38 },
        }}),
        // Method 'setPosition'
        QtMocHelpers::MethodData<void(int)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 40 },
        }}),
        // Method 'setHideMode'
        QtMocHelpers::MethodData<void(int)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 40 },
        }}),
        // Method 'setShowInPrimary'
        QtMocHelpers::MethodData<void(bool)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Method 'setLocked'
        QtMocHelpers::MethodData<void(bool)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'DisplayMode'
        QtMocHelpers::PropertyData<int>(44, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'Position'
        QtMocHelpers::PropertyData<int>(45, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'HideMode'
        QtMocHelpers::PropertyData<int>(46, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'WindowSizeEfficient'
        QtMocHelpers::PropertyData<uint>(47, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'WindowSizeFashion'
        QtMocHelpers::PropertyData<uint>(48, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'showInPrimary'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'locked'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'ShowRecent'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DockDBusProxy, qt_meta_tag_ZN13DockDBusProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DockDBusProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DockDBusProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DockDBusProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13DockDBusProxyE_t>.metaTypes,
    nullptr
} };

void DockDBusProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DockDBusProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->DisplayModeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->PositionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->HideModeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->WindowSizeEfficientChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 4: _t->WindowSizeFashionChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 5: _t->ShowInPrimaryChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->LockedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->pluginVisibleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: _t->showRecentChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->resizeDock((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 10: { QDBusPendingReply<QStringList> _r = _t->GetLoadedPlugins();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<QString> _r = _t->getPluginKey((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<bool> _r = _t->getPluginVisible((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<> _r = _t->setPluginVisible((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<> _r = _t->SetShowRecent((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<DockItemInfos> _r = _t->plugins();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<DockItemInfos>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<> _r = _t->setItemOnDock((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->setDisplayMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->setPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->setHideMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->setShowInPrimary((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->setLocked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DockDBusProxy::*)(int ) const>(_a, &DockDBusProxy::DisplayModeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockDBusProxy::*)(int ) const>(_a, &DockDBusProxy::PositionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockDBusProxy::*)(int ) const>(_a, &DockDBusProxy::HideModeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockDBusProxy::*)(uint ) const>(_a, &DockDBusProxy::WindowSizeEfficientChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockDBusProxy::*)(uint ) const>(_a, &DockDBusProxy::WindowSizeFashionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockDBusProxy::*)(bool ) const>(_a, &DockDBusProxy::ShowInPrimaryChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockDBusProxy::*)(bool ) const>(_a, &DockDBusProxy::LockedChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockDBusProxy::*)(const QString & , bool ) const>(_a, &DockDBusProxy::pluginVisibleChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockDBusProxy::*)(bool ) const>(_a, &DockDBusProxy::showRecentChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->displayMode(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->position(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->hideMode(); break;
        case 3: *reinterpret_cast<uint*>(_v) = _t->windowSizeEfficient(); break;
        case 4: *reinterpret_cast<uint*>(_v) = _t->windowSizeFashion(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->showInPrimary(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->locked(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->showRecent(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDisplayMode(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setPosition(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setHideMode(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setWindowSizeEfficient(*reinterpret_cast<uint*>(_v)); break;
        case 4: _t->setWindowSizeFashion(*reinterpret_cast<uint*>(_v)); break;
        case 5: _t->setShowInPrimary(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setLocked(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DockDBusProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DockDBusProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DockDBusProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DockDBusProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 22;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void DockDBusProxy::DisplayModeChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< DockDBusProxy *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DockDBusProxy::PositionChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< DockDBusProxy *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DockDBusProxy::HideModeChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< DockDBusProxy *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DockDBusProxy::WindowSizeEfficientChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< DockDBusProxy *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DockDBusProxy::WindowSizeFashionChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< DockDBusProxy *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DockDBusProxy::ShowInPrimaryChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< DockDBusProxy *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DockDBusProxy::LockedChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< DockDBusProxy *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void DockDBusProxy::pluginVisibleChanged(const QString & _t1, bool _t2)const
{
    QMetaObject::activate<void>(const_cast< DockDBusProxy *>(this), &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void DockDBusProxy::showRecentChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< DockDBusProxy *>(this), &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
