/****************************************************************************
** Meta object code from reading C++ file 'applicationinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "applicationinterface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'applicationinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22AppManager1ApplicationE_t {};
} // unnamed namespace

template <> constexpr inline auto AppManager1Application::qt_create_metaobjectdata<qt_meta_tag_ZN22AppManager1ApplicationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AppManager1Application",
        "Launch",
        "QDBusPendingReply<QDBusObjectPath>",
        "",
        "action",
        "fields",
        "QVariantMap",
        "options",
        "RemoveFromDesktop",
        "QDBusPendingReply<bool>",
        "SendToDesktop",
        "ActionName",
        "PropMap",
        "Actions",
        "AutoStart",
        "Categories",
        "Environ",
        "GenericName",
        "QStringMap",
        "ID",
        "Icons",
        "InstalledTime",
        "Instances",
        "QList<QDBusObjectPath>",
        "LastLaunchedTime",
        "LaunchedTimes",
        "MimeTypes",
        "Name",
        "NoDisplay",
        "Terminal",
        "X_Deepin_Vendor",
        "X_Flatpak",
        "X_linglong",
        "isOnDesktop"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'Launch'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &, const QStringList &, const QVariantMap &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 4 }, { QMetaType::QStringList, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'RemoveFromDesktop'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(8, 3, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'SendToDesktop'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(10, 3, QMC::AccessPublic, 0x80000000 | 9),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'ActionName'
        QtMocHelpers::PropertyData<PropMap>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Actions'
        QtMocHelpers::PropertyData<QStringList>(13, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'AutoStart'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'Categories'
        QtMocHelpers::PropertyData<QStringList>(15, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'Environ'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'GenericName'
        QtMocHelpers::PropertyData<QStringMap>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'ID'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Icons'
        QtMocHelpers::PropertyData<QStringMap>(20, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'InstalledTime'
        QtMocHelpers::PropertyData<qlonglong>(21, QMetaType::LongLong, QMC::DefaultPropertyFlags),
        // property 'Instances'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'LastLaunchedTime'
        QtMocHelpers::PropertyData<qlonglong>(24, QMetaType::LongLong, QMC::DefaultPropertyFlags),
        // property 'LaunchedTimes'
        QtMocHelpers::PropertyData<qlonglong>(25, QMetaType::LongLong, QMC::DefaultPropertyFlags),
        // property 'MimeTypes'
        QtMocHelpers::PropertyData<QStringList>(26, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'Name'
        QtMocHelpers::PropertyData<QStringMap>(27, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'NoDisplay'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Terminal'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'X_Deepin_Vendor'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'X_Flatpak'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'X_linglong'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'isOnDesktop'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AppManager1Application, qt_meta_tag_ZN22AppManager1ApplicationE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AppManager1Application::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22AppManager1ApplicationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22AppManager1ApplicationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22AppManager1ApplicationE_t>.metaTypes,
    nullptr
} };

void AppManager1Application::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AppManager1Application *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<QDBusObjectPath> _r = _t->Launch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<bool> _r = _t->RemoveFromDesktop();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<bool> _r = _t->SendToDesktop();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PropMap >(); break;
        case 13:
        case 7:
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QStringMap >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<PropMap*>(_v) = _t->actionName(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->actions(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->autoStart(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->categories(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->environ(); break;
        case 5: *reinterpret_cast<QStringMap*>(_v) = _t->genericName(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->iD(); break;
        case 7: *reinterpret_cast<QStringMap*>(_v) = _t->icons(); break;
        case 8: *reinterpret_cast<qlonglong*>(_v) = _t->installedTime(); break;
        case 9: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->instances(); break;
        case 10: *reinterpret_cast<qlonglong*>(_v) = _t->lastLaunchedTime(); break;
        case 11: *reinterpret_cast<qlonglong*>(_v) = _t->launchedTimes(); break;
        case 12: *reinterpret_cast<QStringList*>(_v) = _t->mimeTypes(); break;
        case 13: *reinterpret_cast<QStringMap*>(_v) = _t->name(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->noDisplay(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->terminal(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->x_Deepin_Vendor(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->x_Flatpak(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->x_linglong(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isOnDesktop(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setAutoStart(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setEnviron(*reinterpret_cast<QString*>(_v)); break;
        case 12: _t->setMimeTypes(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AppManager1Application::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AppManager1Application::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22AppManager1ApplicationE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int AppManager1Application::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}
QT_WARNING_POP
