/****************************************************************************
** Meta object code from reading C++ file 'soundworker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-sound/operation/soundworker.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'soundworker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11SoundWorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto SoundWorker::qt_create_metaobjectdata<qt_meta_tag_ZN11SoundWorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SoundWorker",
        "QML.Element",
        "QML.Singleton",
        "true",
        "switchSpeaker",
        "",
        "on",
        "switchMicrophone",
        "setPortEnabled",
        "cardid",
        "portName",
        "enable",
        "setSourceMute",
        "flag",
        "setSinkMute",
        "setPort",
        "Port*",
        "port",
        "setEffectEnable",
        "DDesktopServices::SystemSoundEffect",
        "effect",
        "setBluetoothMode",
        "mode",
        "refreshSoundEffect",
        "setAudioServer",
        "value",
        "defaultSinkChanged",
        "QDBusObjectPath",
        "path",
        "defaultSourceChanged",
        "cardsChanged",
        "cards",
        "activeSinkPortChanged",
        "AudioPort",
        "activeSinkPort",
        "activeSourcePortChanged",
        "activeSourcePort",
        "onSinkCardChanged",
        "cardId",
        "onSourceCardChanged",
        "getSoundEnabledMapFinished",
        "QMap<QString,bool>",
        "map",
        "getSoundPathFinished",
        "QDBusPendingCallWatcher*",
        "watcher",
        "onAniTimerTimeOut",
        "onSoundPlayingChanged",
        "updatePlayAniIconPath",
        "setSinkVolume",
        "volume",
        "setReduceNoise",
        "setPausePlayer",
        "setIncreaseVolume",
        "setSinkBalance",
        "balance",
        "setActivePort",
        "index",
        "portType",
        "setSoundEffectEnable",
        "setSourceVolume",
        "enableAllSoundEffect",
        "setPortEnableIndex",
        "checked",
        "playSoundEffect",
        "stopSoundEffectPlayback",
        "setAudioServerIndex",
        "setAudioMono"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'switchSpeaker'
        QtMocHelpers::SlotData<void(bool)>(4, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'switchMicrophone'
        QtMocHelpers::SlotData<void(bool)>(7, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'setPortEnabled'
        QtMocHelpers::SlotData<void(unsigned int, QString, bool)>(8, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 9 }, { QMetaType::QString, 10 }, { QMetaType::Bool, 11 },
        }}),
        // Slot 'setSourceMute'
        QtMocHelpers::SlotData<void(bool)>(12, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'setSourceMute'
        QtMocHelpers::SlotData<void()>(12, 5, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setSinkMute'
        QtMocHelpers::SlotData<void(bool)>(14, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'setSinkMute'
        QtMocHelpers::SlotData<void()>(14, 5, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setPort'
        QtMocHelpers::SlotData<void(Port *)>(15, 5, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'setEffectEnable'
        QtMocHelpers::SlotData<void(DDesktopServices::SystemSoundEffect, bool)>(18, 5, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { QMetaType::Bool, 11 },
        }}),
        // Slot 'setBluetoothMode'
        QtMocHelpers::SlotData<void(const QString &)>(21, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'refreshSoundEffect'
        QtMocHelpers::SlotData<void()>(23, 5, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setAudioServer'
        QtMocHelpers::SlotData<void(const QString &)>(24, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'defaultSinkChanged'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(26, 5, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'defaultSourceChanged'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(29, 5, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'cardsChanged'
        QtMocHelpers::SlotData<void(const QString &)>(30, 5, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Slot 'activeSinkPortChanged'
        QtMocHelpers::SlotData<void(const AudioPort &)>(32, 5, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'activeSourcePortChanged'
        QtMocHelpers::SlotData<void(const AudioPort &)>(35, 5, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 33, 36 },
        }}),
        // Slot 'onSinkCardChanged'
        QtMocHelpers::SlotData<void(const uint &)>(37, 5, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 38 },
        }}),
        // Slot 'onSourceCardChanged'
        QtMocHelpers::SlotData<void(const uint &)>(39, 5, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 38 },
        }}),
        // Slot 'getSoundEnabledMapFinished'
        QtMocHelpers::SlotData<void(QMap<QString,bool>)>(40, 5, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Slot 'getSoundPathFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(43, 5, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 44, 45 },
        }}),
        // Slot 'onAniTimerTimeOut'
        QtMocHelpers::SlotData<void()>(46, 5, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSoundPlayingChanged'
        QtMocHelpers::SlotData<void()>(47, 5, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updatePlayAniIconPath'
        QtMocHelpers::SlotData<void()>(48, 5, QMC::AccessPrivate, QMetaType::Void),
        // Method 'setSinkVolume'
        QtMocHelpers::MethodData<void(double)>(49, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 50 },
        }}),
        // Method 'setReduceNoise'
        QtMocHelpers::MethodData<void(bool)>(51, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Method 'setPausePlayer'
        QtMocHelpers::MethodData<void(bool)>(52, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Method 'setIncreaseVolume'
        QtMocHelpers::MethodData<void(bool)>(53, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Method 'setSinkBalance'
        QtMocHelpers::MethodData<void(double)>(54, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 55 },
        }}),
        // Method 'setActivePort'
        QtMocHelpers::MethodData<void(int, int)>(56, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 57 }, { QMetaType::Int, 58 },
        }}),
        // Method 'setSoundEffectEnable'
        QtMocHelpers::MethodData<void(int, bool)>(59, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 57 }, { QMetaType::Bool, 11 },
        }}),
        // Method 'setSourceVolume'
        QtMocHelpers::MethodData<void(double)>(60, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 50 },
        }}),
        // Method 'enableAllSoundEffect'
        QtMocHelpers::MethodData<void(bool)>(61, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Method 'setPortEnableIndex'
        QtMocHelpers::MethodData<void(int, bool, int)>(62, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 57 }, { QMetaType::Bool, 63 }, { QMetaType::Int, 58 },
        }}),
        // Method 'playSoundEffect'
        QtMocHelpers::MethodData<void(int)>(64, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 57 },
        }}),
        // Method 'stopSoundEffectPlayback'
        QtMocHelpers::MethodData<void()>(65, 5, QMC::AccessPublic, QMetaType::Void),
        // Method 'setAudioServerIndex'
        QtMocHelpers::MethodData<void(int)>(66, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 57 },
        }}),
        // Method 'setAudioMono'
        QtMocHelpers::MethodData<void(bool)>(67, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    0 },
            {    2,    3 },
    });
    return QtMocHelpers::metaObjectData<SoundWorker, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SoundWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SoundWorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SoundWorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11SoundWorkerE_t>.metaTypes,
    nullptr
} };

void SoundWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SoundWorker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->switchSpeaker((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->switchMicrophone((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->setPortEnabled((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 3: _t->setSourceMute((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->setSourceMute(); break;
        case 5: _t->setSinkMute((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->setSinkMute(); break;
        case 7: _t->setPort((*reinterpret_cast<std::add_pointer_t<Port*>>(_a[1]))); break;
        case 8: _t->setEffectEnable((*reinterpret_cast<std::add_pointer_t<DDesktopServices::SystemSoundEffect>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 9: _t->setBluetoothMode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->refreshSoundEffect(); break;
        case 11: _t->setAudioServer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->defaultSinkChanged((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 13: _t->defaultSourceChanged((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 14: _t->cardsChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->activeSinkPortChanged((*reinterpret_cast<std::add_pointer_t<AudioPort>>(_a[1]))); break;
        case 16: _t->activeSourcePortChanged((*reinterpret_cast<std::add_pointer_t<AudioPort>>(_a[1]))); break;
        case 17: _t->onSinkCardChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 18: _t->onSourceCardChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 19: _t->getSoundEnabledMapFinished((*reinterpret_cast<std::add_pointer_t<QMap<QString,bool>>>(_a[1]))); break;
        case 20: _t->getSoundPathFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 21: _t->onAniTimerTimeOut(); break;
        case 22: _t->onSoundPlayingChanged(); break;
        case 23: _t->updatePlayAniIconPath(); break;
        case 24: _t->setSinkVolume((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 25: _t->setReduceNoise((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->setPausePlayer((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->setIncreaseVolume((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 28: _t->setSinkBalance((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 29: _t->setActivePort((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 30: _t->setSoundEffectEnable((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 31: _t->setSourceVolume((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 32: _t->enableAllSoundEffect((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->setPortEnableIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 34: _t->playSoundEffect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 35: _t->stopSoundEffectPlayback(); break;
        case 36: _t->setAudioServerIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 37: _t->setAudioMono((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Port* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AudioPort >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AudioPort >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *SoundWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SoundWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SoundWorkerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SoundWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    return _id;
}
QT_WARNING_POP
