/****************************************************************************
** Meta object code from reading C++ file 'accountsworker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-accounts/operation/accountsworker.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'accountsworker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6dccV2514AccountsWorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::AccountsWorker::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV2514AccountsWorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::AccountsWorker",
        "accountCreationFinished",
        "",
        "CreationResult*",
        "result",
        "accountFullNameChangeFinished",
        "requestMainWindowEnabled",
        "isEnabled",
        "localBindUbid",
        "ubid",
        "localBindError",
        "error",
        "showSafetyPage",
        "errorTips",
        "updateGroupFinished",
        "OperateType",
        "operation",
        "successfully",
        "groupName",
        "updateGroupFailed",
        "createGroupFailed",
        "randomUserIcon",
        "User*",
        "user",
        "createAccount",
        "const User*",
        "setAvatar",
        "iconPath",
        "setFullname",
        "fullname",
        "deleteAccount",
        "deleteHome",
        "setAutoLogin",
        "autoLogin",
        "setQuickLogin",
        "quickLogin",
        "setAdministrator",
        "asAdministrator",
        "onUserListChanged",
        "userList",
        "onGroupListChanged",
        "groupList",
        "setPassword",
        "oldpwd",
        "passwd",
        "repeatPasswd",
        "needResule",
        "resetPassword",
        "password",
        "deleteUserIcon",
        "setNopasswdLogin",
        "nopasswdLogin",
        "setMaxPasswordAge",
        "maxAge",
        "loadUserList",
        "getUOSID",
        "QString&",
        "uosid",
        "getUUID",
        "uuid",
        "localBindCheck",
        "startResetPasswordExec",
        "asyncSecurityQuestionsCheck",
        "refreshADDomain",
        "ADDomainHandle",
        "server",
        "admin",
        "addUser",
        "userPath",
        "removeUser",
        "setGroups",
        "usrGroups",
        "setPasswordHint",
        "passwordHint",
        "setSecurityQuestions",
        "QMap<int,QByteArray>",
        "securityQuestions",
        "deleteGroup",
        "group",
        "createGroup",
        "uint32_t",
        "gid",
        "isSystem",
        "modifyGroup",
        "oldGroup",
        "newGroup",
        "getGroupInfoByName",
        "resInfoJson",
        "hasOpenSecurity",
        "getSecUserLeverbyname",
        "SecurityLever",
        "userName",
        "checkPwdLimitLevel",
        "level",
        "showDefender",
        "playSystemSound",
        "soundType",
        "updateUserOnlineStatus",
        "QList<QDBusObjectPath>",
        "paths",
        "getAllGroups",
        "getAllGroupsResult",
        "QDBusPendingCallWatcher*",
        "watch",
        "getPresetGroups",
        "getPresetGroupsResult",
        "checkADUser",
        "active"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'accountCreationFinished'
        QtMocHelpers::SignalData<void(CreationResult *) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'accountFullNameChangeFinished'
        QtMocHelpers::SignalData<void() const>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestMainWindowEnabled'
        QtMocHelpers::SignalData<void(const bool) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'localBindUbid'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'localBindError'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'showSafetyPage'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'updateGroupFinished'
        QtMocHelpers::SignalData<void(enum OperateType, bool, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::Bool, 17 }, { QMetaType::QString, 18 },
        }}),
        // Signal 'updateGroupFinished'
        QtMocHelpers::SignalData<void(enum OperateType, bool)>(14, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::Bool, 17 },
        }}),
        // Signal 'updateGroupFailed'
        QtMocHelpers::SignalData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Signal 'updateGroupFailed'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'createGroupFailed'
        QtMocHelpers::SignalData<void(const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Signal 'createGroupFailed'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'randomUserIcon'
        QtMocHelpers::SlotData<void(User *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'createAccount'
        QtMocHelpers::SlotData<void(const User *)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 23 },
        }}),
        // Slot 'setAvatar'
        QtMocHelpers::SlotData<void(User *, const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'setFullname'
        QtMocHelpers::SlotData<void(User *, const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::QString, 29 },
        }}),
        // Slot 'deleteAccount'
        QtMocHelpers::SlotData<void(User *, const bool)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::Bool, 31 },
        }}),
        // Slot 'setAutoLogin'
        QtMocHelpers::SlotData<void(User *, const bool)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::Bool, 33 },
        }}),
        // Slot 'setQuickLogin'
        QtMocHelpers::SlotData<void(User *, const bool)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::Bool, 35 },
        }}),
        // Slot 'setAdministrator'
        QtMocHelpers::SlotData<void(User *, const bool)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::Bool, 37 },
        }}),
        // Slot 'onUserListChanged'
        QtMocHelpers::SlotData<void(const QStringList &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 39 },
        }}),
        // Slot 'onGroupListChanged'
        QtMocHelpers::SlotData<void(const QStringList &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 41 },
        }}),
        // Slot 'setPassword'
        QtMocHelpers::SlotData<void(User *, const QString &, const QString &, const QString &, const bool)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::QString, 43 }, { QMetaType::QString, 44 }, { QMetaType::QString, 45 },
            { QMetaType::Bool, 46 },
        }}),
        // Slot 'setPassword'
        QtMocHelpers::SlotData<void(User *, const QString &, const QString &, const QString &)>(42, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::QString, 43 }, { QMetaType::QString, 44 }, { QMetaType::QString, 45 },
        }}),
        // Slot 'resetPassword'
        QtMocHelpers::SlotData<void(User *, const QString &)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::QString, 48 },
        }}),
        // Slot 'deleteUserIcon'
        QtMocHelpers::SlotData<void(User *, const QString &)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'setNopasswdLogin'
        QtMocHelpers::SlotData<void(User *, const bool)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::Bool, 51 },
        }}),
        // Slot 'setMaxPasswordAge'
        QtMocHelpers::SlotData<void(User *, const int)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::Int, 53 },
        }}),
        // Slot 'loadUserList'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'getUOSID'
        QtMocHelpers::SlotData<void(QString &)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 56, 57 },
        }}),
        // Slot 'getUUID'
        QtMocHelpers::SlotData<void(QString &)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 56, 59 },
        }}),
        // Slot 'localBindCheck'
        QtMocHelpers::SlotData<void(User *, const QString &, const QString &)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::QString, 57 }, { QMetaType::QString, 59 },
        }}),
        // Slot 'startResetPasswordExec'
        QtMocHelpers::SlotData<void(User *)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'asyncSecurityQuestionsCheck'
        QtMocHelpers::SlotData<void(User *)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'refreshADDomain'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ADDomainHandle'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 65 }, { QMetaType::QString, 66 }, { QMetaType::QString, 48 },
        }}),
        // Slot 'addUser'
        QtMocHelpers::SlotData<void(const QString &)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 68 },
        }}),
        // Slot 'removeUser'
        QtMocHelpers::SlotData<void(const QString &)>(69, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 68 },
        }}),
        // Slot 'setGroups'
        QtMocHelpers::SlotData<void(User *, const QStringList &)>(70, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::QStringList, 71 },
        }}),
        // Slot 'setPasswordHint'
        QtMocHelpers::SlotData<void(User *, const QString &)>(72, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::QString, 73 },
        }}),
        // Slot 'setSecurityQuestions'
        QtMocHelpers::SlotData<void(User *, const QMap<int,QByteArray> &)>(74, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { 0x80000000 | 75, 76 },
        }}),
        // Slot 'deleteGroup'
        QtMocHelpers::SlotData<void(const QString &)>(77, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 78 },
        }}),
        // Slot 'createGroup'
        QtMocHelpers::SlotData<void(const QString &, uint32_t, bool)>(79, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 78 }, { 0x80000000 | 80, 81 }, { QMetaType::Bool, 82 },
        }}),
        // Slot 'modifyGroup'
        QtMocHelpers::SlotData<void(const QString &, const QString &, uint32_t)>(83, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 84 }, { QMetaType::QString, 85 }, { 0x80000000 | 80, 81 },
        }}),
        // Slot 'getGroupInfoByName'
        QtMocHelpers::SlotData<void(const QString &, QString &)>(86, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 }, { 0x80000000 | 56, 87 },
        }}),
        // Slot 'hasOpenSecurity'
        QtMocHelpers::SlotData<bool()>(88, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'getSecUserLeverbyname'
        QtMocHelpers::SlotData<SecurityLever(QString)>(89, 2, QMC::AccessPublic, 0x80000000 | 90, {{
            { QMetaType::QString, 91 },
        }}),
        // Slot 'checkPwdLimitLevel'
        QtMocHelpers::SlotData<void(int)>(92, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 93 },
        }}),
        // Slot 'showDefender'
        QtMocHelpers::SlotData<void()>(94, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'playSystemSound'
        QtMocHelpers::SlotData<void(int)>(95, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 96 },
        }}),
        // Slot 'updateUserOnlineStatus'
        QtMocHelpers::SlotData<void(const QList<QDBusObjectPath> &)>(97, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 98, 99 },
        }}),
        // Slot 'getAllGroups'
        QtMocHelpers::SlotData<void()>(100, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'getAllGroupsResult'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(101, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 102, 103 },
        }}),
        // Slot 'getPresetGroups'
        QtMocHelpers::SlotData<void()>(104, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'getPresetGroupsResult'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(105, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 102, 103 },
        }}),
        // Slot 'checkADUser'
        QtMocHelpers::SlotData<void()>(106, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'active'
        QtMocHelpers::MethodData<void()>(107, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AccountsWorker, qt_meta_tag_ZN6dccV2514AccountsWorkerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dccV25::AccountsWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2514AccountsWorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2514AccountsWorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV2514AccountsWorkerE_t>.metaTypes,
    nullptr
} };

void dccV25::AccountsWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AccountsWorker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->accountCreationFinished((*reinterpret_cast<std::add_pointer_t<CreationResult*>>(_a[1]))); break;
        case 1: _t->accountFullNameChangeFinished(); break;
        case 2: _t->requestMainWindowEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->localBindUbid((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->localBindError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->showSafetyPage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->updateGroupFinished((*reinterpret_cast<std::add_pointer_t<enum OperateType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 7: _t->updateGroupFinished((*reinterpret_cast<std::add_pointer_t<enum OperateType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: _t->updateGroupFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->updateGroupFailed(); break;
        case 10: _t->createGroupFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->createGroupFailed(); break;
        case 12: _t->randomUserIcon((*reinterpret_cast<std::add_pointer_t<User*>>(_a[1]))); break;
        case 13: _t->createAccount((*reinterpret_cast<std::add_pointer_t<const User*>>(_a[1]))); break;
        case 14: _t->setAvatar((*reinterpret_cast<std::add_pointer_t<User*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 15: _t->setFullname((*reinterpret_cast<std::add_pointer_t<User*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: _t->deleteAccount((*reinterpret_cast<std::add_pointer_t<User*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 17: _t->setAutoLogin((*reinterpret_cast<std::add_pointer_t<User*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 18: _t->setQuickLogin((*reinterpret_cast<std::add_pointer_t<User*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 19: _t->setAdministrator((*reinterpret_cast<std::add_pointer_t<User*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 20: _t->onUserListChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 21: _t->onGroupListChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 22: _t->setPassword((*reinterpret_cast<std::add_pointer_t<User*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 23: _t->setPassword((*reinterpret_cast<std::add_pointer_t<User*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 24: _t->resetPassword((*reinterpret_cast<std::add_pointer_t<User*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 25: _t->deleteUserIcon((*reinterpret_cast<std::add_pointer_t<User*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 26: _t->setNopasswdLogin((*reinterpret_cast<std::add_pointer_t<User*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 27: _t->setMaxPasswordAge((*reinterpret_cast<std::add_pointer_t<User*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 28: _t->loadUserList(); break;
        case 29: _t->getUOSID((*reinterpret_cast<std::add_pointer_t<QString&>>(_a[1]))); break;
        case 30: _t->getUUID((*reinterpret_cast<std::add_pointer_t<QString&>>(_a[1]))); break;
        case 31: _t->localBindCheck((*reinterpret_cast<std::add_pointer_t<User*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 32: _t->startResetPasswordExec((*reinterpret_cast<std::add_pointer_t<User*>>(_a[1]))); break;
        case 33: _t->asyncSecurityQuestionsCheck((*reinterpret_cast<std::add_pointer_t<User*>>(_a[1]))); break;
        case 34: _t->refreshADDomain(); break;
        case 35: _t->ADDomainHandle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 36: _t->addUser((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 37: _t->removeUser((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 38: _t->setGroups((*reinterpret_cast<std::add_pointer_t<User*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 39: _t->setPasswordHint((*reinterpret_cast<std::add_pointer_t<User*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 40: _t->setSecurityQuestions((*reinterpret_cast<std::add_pointer_t<User*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMap<int,QByteArray>>>(_a[2]))); break;
        case 41: _t->deleteGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 42: _t->createGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 43: _t->modifyGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[3]))); break;
        case 44: _t->getGroupInfoByName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2]))); break;
        case 45: { bool _r = _t->hasOpenSecurity();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 46: { SecurityLever _r = _t->getSecUserLeverbyname((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<SecurityLever*>(_a[0]) = std::move(_r); }  break;
        case 47: _t->checkPwdLimitLevel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 48: _t->showDefender(); break;
        case 49: _t->playSystemSound((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 50: _t->updateUserOnlineStatus((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1]))); break;
        case 51: _t->getAllGroups(); break;
        case 52: _t->getAllGroupsResult((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 53: _t->getPresetGroups(); break;
        case 54: _t->getPresetGroupsResult((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 55: _t->checkADUser(); break;
        case 56: _t->active(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CreationResult* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< User* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< User* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< User* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< User* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< User* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< User* >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< User* >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< User* >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< User* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< User* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< User* >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< User* >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< User* >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< User* >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< User* >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< User* >(); break;
            }
            break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< User* >(); break;
            }
            break;
        case 39:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< User* >(); break;
            }
            break;
        case 40:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< User* >(); break;
            }
            break;
        case 50:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDBusObjectPath> >(); break;
            }
            break;
        case 52:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 54:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AccountsWorker::*)(CreationResult * ) const>(_a, &AccountsWorker::accountCreationFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsWorker::*)() const>(_a, &AccountsWorker::accountFullNameChangeFinished, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsWorker::*)(const bool ) const>(_a, &AccountsWorker::requestMainWindowEnabled, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsWorker::*)(const QString & )>(_a, &AccountsWorker::localBindUbid, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsWorker::*)(const QString & )>(_a, &AccountsWorker::localBindError, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsWorker::*)(const QString & )>(_a, &AccountsWorker::showSafetyPage, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsWorker::*)(OperateType , bool , const QString & )>(_a, &AccountsWorker::updateGroupFinished, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsWorker::*)(const QString & )>(_a, &AccountsWorker::updateGroupFailed, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsWorker::*)(const QString & )>(_a, &AccountsWorker::createGroupFailed, 10))
            return;
    }
}

const QMetaObject *dccV25::AccountsWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::AccountsWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2514AccountsWorkerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dccV25::AccountsWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 57)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 57;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 57)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 57;
    }
    return _id;
}

// SIGNAL 0
void dccV25::AccountsWorker::accountCreationFinished(CreationResult * _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::AccountsWorker *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dccV25::AccountsWorker::accountFullNameChangeFinished()const
{
    QMetaObject::activate(const_cast< dccV25::AccountsWorker *>(this), &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dccV25::AccountsWorker::requestMainWindowEnabled(const bool _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::AccountsWorker *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dccV25::AccountsWorker::localBindUbid(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dccV25::AccountsWorker::localBindError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void dccV25::AccountsWorker::showSafetyPage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void dccV25::AccountsWorker::updateGroupFinished(OperateType _t1, bool _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 8
void dccV25::AccountsWorker::updateGroupFailed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 10
void dccV25::AccountsWorker::createGroupFailed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}
QT_WARNING_POP
