// This file is autogenerated. Changes will be overwritten.
#include "MTJHVBGFB2/moc_dccscreen.cpp"
#include "MTJHVBGFB2/moc_displaymodule.cpp"
#include "MLNVN3SMNM/moc_displaydbusproxy.cpp"
#include "MLNVN3SMNM/moc_displaymodel.cpp"
#include "MLNVN3SMNM/moc_displayworker.cpp"
#include "MLNVN3SMNM/moc_monitor.cpp"
#include "MLNVN3SMNM/moc_monitordbusproxy.cpp"
