/****************************************************************************
** Meta object code from reading C++ file 'mousedbusproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-mouse/operation/mousedbusproxy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mousedbusproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13DCC_NAMESPACE14MouseDBusProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto DCC_NAMESPACE::MouseDBusProxy::qt_create_metaobjectdata<qt_meta_tag_ZN13DCC_NAMESPACE14MouseDBusProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DCC_NAMESPACE::MouseDBusProxy",
        "active",
        "",
        "onDefaultReset",
        "setLeftHandState",
        "state",
        "setDouClick",
        "value",
        "setMouseNaturalScrollState",
        "setDisableTouchPadWhenMouseExist",
        "setAccelProfile",
        "setMouseMotionAcceleration",
        "setTouchNaturalScrollState",
        "setDisTyping",
        "setTouchpadMotionAcceleration",
        "setTapClick",
        "setPalmDetect",
        "palmDetect",
        "setPalmMinWidth",
        "palmMinWidth",
        "setPalmMinz",
        "palmMinz",
        "setTouchpadEnabled",
        "setTrackPointMotionAcceleration",
        "setScrollSpeed",
        "speed",
        "setGesture",
        "name",
        "direction",
        "fingers",
        "action",
        "onMousePathPropertiesChanged",
        "QDBusMessage",
        "msg",
        "onTouchpadPathPropertiesChanged",
        "onTrackpointPathPropertiesChanged",
        "onInputDevicesPathPropertiesChanged",
        "onGesturePropertiesChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'active'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onDefaultReset'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setLeftHandState'
        QtMocHelpers::SlotData<void(const bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setDouClick'
        QtMocHelpers::SlotData<void(const int &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'setMouseNaturalScrollState'
        QtMocHelpers::SlotData<void(const bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setDisableTouchPadWhenMouseExist'
        QtMocHelpers::SlotData<void(const bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setAccelProfile'
        QtMocHelpers::SlotData<void(const bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setMouseMotionAcceleration'
        QtMocHelpers::SlotData<void(const double &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 7 },
        }}),
        // Slot 'setTouchNaturalScrollState'
        QtMocHelpers::SlotData<void(const bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setDisTyping'
        QtMocHelpers::SlotData<void(const bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setTouchpadMotionAcceleration'
        QtMocHelpers::SlotData<void(const double &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 7 },
        }}),
        // Slot 'setTapClick'
        QtMocHelpers::SlotData<void(const bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setPalmDetect'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'setPalmMinWidth'
        QtMocHelpers::SlotData<void(int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'setPalmMinz'
        QtMocHelpers::SlotData<void(int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'setTouchpadEnabled'
        QtMocHelpers::SlotData<void(bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setTrackPointMotionAcceleration'
        QtMocHelpers::SlotData<void(const double &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 7 },
        }}),
        // Slot 'setScrollSpeed'
        QtMocHelpers::SlotData<void(uint)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 25 },
        }}),
        // Slot 'setGesture'
        QtMocHelpers::SlotData<void(const QString &, const QString &, int, const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 }, { QMetaType::QString, 28 }, { QMetaType::Int, 29 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'onMousePathPropertiesChanged'
        QtMocHelpers::SlotData<void(QDBusMessage)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Slot 'onTouchpadPathPropertiesChanged'
        QtMocHelpers::SlotData<void(QDBusMessage)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Slot 'onTrackpointPathPropertiesChanged'
        QtMocHelpers::SlotData<void(QDBusMessage)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Slot 'onInputDevicesPathPropertiesChanged'
        QtMocHelpers::SlotData<void(QDBusMessage)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Slot 'onGesturePropertiesChanged'
        QtMocHelpers::SlotData<void(QDBusMessage)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MouseDBusProxy, qt_meta_tag_ZN13DCC_NAMESPACE14MouseDBusProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DCC_NAMESPACE::MouseDBusProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DCC_NAMESPACE14MouseDBusProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DCC_NAMESPACE14MouseDBusProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13DCC_NAMESPACE14MouseDBusProxyE_t>.metaTypes,
    nullptr
} };

void DCC_NAMESPACE::MouseDBusProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MouseDBusProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->active(); break;
        case 1: _t->onDefaultReset(); break;
        case 2: _t->setLeftHandState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->setDouClick((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->setMouseNaturalScrollState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->setDisableTouchPadWhenMouseExist((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->setAccelProfile((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->setMouseMotionAcceleration((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 8: _t->setTouchNaturalScrollState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->setDisTyping((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->setTouchpadMotionAcceleration((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 11: _t->setTapClick((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->setPalmDetect((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->setPalmMinWidth((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->setPalmMinz((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->setTouchpadEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->setTrackPointMotionAcceleration((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 17: _t->setScrollSpeed((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 18: _t->setGesture((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 19: _t->onMousePathPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        case 20: _t->onTouchpadPathPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        case 21: _t->onTrackpointPathPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        case 22: _t->onInputDevicesPathPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        case 23: _t->onGesturePropertiesChanged((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            }
            break;
        }
    }
}

const QMetaObject *DCC_NAMESPACE::MouseDBusProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DCC_NAMESPACE::MouseDBusProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DCC_NAMESPACE14MouseDBusProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DCC_NAMESPACE::MouseDBusProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    return _id;
}
QT_WARNING_POP
