/****************************************************************************
** Meta object code from reading C++ file 'systeminfomodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-systeminfo/operation/systeminfomodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'systeminfomodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13DCC_NAMESPACE15SystemInfoModelE_t {};
} // unnamed namespace

template <> constexpr inline auto DCC_NAMESPACE::SystemInfoModel::qt_create_metaobjectdata<qt_meta_tag_ZN13DCC_NAMESPACE15SystemInfoModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DCC_NAMESPACE::SystemInfoModel",
        "productNameChanged",
        "",
        "version",
        "versionNumberChanged",
        "versionChanged",
        "typeChanged",
        "type",
        "processorChanged",
        "processor",
        "memoryChanged",
        "memory",
        "kernelChanged",
        "kernel",
        "licenseStateChanged",
        "ActiveState",
        "state",
        "hostNameChanged",
        "hostName",
        "setHostNameError",
        "error",
        "privacyPolicyChanged",
        "gnuLinceseTitleChanged",
        "gnuLinceseContentChanged",
        "userLicenseChanged",
        "userExperienceProgramTextChanged",
        "joinUeProgramChanged",
        "enable",
        "systemCopyrightChanged",
        "licenseStateDataChanged",
        "licenseStatusTextChanged",
        "licenseActionTextChanged",
        "licenseStatusColorChanged",
        "showDetailChanged",
        "logoPathChanged",
        "systemInstallationDateChanged",
        "graphicsPlatformChanged",
        "setProductName",
        "name",
        "setVersionNumber",
        "number",
        "setVersion",
        "setType",
        "setProcessor",
        "setMemory",
        "totalMemory",
        "installedMemory",
        "setKernel",
        "setLicenseState",
        "DCC_NAMESPACE::ActiveState",
        "setHostName",
        "setEndUserAgreementPath",
        "path",
        "showAuthorization",
        "showUserExperienceProgram",
        "showGraphicsPlatform",
        "privacyPolicy",
        "gnuLinceseTitle",
        "gnuLinceseContent",
        "userLicense",
        "userExperienceProgramText",
        "joinUeProgram",
        "productName",
        "systemCopyright",
        "versionNumber",
        "licenseStatusText",
        "licenseActionText",
        "licenseStatusColor",
        "QColor",
        "showDetail",
        "logoPath",
        "systemInstallationDate",
        "graphicsPlatform"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'productNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'versionNumberChanged'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'versionChanged'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'processorChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'memoryChanged'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'kernelChanged'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'licenseStateChanged'
        QtMocHelpers::SignalData<void(ActiveState)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'hostNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Signal 'setHostNameError'
        QtMocHelpers::SignalData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Signal 'privacyPolicyChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gnuLinceseTitleChanged'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gnuLinceseContentChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'userLicenseChanged'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'userExperienceProgramTextChanged'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'joinUeProgramChanged'
        QtMocHelpers::SignalData<void(const bool) const>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Signal 'systemCopyrightChanged'
        QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'licenseStateDataChanged'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'licenseStatusTextChanged'
        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'licenseActionTextChanged'
        QtMocHelpers::SignalData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'licenseStatusColorChanged'
        QtMocHelpers::SignalData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showDetailChanged'
        QtMocHelpers::SignalData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'logoPathChanged'
        QtMocHelpers::SignalData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'systemInstallationDateChanged'
        QtMocHelpers::SignalData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'graphicsPlatformChanged'
        QtMocHelpers::SignalData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setProductName'
        QtMocHelpers::SlotData<void(const QString &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 38 },
        }}),
        // Slot 'setVersionNumber'
        QtMocHelpers::SlotData<void(const QString &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 40 },
        }}),
        // Slot 'setVersion'
        QtMocHelpers::SlotData<void(const QString &)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'setType'
        QtMocHelpers::SlotData<void(qlonglong)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 7 },
        }}),
        // Slot 'setProcessor'
        QtMocHelpers::SlotData<void(const QString &)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'setMemory'
        QtMocHelpers::SlotData<void(qulonglong, qulonglong)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 45 }, { QMetaType::ULongLong, 46 },
        }}),
        // Slot 'setKernel'
        QtMocHelpers::SlotData<void(const QString &)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'setLicenseState'
        QtMocHelpers::SlotData<void(DCC_NAMESPACE::ActiveState)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 49, 16 },
        }}),
        // Slot 'setHostName'
        QtMocHelpers::SlotData<void(const QString &)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'setEndUserAgreementPath'
        QtMocHelpers::SlotData<void(const QString &)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 52 },
        }}),
        // Method 'showAuthorization'
        QtMocHelpers::MethodData<bool() const>(53, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'showUserExperienceProgram'
        QtMocHelpers::MethodData<bool() const>(54, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'showGraphicsPlatform'
        QtMocHelpers::MethodData<bool() const>(55, 2, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'privacyPolicy'
        QtMocHelpers::PropertyData<QString>(56, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 10),
        // property 'gnuLinceseTitle'
        QtMocHelpers::PropertyData<QString>(57, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 11),
        // property 'gnuLinceseContent'
        QtMocHelpers::PropertyData<QString>(58, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 12),
        // property 'userLicense'
        QtMocHelpers::PropertyData<QString>(59, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 13),
        // property 'userExperienceProgramText'
        QtMocHelpers::PropertyData<QString>(60, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 14),
        // property 'joinUeProgram'
        QtMocHelpers::PropertyData<bool>(61, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 15),
        // property 'productName'
        QtMocHelpers::PropertyData<QString>(62, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 0),
        // property 'systemCopyright'
        QtMocHelpers::PropertyData<QString>(63, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 16),
        // property 'hostName'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 8),
        // property 'version'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 2),
        // property 'versionNumber'
        QtMocHelpers::PropertyData<QString>(64, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 1),
        // property 'type'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 3),
        // property 'memory'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 5),
        // property 'kernel'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 6),
        // property 'processor'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 4),
        // property 'licenseStatusText'
        QtMocHelpers::PropertyData<QString>(65, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 18),
        // property 'licenseActionText'
        QtMocHelpers::PropertyData<QString>(66, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 19),
        // property 'licenseStatusColor'
        QtMocHelpers::PropertyData<QColor>(67, 0x80000000 | 68, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 20),
        // property 'showDetail'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 21),
        // property 'logoPath'
        QtMocHelpers::PropertyData<QString>(70, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 22),
        // property 'systemInstallationDate'
        QtMocHelpers::PropertyData<QString>(71, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 23),
        // property 'graphicsPlatform'
        QtMocHelpers::PropertyData<QString>(72, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 24),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SystemInfoModel, qt_meta_tag_ZN13DCC_NAMESPACE15SystemInfoModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DCC_NAMESPACE::SystemInfoModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DCC_NAMESPACE15SystemInfoModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DCC_NAMESPACE15SystemInfoModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13DCC_NAMESPACE15SystemInfoModelE_t>.metaTypes,
    nullptr
} };

void DCC_NAMESPACE::SystemInfoModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SystemInfoModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->productNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->versionNumberChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->versionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->typeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->processorChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->memoryChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->kernelChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->licenseStateChanged((*reinterpret_cast<std::add_pointer_t<ActiveState>>(_a[1]))); break;
        case 8: _t->hostNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->setHostNameError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->privacyPolicyChanged(); break;
        case 11: _t->gnuLinceseTitleChanged(); break;
        case 12: _t->gnuLinceseContentChanged(); break;
        case 13: _t->userLicenseChanged(); break;
        case 14: _t->userExperienceProgramTextChanged(); break;
        case 15: _t->joinUeProgramChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->systemCopyrightChanged(); break;
        case 17: _t->licenseStateDataChanged(); break;
        case 18: _t->licenseStatusTextChanged(); break;
        case 19: _t->licenseActionTextChanged(); break;
        case 20: _t->licenseStatusColorChanged(); break;
        case 21: _t->showDetailChanged(); break;
        case 22: _t->logoPathChanged(); break;
        case 23: _t->systemInstallationDateChanged(); break;
        case 24: _t->graphicsPlatformChanged(); break;
        case 25: _t->setProductName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: _t->setVersionNumber((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->setVersion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->setType((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 29: _t->setProcessor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 30: _t->setMemory((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 31: _t->setKernel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 32: _t->setLicenseState((*reinterpret_cast<std::add_pointer_t<DCC_NAMESPACE::ActiveState>>(_a[1]))); break;
        case 33: _t->setHostName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 34: _t->setEndUserAgreementPath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 35: { bool _r = _t->showAuthorization();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 36: { bool _r = _t->showUserExperienceProgram();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 37: { bool _r = _t->showGraphicsPlatform();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DCC_NAMESPACE::ActiveState >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)(const QString & )>(_a, &SystemInfoModel::productNameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)(const QString & )>(_a, &SystemInfoModel::versionNumberChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)(const QString & )>(_a, &SystemInfoModel::versionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)(const QString & )>(_a, &SystemInfoModel::typeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)(const QString & )>(_a, &SystemInfoModel::processorChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)(const QString & )>(_a, &SystemInfoModel::memoryChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)(const QString & )>(_a, &SystemInfoModel::kernelChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)(ActiveState )>(_a, &SystemInfoModel::licenseStateChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)(const QString & )>(_a, &SystemInfoModel::hostNameChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)(const QString & )>(_a, &SystemInfoModel::setHostNameError, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)()>(_a, &SystemInfoModel::privacyPolicyChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)()>(_a, &SystemInfoModel::gnuLinceseTitleChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)()>(_a, &SystemInfoModel::gnuLinceseContentChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)()>(_a, &SystemInfoModel::userLicenseChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)()>(_a, &SystemInfoModel::userExperienceProgramTextChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)(const bool ) const>(_a, &SystemInfoModel::joinUeProgramChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)()>(_a, &SystemInfoModel::systemCopyrightChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)()>(_a, &SystemInfoModel::licenseStateDataChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)()>(_a, &SystemInfoModel::licenseStatusTextChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)()>(_a, &SystemInfoModel::licenseActionTextChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)()>(_a, &SystemInfoModel::licenseStatusColorChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)()>(_a, &SystemInfoModel::showDetailChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)()>(_a, &SystemInfoModel::logoPathChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)()>(_a, &SystemInfoModel::systemInstallationDateChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoModel::*)()>(_a, &SystemInfoModel::graphicsPlatformChanged, 24))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->privacyPolicy(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->gnuLinceseTitle(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->gnuLinceseContent(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->userLicense(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->userExperienceProgramText(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->joinUeProgram(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->productName(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->systemCopyright(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->hostName(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->version(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->versionNumber(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->type(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->memory(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->kernel(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->processor(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->licenseStatusText(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->licenseActionText(); break;
        case 17: *reinterpret_cast<QColor*>(_v) = _t->licenseStatusColor(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->showDetail(); break;
        case 19: *reinterpret_cast<QString*>(_v) = _t->logoPath(); break;
        case 20: *reinterpret_cast<QString*>(_v) = _t->systemInstallationDate(); break;
        case 21: *reinterpret_cast<QString*>(_v) = _t->graphicsPlatform(); break;
        default: break;
        }
    }
}

const QMetaObject *DCC_NAMESPACE::SystemInfoModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DCC_NAMESPACE::SystemInfoModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DCC_NAMESPACE15SystemInfoModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DCC_NAMESPACE::SystemInfoModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void DCC_NAMESPACE::SystemInfoModel::productNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DCC_NAMESPACE::SystemInfoModel::versionNumberChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DCC_NAMESPACE::SystemInfoModel::versionChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DCC_NAMESPACE::SystemInfoModel::typeChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DCC_NAMESPACE::SystemInfoModel::processorChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DCC_NAMESPACE::SystemInfoModel::memoryChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DCC_NAMESPACE::SystemInfoModel::kernelChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void DCC_NAMESPACE::SystemInfoModel::licenseStateChanged(ActiveState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void DCC_NAMESPACE::SystemInfoModel::hostNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void DCC_NAMESPACE::SystemInfoModel::setHostNameError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void DCC_NAMESPACE::SystemInfoModel::privacyPolicyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DCC_NAMESPACE::SystemInfoModel::gnuLinceseTitleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void DCC_NAMESPACE::SystemInfoModel::gnuLinceseContentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void DCC_NAMESPACE::SystemInfoModel::userLicenseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void DCC_NAMESPACE::SystemInfoModel::userExperienceProgramTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void DCC_NAMESPACE::SystemInfoModel::joinUeProgramChanged(const bool _t1)const
{
    QMetaObject::activate<void>(const_cast< DCC_NAMESPACE::SystemInfoModel *>(this), &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void DCC_NAMESPACE::SystemInfoModel::systemCopyrightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void DCC_NAMESPACE::SystemInfoModel::licenseStateDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void DCC_NAMESPACE::SystemInfoModel::licenseStatusTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void DCC_NAMESPACE::SystemInfoModel::licenseActionTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void DCC_NAMESPACE::SystemInfoModel::licenseStatusColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void DCC_NAMESPACE::SystemInfoModel::showDetailChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void DCC_NAMESPACE::SystemInfoModel::logoPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void DCC_NAMESPACE::SystemInfoModel::systemInstallationDateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void DCC_NAMESPACE::SystemInfoModel::graphicsPlatformChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}
QT_WARNING_POP
