/* Generated by wayland-scanner 1.25.0 */

/*
 * SPDX-FileCopyrightText: 2023 rewine <luhongxu@deepin.org>.
 * SPDX-License-Identifier: MIT
 */

#include <stdbool.h>
#include <stdlib.h>
#include <stdint.h>
#include "wayland-util.h"


static const struct wl_interface *treeland_output_manager_v1_types[] = {
	NULL,
};

static const struct wl_message treeland_output_manager_v1_requests[] = {
	{ "set_primary_output", "s", treeland_output_manager_v1_types + 0 },
	{ "destroy", "", treeland_output_manager_v1_types + 0 },
};

static const struct wl_message treeland_output_manager_v1_events[] = {
	{ "primary_output", "s", treeland_output_manager_v1_types + 0 },
};

WL_EXPORT const struct wl_interface treeland_output_manager_v1_interface = {
	"treeland_output_manager_v1", 1,
	2, treeland_output_manager_v1_requests,
	1, treeland_output_manager_v1_events,
};

