/****************************************************************************
** Meta object code from reading C++ file 'pluginmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/dde-control-center/pluginmanager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSet>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pluginmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6dccV2513PluginManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::PluginManager::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV2513PluginManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::PluginManager",
        "addObject",
        "",
        "DccObject*",
        "obj",
        "loadAllFinished",
        "pluginEndStatusChanged",
        "PluginData*",
        "plugin",
        "updatePluginStatus",
        "status",
        "log",
        "cancelLoad",
        "loadPlugin",
        "loadMetaData",
        "loadModule",
        "loadMain",
        "createModule",
        "QQmlComponent*",
        "component",
        "createMain",
        "addMainObject",
        "moduleLoading",
        "mainLoading",
        "onHideModuleChanged",
        "QSet<QString>",
        "hideModule",
        "onVisibleToAppChanged",
        "visibleToApp",
        "onUpdatePluginStatus"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'addObject'
        QtMocHelpers::SignalData<void(DccObject *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'loadAllFinished'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pluginEndStatusChanged'
        QtMocHelpers::SignalData<void(PluginData *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'updatePluginStatus'
        QtMocHelpers::SignalData<void(PluginData *, uint, const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::UInt, 10 }, { QMetaType::QString, 11 },
        }}),
        // Slot 'cancelLoad'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadPlugin'
        QtMocHelpers::SlotData<void(PluginData *)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'loadMetaData'
        QtMocHelpers::SlotData<void(PluginData *)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'loadModule'
        QtMocHelpers::SlotData<void(PluginData *)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'loadMain'
        QtMocHelpers::SlotData<void(PluginData *)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'createModule'
        QtMocHelpers::SlotData<void(QQmlComponent *)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'createMain'
        QtMocHelpers::SlotData<void(QQmlComponent *)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'addMainObject'
        QtMocHelpers::SlotData<void(PluginData *)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'moduleLoading'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'mainLoading'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onHideModuleChanged'
        QtMocHelpers::SlotData<void(const QSet<QString> &)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'onVisibleToAppChanged'
        QtMocHelpers::SlotData<void(bool)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'onUpdatePluginStatus'
        QtMocHelpers::SlotData<void(PluginData *, uint, const QString &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::UInt, 10 }, { QMetaType::QString, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PluginManager, qt_meta_tag_ZN6dccV2513PluginManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dccV25::PluginManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2513PluginManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2513PluginManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV2513PluginManagerE_t>.metaTypes,
    nullptr
} };

void dccV25::PluginManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PluginManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addObject((*reinterpret_cast<std::add_pointer_t<DccObject*>>(_a[1]))); break;
        case 1: _t->loadAllFinished(); break;
        case 2: _t->pluginEndStatusChanged((*reinterpret_cast<std::add_pointer_t<PluginData*>>(_a[1]))); break;
        case 3: _t->updatePluginStatus((*reinterpret_cast<std::add_pointer_t<PluginData*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 4: _t->cancelLoad(); break;
        case 5: _t->loadPlugin((*reinterpret_cast<std::add_pointer_t<PluginData*>>(_a[1]))); break;
        case 6: _t->loadMetaData((*reinterpret_cast<std::add_pointer_t<PluginData*>>(_a[1]))); break;
        case 7: _t->loadModule((*reinterpret_cast<std::add_pointer_t<PluginData*>>(_a[1]))); break;
        case 8: _t->loadMain((*reinterpret_cast<std::add_pointer_t<PluginData*>>(_a[1]))); break;
        case 9: _t->createModule((*reinterpret_cast<std::add_pointer_t<QQmlComponent*>>(_a[1]))); break;
        case 10: _t->createMain((*reinterpret_cast<std::add_pointer_t<QQmlComponent*>>(_a[1]))); break;
        case 11: _t->addMainObject((*reinterpret_cast<std::add_pointer_t<PluginData*>>(_a[1]))); break;
        case 12: _t->moduleLoading(); break;
        case 13: _t->mainLoading(); break;
        case 14: _t->onHideModuleChanged((*reinterpret_cast<std::add_pointer_t<QSet<QString>>>(_a[1]))); break;
        case 15: _t->onVisibleToAppChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->onUpdatePluginStatus((*reinterpret_cast<std::add_pointer_t<PluginData*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QString> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PluginManager::*)(DccObject * )>(_a, &PluginManager::addObject, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginManager::*)()>(_a, &PluginManager::loadAllFinished, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginManager::*)(PluginData * )>(_a, &PluginManager::pluginEndStatusChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginManager::*)(PluginData * , uint , const QString & )>(_a, &PluginManager::updatePluginStatus, 3))
            return;
    }
}

const QMetaObject *dccV25::PluginManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::PluginManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2513PluginManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dccV25::PluginManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void dccV25::PluginManager::addObject(DccObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dccV25::PluginManager::loadAllFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dccV25::PluginManager::pluginEndStatusChanged(PluginData * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dccV25::PluginManager::updatePluginStatus(PluginData * _t1, uint _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
