// This file is autogenerated. Changes will be overwritten.
#include "MTJHVBGFB2/moc_powerdbusproxy.cpp"
#include "MTJHVBGFB2/moc_powerinterface.cpp"
#include "MTJHVBGFB2/moc_powermodel.cpp"
#include "MTJHVBGFB2/moc_poweroperatormodel.cpp"
#include "MTJHVBGFB2/moc_powerworker.cpp"
