/****************************************************************************
** Meta object code from reading C++ file 'commoninfomodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-commoninfo/operation/commoninfomodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'commoninfomodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15CommonInfoModelE_t {};
} // unnamed namespace

template <> constexpr inline auto CommonInfoModel::qt_create_metaobjectdata<qt_meta_tag_ZN15CommonInfoModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CommonInfoModel",
        "QML.Element",
        "QML.Singleton",
        "true",
        "bootDelayChanged",
        "",
        "enabled",
        "themeEnabledChanged",
        "grubEditAuthEnabledChanged",
        "entryListsChanged",
        "list",
        "defaultEntryChanged",
        "entry",
        "updatingChanged",
        "updating",
        "backgroundChanged",
        "QPixmap",
        "pixmap",
        "ueProgramChanged",
        "enable",
        "developerModeStateChanged",
        "isLoginChenged",
        "log",
        "LicenseStateChanged",
        "state",
        "plymouthScaleChanged",
        "scale",
        "plymouthThemeChanged",
        "themeName",
        "GrubAnimationModelChanged",
        "debugLogCurrentIndexChanged",
        "grubThemePathChanged",
        "needShowModalDialogChanged",
        "isDeveloperModeChanged",
        "setBootDelay",
        "bootDelay",
        "setThemeEnabled",
        "setShowGrubEditAuth",
        "setGrubEditAuthEnabled",
        "setDefaultEntry",
        "setUpdating",
        "setUeProgram",
        "ueProgram",
        "setDeveloperModeState",
        "setIsLogin",
        "setPlymouthScale",
        "setPlymouthTheme",
        "setIsDeveloperMode",
        "newIsDeveloperMode",
        "grubAnimationModel",
        "GrubAnimationModel*",
        "grubMenuListModel",
        "GrubMenuListModel*",
        "isCommunitySystem",
        "themeEnabled",
        "grubEditAuthEnabled",
        "debugLogCurrentIndex",
        "developerModeState",
        "isLogin",
        "isActivate",
        "grubThemePath",
        "needShowModalDialog",
        "isDeveloperMode"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bootDelayChanged'
        QtMocHelpers::SignalData<void(const bool) const>(4, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'themeEnabledChanged'
        QtMocHelpers::SignalData<void(const bool) const>(7, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'grubEditAuthEnabledChanged'
        QtMocHelpers::SignalData<void(const bool) const>(8, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'entryListsChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(9, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 10 },
        }}),
        // Signal 'defaultEntryChanged'
        QtMocHelpers::SignalData<void(const QString &)>(11, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'updatingChanged'
        QtMocHelpers::SignalData<void(const bool &)>(13, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'backgroundChanged'
        QtMocHelpers::SignalData<void(const QPixmap &)>(15, 5, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'ueProgramChanged'
        QtMocHelpers::SignalData<void(const bool) const>(18, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Signal 'developerModeStateChanged'
        QtMocHelpers::SignalData<void(const bool) const>(20, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Signal 'isLoginChenged'
        QtMocHelpers::SignalData<void(bool) const>(21, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Signal 'LicenseStateChanged'
        QtMocHelpers::SignalData<void(bool)>(23, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Signal 'plymouthScaleChanged'
        QtMocHelpers::SignalData<void(int)>(25, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Signal 'plymouthThemeChanged'
        QtMocHelpers::SignalData<void(const QString &)>(27, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Signal 'GrubAnimationModelChanged'
        QtMocHelpers::SignalData<void()>(29, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'debugLogCurrentIndexChanged'
        QtMocHelpers::SignalData<void()>(30, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'grubThemePathChanged'
        QtMocHelpers::SignalData<void()>(31, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'needShowModalDialogChanged'
        QtMocHelpers::SignalData<void()>(32, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isDeveloperModeChanged'
        QtMocHelpers::SignalData<void()>(33, 5, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setBootDelay'
        QtMocHelpers::SlotData<void(bool)>(34, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 35 },
        }}),
        // Slot 'setThemeEnabled'
        QtMocHelpers::SlotData<void(const bool)>(36, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'setShowGrubEditAuth'
        QtMocHelpers::SlotData<void(const bool)>(37, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'setGrubEditAuthEnabled'
        QtMocHelpers::SlotData<void(const bool)>(38, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'setDefaultEntry'
        QtMocHelpers::SlotData<void(const QString &)>(39, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'setUpdating'
        QtMocHelpers::SlotData<void(bool)>(40, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'setUeProgram'
        QtMocHelpers::SlotData<void(const bool)>(41, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Slot 'setDeveloperModeState'
        QtMocHelpers::SlotData<void(const bool)>(43, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'setIsLogin'
        QtMocHelpers::SlotData<void(const bool)>(44, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'setPlymouthScale'
        QtMocHelpers::SlotData<void(int)>(45, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'setPlymouthTheme'
        QtMocHelpers::SlotData<void(const QString &)>(46, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'setIsDeveloperMode'
        QtMocHelpers::SlotData<void(bool)>(47, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 48 },
        }}),
        // Method 'grubAnimationModel'
        QtMocHelpers::MethodData<GrubAnimationModel *()>(49, 5, QMC::AccessPublic, 0x80000000 | 50),
        // Method 'grubMenuListModel'
        QtMocHelpers::MethodData<GrubMenuListModel *()>(51, 5, QMC::AccessPublic, 0x80000000 | 52),
        // Method 'isCommunitySystem'
        QtMocHelpers::MethodData<bool() const>(53, 5, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'bootDelay'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 0),
        // property 'themeEnabled'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 1),
        // property 'grubEditAuthEnabled'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 2),
        // property 'debugLogCurrentIndex'
        QtMocHelpers::PropertyData<int>(56, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 14),
        // property 'developerModeState'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 8),
        // property 'isLogin'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 9),
        // property 'isActivate'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 10),
        // property 'grubThemePath'
        QtMocHelpers::PropertyData<QString>(60, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 15),
        // property 'needShowModalDialog'
        QtMocHelpers::PropertyData<bool>(61, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 16),
        // property 'isDeveloperMode'
        QtMocHelpers::PropertyData<bool>(62, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 17),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    0 },
            {    2,    3 },
    });
    return QtMocHelpers::metaObjectData<CommonInfoModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CommonInfoModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CommonInfoModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CommonInfoModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15CommonInfoModelE_t>.metaTypes,
    nullptr
} };

void CommonInfoModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CommonInfoModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bootDelayChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->themeEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->grubEditAuthEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->entryListsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 4: _t->defaultEntryChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->updatingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->backgroundChanged((*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[1]))); break;
        case 7: _t->ueProgramChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->developerModeStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->isLoginChenged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->LicenseStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->plymouthScaleChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->plymouthThemeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->GrubAnimationModelChanged(); break;
        case 14: _t->debugLogCurrentIndexChanged(); break;
        case 15: _t->grubThemePathChanged(); break;
        case 16: _t->needShowModalDialogChanged(); break;
        case 17: _t->isDeveloperModeChanged(); break;
        case 18: _t->setBootDelay((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->setThemeEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->setShowGrubEditAuth((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->setGrubEditAuthEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->setDefaultEntry((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->setUpdating((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: _t->setUeProgram((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->setDeveloperModeState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->setIsLogin((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->setPlymouthScale((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->setPlymouthTheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: _t->setIsDeveloperMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: { GrubAnimationModel* _r = _t->grubAnimationModel();
            if (_a[0]) *reinterpret_cast<GrubAnimationModel**>(_a[0]) = std::move(_r); }  break;
        case 31: { GrubMenuListModel* _r = _t->grubMenuListModel();
            if (_a[0]) *reinterpret_cast<GrubMenuListModel**>(_a[0]) = std::move(_r); }  break;
        case 32: { bool _r = _t->isCommunitySystem();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CommonInfoModel::*)(const bool ) const>(_a, &CommonInfoModel::bootDelayChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoModel::*)(const bool ) const>(_a, &CommonInfoModel::themeEnabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoModel::*)(const bool ) const>(_a, &CommonInfoModel::grubEditAuthEnabledChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoModel::*)(const QStringList & )>(_a, &CommonInfoModel::entryListsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoModel::*)(const QString & )>(_a, &CommonInfoModel::defaultEntryChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoModel::*)(const bool & )>(_a, &CommonInfoModel::updatingChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoModel::*)(const QPixmap & )>(_a, &CommonInfoModel::backgroundChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoModel::*)(const bool ) const>(_a, &CommonInfoModel::ueProgramChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoModel::*)(const bool ) const>(_a, &CommonInfoModel::developerModeStateChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoModel::*)(bool ) const>(_a, &CommonInfoModel::isLoginChenged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoModel::*)(bool )>(_a, &CommonInfoModel::LicenseStateChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoModel::*)(int )>(_a, &CommonInfoModel::plymouthScaleChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoModel::*)(const QString & )>(_a, &CommonInfoModel::plymouthThemeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoModel::*)()>(_a, &CommonInfoModel::GrubAnimationModelChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoModel::*)()>(_a, &CommonInfoModel::debugLogCurrentIndexChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoModel::*)()>(_a, &CommonInfoModel::grubThemePathChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoModel::*)()>(_a, &CommonInfoModel::needShowModalDialogChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoModel::*)()>(_a, &CommonInfoModel::isDeveloperModeChanged, 17))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->bootDelay(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->themeEnabled(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->grubEditAuthEnabled(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->debugLogCurrentIndex(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->developerModeState(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isLogin(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isActivate(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->grubThemePath(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->needShowModalDialog(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isDeveloperMode(); break;
        default: break;
        }
    }
}

const QMetaObject *CommonInfoModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CommonInfoModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CommonInfoModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int CommonInfoModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 33)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 33;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void CommonInfoModel::bootDelayChanged(const bool _t1)const
{
    QMetaObject::activate<void>(const_cast< CommonInfoModel *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void CommonInfoModel::themeEnabledChanged(const bool _t1)const
{
    QMetaObject::activate<void>(const_cast< CommonInfoModel *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void CommonInfoModel::grubEditAuthEnabledChanged(const bool _t1)const
{
    QMetaObject::activate<void>(const_cast< CommonInfoModel *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void CommonInfoModel::entryListsChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void CommonInfoModel::defaultEntryChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void CommonInfoModel::updatingChanged(const bool & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void CommonInfoModel::backgroundChanged(const QPixmap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void CommonInfoModel::ueProgramChanged(const bool _t1)const
{
    QMetaObject::activate<void>(const_cast< CommonInfoModel *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void CommonInfoModel::developerModeStateChanged(const bool _t1)const
{
    QMetaObject::activate<void>(const_cast< CommonInfoModel *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void CommonInfoModel::isLoginChenged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< CommonInfoModel *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void CommonInfoModel::LicenseStateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void CommonInfoModel::plymouthScaleChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void CommonInfoModel::plymouthThemeChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void CommonInfoModel::GrubAnimationModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void CommonInfoModel::debugLogCurrentIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void CommonInfoModel::grubThemePathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void CommonInfoModel::needShowModalDialogChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void CommonInfoModel::isDeveloperModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}
QT_WARNING_POP
