/****************************************************************************
** Meta object code from reading C++ file 'powerdbusproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-power/operation/powerdbusproxy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'powerdbusproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14PowerDBusProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto PowerDBusProxy::qt_create_metaobjectdata<qt_meta_tag_ZN14PowerDBusProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowerDBusProxy",
        "ScreenBlackLockChanged",
        "",
        "value",
        "SleepLockChanged",
        "LidIsPresentChanged",
        "LidClosedSleepChanged",
        "LinePowerScreenBlackDelayChanged",
        "LinePowerSleepDelayChanged",
        "BatteryScreenBlackDelayChanged",
        "BatterySleepDelayChanged",
        "BatteryLockDelayChanged",
        "LinePowerLockDelayChanged",
        "IsHighPerformanceSupportedChanged",
        "IsBalancePerformanceSupportedChanged",
        "LinePowerPressPowerBtnActionChanged",
        "LinePowerLidClosedActionChanged",
        "BatteryPressPowerBtnActionChanged",
        "BatteryLidClosedActionChanged",
        "LowPowerNotifyEnableChanged",
        "LowPowerNotifyThresholdChanged",
        "LowPowerAutoSleepThresholdChanged",
        "ShutdownTimeChanged",
        "time",
        "PowerSavingModeAutoChanged",
        "PowerSavingModeEnabledChanged",
        "HasBatteryChanged",
        "BatteryPercentageChanged",
        "PowerSavingModeAutoWhenBatteryLowChanged",
        "PowerSavingModeBrightnessDropPercentChanged",
        "PowerSavingModeAutoBatteryPercentChanged",
        "ModeChanged",
        "BatteryCapacityChanged",
        "noPasswdLoginChanged",
        "ScheduledShutdownStateChanged",
        "ShutdownRepetitionChanged",
        "repetition",
        "CustomShutdownWeekDaysChanged",
        "LowPowerActionChanged",
        "action",
        "SetMode",
        "mode",
        "CanSuspend",
        "CanHibernate",
        "login1ManagerCanSuspend",
        "login1ManagerCanHibernate",
        "ScreenBlackLock",
        "SleepLock",
        "LidIsPresent",
        "LidClosedSleep",
        "LowPowerNotifyEnable",
        "LowPowerAutoSleepThreshold",
        "LowPowerNotifyThreshold",
        "LinePowerPressPowerBtnAction",
        "LinePowerLidClosedAction",
        "BatteryPressPowerBtnAction",
        "BatteryLidClosedAction",
        "IsHighPerformanceSupported",
        "IsBalancePerformanceSupported",
        "LinePowerScreenBlackDelay",
        "LinePowerSleepDelay",
        "BatteryScreenBlackDelay",
        "BatterySleepDelay",
        "BatteryLockDelay",
        "LinePowerLockDelay",
        "HasBattery",
        "PowerSavingModeAutoWhenBatteryLow",
        "PowerSavingModeBrightnessDropPercent",
        "PowerSavingModeAutoBatteryPercent",
        "Mode",
        "PowerSavingModeAuto",
        "PowerSavingModeEnabled",
        "BatteryCapacity",
        "MaxBacklightBrightness",
        "NoPasswdLogin",
        "ScheduledShutdownState",
        "ShutdownTime",
        "ShutdownRepetition",
        "CustomShutdownWeekDays",
        "LowPowerAction"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ScreenBlackLockChanged'
        QtMocHelpers::SignalData<void(bool) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'SleepLockChanged'
        QtMocHelpers::SignalData<void(bool) const>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'LidIsPresentChanged'
        QtMocHelpers::SignalData<void(bool) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'LidClosedSleepChanged'
        QtMocHelpers::SignalData<void(bool) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'LinePowerScreenBlackDelayChanged'
        QtMocHelpers::SignalData<void(int) const>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'LinePowerSleepDelayChanged'
        QtMocHelpers::SignalData<void(int) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'BatteryScreenBlackDelayChanged'
        QtMocHelpers::SignalData<void(int) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'BatterySleepDelayChanged'
        QtMocHelpers::SignalData<void(int) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'BatteryLockDelayChanged'
        QtMocHelpers::SignalData<void(int) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'LinePowerLockDelayChanged'
        QtMocHelpers::SignalData<void(int) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'IsHighPerformanceSupportedChanged'
        QtMocHelpers::SignalData<void(bool) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'IsBalancePerformanceSupportedChanged'
        QtMocHelpers::SignalData<void(bool) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'LinePowerPressPowerBtnActionChanged'
        QtMocHelpers::SignalData<void(int) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'LinePowerLidClosedActionChanged'
        QtMocHelpers::SignalData<void(int) const>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'BatteryPressPowerBtnActionChanged'
        QtMocHelpers::SignalData<void(int) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'BatteryLidClosedActionChanged'
        QtMocHelpers::SignalData<void(int) const>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'LowPowerNotifyEnableChanged'
        QtMocHelpers::SignalData<void(bool) const>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'LowPowerNotifyThresholdChanged'
        QtMocHelpers::SignalData<void(int) const>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'LowPowerAutoSleepThresholdChanged'
        QtMocHelpers::SignalData<void(int) const>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'ShutdownTimeChanged'
        QtMocHelpers::SignalData<void(const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Signal 'PowerSavingModeAutoChanged'
        QtMocHelpers::SignalData<void(bool) const>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'PowerSavingModeEnabledChanged'
        QtMocHelpers::SignalData<void(bool) const>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'HasBatteryChanged'
        QtMocHelpers::SignalData<void(bool) const>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'BatteryPercentageChanged'
        QtMocHelpers::SignalData<void(double) const>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 3 },
        }}),
        // Signal 'PowerSavingModeAutoWhenBatteryLowChanged'
        QtMocHelpers::SignalData<void(bool) const>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'PowerSavingModeBrightnessDropPercentChanged'
        QtMocHelpers::SignalData<void(uint) const>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'PowerSavingModeAutoBatteryPercentChanged'
        QtMocHelpers::SignalData<void(uint) const>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'ModeChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'BatteryCapacityChanged'
        QtMocHelpers::SignalData<void(double) const>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 3 },
        }}),
        // Signal 'noPasswdLoginChanged'
        QtMocHelpers::SignalData<void(bool)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'ScheduledShutdownStateChanged'
        QtMocHelpers::SignalData<void(bool)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'ShutdownRepetitionChanged'
        QtMocHelpers::SignalData<void(int)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 36 },
        }}),
        // Signal 'CustomShutdownWeekDaysChanged'
        QtMocHelpers::SignalData<void(const QByteArray &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 3 },
        }}),
        // Signal 'LowPowerActionChanged'
        QtMocHelpers::SignalData<void(int)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 39 },
        }}),
        // Slot 'SetMode'
        QtMocHelpers::SlotData<void(const QString &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 41 },
        }}),
        // Slot 'CanSuspend'
        QtMocHelpers::SlotData<bool()>(42, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'CanHibernate'
        QtMocHelpers::SlotData<bool()>(43, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'login1ManagerCanSuspend'
        QtMocHelpers::SlotData<bool()>(44, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'login1ManagerCanHibernate'
        QtMocHelpers::SlotData<bool()>(45, 2, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'ScreenBlackLock'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'SleepLock'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'LidIsPresent'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'LidClosedSleep'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'LowPowerNotifyEnable'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'LowPowerAutoSleepThreshold'
        QtMocHelpers::PropertyData<int>(51, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'LowPowerNotifyThreshold'
        QtMocHelpers::PropertyData<int>(52, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'LinePowerPressPowerBtnAction'
        QtMocHelpers::PropertyData<int>(53, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'LinePowerLidClosedAction'
        QtMocHelpers::PropertyData<int>(54, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'BatteryPressPowerBtnAction'
        QtMocHelpers::PropertyData<int>(55, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'BatteryLidClosedAction'
        QtMocHelpers::PropertyData<int>(56, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'IsHighPerformanceSupported'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags, 10),
        // property 'IsBalancePerformanceSupported'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags, 11),
        // property 'LinePowerScreenBlackDelay'
        QtMocHelpers::PropertyData<int>(59, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'LinePowerSleepDelay'
        QtMocHelpers::PropertyData<int>(60, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'BatteryScreenBlackDelay'
        QtMocHelpers::PropertyData<int>(61, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'BatterySleepDelay'
        QtMocHelpers::PropertyData<int>(62, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'BatteryLockDelay'
        QtMocHelpers::PropertyData<int>(63, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'LinePowerLockDelay'
        QtMocHelpers::PropertyData<int>(64, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'HasBattery'
        QtMocHelpers::PropertyData<bool>(65, QMetaType::Bool, QMC::DefaultPropertyFlags, 22),
        // property 'PowerSavingModeAutoWhenBatteryLow'
        QtMocHelpers::PropertyData<bool>(66, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'PowerSavingModeBrightnessDropPercent'
        QtMocHelpers::PropertyData<uint>(67, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 25),
        // property 'PowerSavingModeAutoBatteryPercent'
        QtMocHelpers::PropertyData<uint>(68, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 26),
        // property 'Mode'
        QtMocHelpers::PropertyData<QString>(69, QMetaType::QString, QMC::DefaultPropertyFlags, 27),
        // property 'PowerSavingModeAuto'
        QtMocHelpers::PropertyData<bool>(70, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'PowerSavingModeEnabled'
        QtMocHelpers::PropertyData<bool>(71, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'BatteryCapacity'
        QtMocHelpers::PropertyData<double>(72, QMetaType::Double, QMC::DefaultPropertyFlags, 28),
        // property 'MaxBacklightBrightness'
        QtMocHelpers::PropertyData<int>(73, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'NoPasswdLogin'
        QtMocHelpers::PropertyData<bool>(74, QMetaType::Bool, QMC::DefaultPropertyFlags, 29),
        // property 'ScheduledShutdownState'
        QtMocHelpers::PropertyData<bool>(75, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 30),
        // property 'ShutdownTime'
        QtMocHelpers::PropertyData<QString>(76, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'ShutdownRepetition'
        QtMocHelpers::PropertyData<int>(77, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 31),
        // property 'CustomShutdownWeekDays'
        QtMocHelpers::PropertyData<QByteArray>(78, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 32),
        // property 'LowPowerAction'
        QtMocHelpers::PropertyData<int>(79, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 33),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PowerDBusProxy, qt_meta_tag_ZN14PowerDBusProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PowerDBusProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14PowerDBusProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14PowerDBusProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14PowerDBusProxyE_t>.metaTypes,
    nullptr
} };

void PowerDBusProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PowerDBusProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ScreenBlackLockChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->SleepLockChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->LidIsPresentChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->LidClosedSleepChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->LinePowerScreenBlackDelayChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->LinePowerSleepDelayChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->BatteryScreenBlackDelayChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->BatterySleepDelayChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->BatteryLockDelayChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->LinePowerLockDelayChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->IsHighPerformanceSupportedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->IsBalancePerformanceSupportedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->LinePowerPressPowerBtnActionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->LinePowerLidClosedActionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->BatteryPressPowerBtnActionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->BatteryLidClosedActionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->LowPowerNotifyEnableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->LowPowerNotifyThresholdChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->LowPowerAutoSleepThresholdChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->ShutdownTimeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->PowerSavingModeAutoChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->PowerSavingModeEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->HasBatteryChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->BatteryPercentageChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 24: _t->PowerSavingModeAutoWhenBatteryLowChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->PowerSavingModeBrightnessDropPercentChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 26: _t->PowerSavingModeAutoBatteryPercentChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 27: _t->ModeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->BatteryCapacityChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 29: _t->noPasswdLoginChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->ScheduledShutdownStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 31: _t->ShutdownRepetitionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 32: _t->CustomShutdownWeekDaysChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 33: _t->LowPowerActionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 34: _t->SetMode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 35: { bool _r = _t->CanSuspend();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 36: { bool _r = _t->CanHibernate();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 37: { bool _r = _t->login1ManagerCanSuspend();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 38: { bool _r = _t->login1ManagerCanHibernate();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(bool ) const>(_a, &PowerDBusProxy::ScreenBlackLockChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(bool ) const>(_a, &PowerDBusProxy::SleepLockChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(bool ) const>(_a, &PowerDBusProxy::LidIsPresentChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(bool ) const>(_a, &PowerDBusProxy::LidClosedSleepChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(int ) const>(_a, &PowerDBusProxy::LinePowerScreenBlackDelayChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(int ) const>(_a, &PowerDBusProxy::LinePowerSleepDelayChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(int ) const>(_a, &PowerDBusProxy::BatteryScreenBlackDelayChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(int ) const>(_a, &PowerDBusProxy::BatterySleepDelayChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(int ) const>(_a, &PowerDBusProxy::BatteryLockDelayChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(int ) const>(_a, &PowerDBusProxy::LinePowerLockDelayChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(bool ) const>(_a, &PowerDBusProxy::IsHighPerformanceSupportedChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(bool ) const>(_a, &PowerDBusProxy::IsBalancePerformanceSupportedChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(int ) const>(_a, &PowerDBusProxy::LinePowerPressPowerBtnActionChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(int ) const>(_a, &PowerDBusProxy::LinePowerLidClosedActionChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(int ) const>(_a, &PowerDBusProxy::BatteryPressPowerBtnActionChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(int ) const>(_a, &PowerDBusProxy::BatteryLidClosedActionChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(bool ) const>(_a, &PowerDBusProxy::LowPowerNotifyEnableChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(int ) const>(_a, &PowerDBusProxy::LowPowerNotifyThresholdChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(int ) const>(_a, &PowerDBusProxy::LowPowerAutoSleepThresholdChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(const QString & )>(_a, &PowerDBusProxy::ShutdownTimeChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(bool ) const>(_a, &PowerDBusProxy::PowerSavingModeAutoChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(bool ) const>(_a, &PowerDBusProxy::PowerSavingModeEnabledChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(bool ) const>(_a, &PowerDBusProxy::HasBatteryChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(double ) const>(_a, &PowerDBusProxy::BatteryPercentageChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(bool ) const>(_a, &PowerDBusProxy::PowerSavingModeAutoWhenBatteryLowChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(uint ) const>(_a, &PowerDBusProxy::PowerSavingModeBrightnessDropPercentChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(uint ) const>(_a, &PowerDBusProxy::PowerSavingModeAutoBatteryPercentChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(const QString & ) const>(_a, &PowerDBusProxy::ModeChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(double ) const>(_a, &PowerDBusProxy::BatteryCapacityChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(bool )>(_a, &PowerDBusProxy::noPasswdLoginChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(bool )>(_a, &PowerDBusProxy::ScheduledShutdownStateChanged, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(int )>(_a, &PowerDBusProxy::ShutdownRepetitionChanged, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(const QByteArray & )>(_a, &PowerDBusProxy::CustomShutdownWeekDaysChanged, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerDBusProxy::*)(int )>(_a, &PowerDBusProxy::LowPowerActionChanged, 33))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->screenBlackLock(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->sleepLock(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->lidIsPresent(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->lidClosedSleep(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->lowPowerNotifyEnable(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->lowPowerAutoSleepThreshold(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->lowPowerNotifyThreshold(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->linePowerPressPowerBtnAction(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->linePowerLidClosedAction(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->batteryPressPowerBtnAction(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->batteryLidClosedAction(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isHighPerformanceSupported(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->isBalancePerformanceSupported(); break;
        case 13: *reinterpret_cast<int*>(_v) = _t->linePowerScreenBlackDelay(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->linePowerSleepDelay(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->batteryScreenBlackDelay(); break;
        case 16: *reinterpret_cast<int*>(_v) = _t->batterySleepDelay(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->batteryLockDelay(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->linePowerLockDelay(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->hasBattery(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->powerSavingModeAutoWhenBatteryLow(); break;
        case 21: *reinterpret_cast<uint*>(_v) = _t->powerSavingModeBrightnessDropPercent(); break;
        case 22: *reinterpret_cast<uint*>(_v) = _t->powerSavingModeAutoBatteryPercent(); break;
        case 23: *reinterpret_cast<QString*>(_v) = _t->mode(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->powerSavingModeAuto(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->powerSavingModeEnabled(); break;
        case 26: *reinterpret_cast<double*>(_v) = _t->batteryCapacity(); break;
        case 27: *reinterpret_cast<int*>(_v) = _t->maxBacklightBrightness(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->noPasswdLogin(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->scheduledShutdownState(); break;
        case 30: *reinterpret_cast<QString*>(_v) = _t->shutdownTime(); break;
        case 31: *reinterpret_cast<int*>(_v) = _t->shutdownRepetition(); break;
        case 32: *reinterpret_cast<QByteArray*>(_v) = _t->customShutdownWeekDays(); break;
        case 33: *reinterpret_cast<int*>(_v) = _t->lowPowerAction(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setScreenBlackLock(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setSleepLock(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setLidClosedSleep(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setLowPowerNotifyEnable(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setLowPowerAutoSleepThreshold(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setLowPowerNotifyThreshold(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setLinePowerPressPowerBtnAction(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setLinePowerLidClosedAction(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setBatteryPressPowerBtnAction(*reinterpret_cast<int*>(_v)); break;
        case 10: _t->setBatteryLidClosedAction(*reinterpret_cast<int*>(_v)); break;
        case 13: _t->setLinePowerScreenBlackDelay(*reinterpret_cast<int*>(_v)); break;
        case 14: _t->setLinePowerSleepDelay(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setBatteryScreenBlackDelay(*reinterpret_cast<int*>(_v)); break;
        case 16: _t->setBatterySleepDelay(*reinterpret_cast<int*>(_v)); break;
        case 17: _t->setBatteryLockDelay(*reinterpret_cast<int*>(_v)); break;
        case 18: _t->setLinePowerLockDelay(*reinterpret_cast<int*>(_v)); break;
        case 20: _t->setPowerSavingModeAutoWhenBatteryLow(*reinterpret_cast<bool*>(_v)); break;
        case 21: _t->setPowerSavingModeBrightnessDropPercent(*reinterpret_cast<uint*>(_v)); break;
        case 22: _t->setPowerSavingModeAutoBatteryPercent(*reinterpret_cast<uint*>(_v)); break;
        case 24: _t->setPowerSavingModeAuto(*reinterpret_cast<bool*>(_v)); break;
        case 25: _t->setPowerSavingModeEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 29: _t->setScheduledShutdownState(*reinterpret_cast<bool*>(_v)); break;
        case 30: _t->setShutdownTime(*reinterpret_cast<QString*>(_v)); break;
        case 31: _t->setShutdownRepetition(*reinterpret_cast<int*>(_v)); break;
        case 32: _t->setCustomShutdownWeekDays(*reinterpret_cast<QByteArray*>(_v)); break;
        case 33: _t->setLowPowerAction(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PowerDBusProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PowerDBusProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14PowerDBusProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PowerDBusProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 39)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 39;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    return _id;
}

// SIGNAL 0
void PowerDBusProxy::ScreenBlackLockChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PowerDBusProxy::SleepLockChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PowerDBusProxy::LidIsPresentChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PowerDBusProxy::LidClosedSleepChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void PowerDBusProxy::LinePowerScreenBlackDelayChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void PowerDBusProxy::LinePowerSleepDelayChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void PowerDBusProxy::BatteryScreenBlackDelayChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void PowerDBusProxy::BatterySleepDelayChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void PowerDBusProxy::BatteryLockDelayChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void PowerDBusProxy::LinePowerLockDelayChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void PowerDBusProxy::IsHighPerformanceSupportedChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void PowerDBusProxy::IsBalancePerformanceSupportedChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void PowerDBusProxy::LinePowerPressPowerBtnActionChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void PowerDBusProxy::LinePowerLidClosedActionChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void PowerDBusProxy::BatteryPressPowerBtnActionChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void PowerDBusProxy::BatteryLidClosedActionChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void PowerDBusProxy::LowPowerNotifyEnableChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void PowerDBusProxy::LowPowerNotifyThresholdChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void PowerDBusProxy::LowPowerAutoSleepThresholdChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void PowerDBusProxy::ShutdownTimeChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void PowerDBusProxy::PowerSavingModeAutoChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void PowerDBusProxy::PowerSavingModeEnabledChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void PowerDBusProxy::HasBatteryChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void PowerDBusProxy::BatteryPercentageChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void PowerDBusProxy::PowerSavingModeAutoWhenBatteryLowChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void PowerDBusProxy::PowerSavingModeBrightnessDropPercentChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 25, nullptr, _t1);
}

// SIGNAL 26
void PowerDBusProxy::PowerSavingModeAutoBatteryPercentChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void PowerDBusProxy::ModeChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 27, nullptr, _t1);
}

// SIGNAL 28
void PowerDBusProxy::BatteryCapacityChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< PowerDBusProxy *>(this), &staticMetaObject, 28, nullptr, _t1);
}

// SIGNAL 29
void PowerDBusProxy::noPasswdLoginChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 29, nullptr, _t1);
}

// SIGNAL 30
void PowerDBusProxy::ScheduledShutdownStateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 30, nullptr, _t1);
}

// SIGNAL 31
void PowerDBusProxy::ShutdownRepetitionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 31, nullptr, _t1);
}

// SIGNAL 32
void PowerDBusProxy::CustomShutdownWeekDaysChanged(const QByteArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 32, nullptr, _t1);
}

// SIGNAL 33
void PowerDBusProxy::LowPowerActionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 33, nullptr, _t1);
}
QT_WARNING_POP
