/****************************************************************************
** Meta object code from reading C++ file 'displaydbusproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-display/operation/private/displaydbusproxy.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'displaydbusproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16DisplayDBusProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto DisplayDBusProxy::qt_create_metaobjectdata<qt_meta_tag_ZN16DisplayDBusProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DisplayDBusProxy",
        "BrightnessChanged",
        "",
        "BrightnessMap",
        "value",
        "ColorTemperatureEnabledChanged",
        "ColorTemperatureManualChanged",
        "ColorTemperatureModeChanged",
        "CustomColorTempTimePeriodChanged",
        "CurrentCustomIdChanged",
        "CustomIdListChanged",
        "DisplayModeChanged",
        "HasChangedChanged",
        "MaxBacklightBrightnessChanged",
        "MonitorsChanged",
        "QList<QDBusObjectPath>",
        "PrimaryChanged",
        "PrimaryRectChanged",
        "ScreenRect",
        "ScreenHeightChanged",
        "ScreenWidthChanged",
        "TouchMapChanged",
        "TouchscreenMap",
        "TouchscreensChanged",
        "TouchscreenInfoList",
        "TouchscreensV2Changed",
        "TouchscreenInfoList_V2",
        "AmbientLightAdjustBrightnessChanged",
        "HasAmbientLightSensorChanged",
        "WallpaperURlsChanged",
        "WorkspaceSwitched",
        "oldIndex",
        "newIndex",
        "ApplyChanges",
        "QDBusPendingReply<>",
        "AssociateTouch",
        "in0",
        "in1",
        "AssociateTouchByUUID",
        "ChangeBrightness",
        "DeleteCustomMode",
        "GetRealDisplayMode",
        "QDBusPendingReply<uchar>",
        "ListOutputNames",
        "QDBusPendingReply<QStringList>",
        "ListOutputsCommonModes",
        "QDBusPendingReply<ResolutionList>",
        "ModifyConfigName",
        "RefreshBrightness",
        "Reset",
        "ResetChanges",
        "Save",
        "SetAndSaveBrightness",
        "SetBrightness",
        "SetColorTemperature",
        "SetCustomColorTempTimePeriod",
        "SetMethodAdjustCCT",
        "SetPrimary",
        "SwitchMode",
        "CanSetBrightnessSync",
        "QDBusReply<bool>",
        "name",
        "SupportSetColorTemperatureSync",
        "GetScaleFactor",
        "QDBusPendingReply<double>",
        "GetScreenScaleFactors",
        "QDBusPendingReply<QMap<QString,double>>",
        "SetScaleFactor",
        "SetScreenScaleFactors",
        "QMap<QString,double>",
        "scaleFactors",
        "GetCurrentWorkspaceBackgroundForMonitor",
        "QDBusPendingReply<QString>",
        "strMonitorName",
        "GetConfig",
        "SetConfig",
        "cfgStr",
        "Brightness",
        "ColorTemperatureEnabled",
        "ColorTemperatureManual",
        "ColorTemperatureMode",
        "CustomColorTempTimePeriod",
        "CurrentCustomId",
        "CustomIdList",
        "DisplayMode",
        "HasChanged",
        "MaxBacklightBrightness",
        "Monitors",
        "Primary",
        "PrimaryRect",
        "ScreenHeight",
        "ScreenWidth",
        "TouchMap",
        "Touchscreens",
        "TouchscreensV2",
        "AmbientLightAdjustBrightness",
        "HasAmbientLightSensor",
        "WallpaperURls"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'BrightnessChanged'
        QtMocHelpers::SignalData<void(BrightnessMap) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'ColorTemperatureEnabledChanged'
        QtMocHelpers::SignalData<void(bool) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'ColorTemperatureManualChanged'
        QtMocHelpers::SignalData<void(int) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'ColorTemperatureModeChanged'
        QtMocHelpers::SignalData<void(int) const>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'CustomColorTempTimePeriodChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'CurrentCustomIdChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'CustomIdListChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 4 },
        }}),
        // Signal 'DisplayModeChanged'
        QtMocHelpers::SignalData<void(uchar) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UChar, 4 },
        }}),
        // Signal 'HasChangedChanged'
        QtMocHelpers::SignalData<void(bool) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'MaxBacklightBrightnessChanged'
        QtMocHelpers::SignalData<void(uint) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 4 },
        }}),
        // Signal 'MonitorsChanged'
        QtMocHelpers::SignalData<void(const QList<QDBusObjectPath> &) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 4 },
        }}),
        // Signal 'PrimaryChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'PrimaryRectChanged'
        QtMocHelpers::SignalData<void(ScreenRect) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 4 },
        }}),
        // Signal 'ScreenHeightChanged'
        QtMocHelpers::SignalData<void(ushort) const>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UShort, 4 },
        }}),
        // Signal 'ScreenWidthChanged'
        QtMocHelpers::SignalData<void(ushort) const>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UShort, 4 },
        }}),
        // Signal 'TouchMapChanged'
        QtMocHelpers::SignalData<void(TouchscreenMap) const>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 4 },
        }}),
        // Signal 'TouchscreensChanged'
        QtMocHelpers::SignalData<void(TouchscreenInfoList) const>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 4 },
        }}),
        // Signal 'TouchscreensV2Changed'
        QtMocHelpers::SignalData<void(TouchscreenInfoList_V2) const>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 4 },
        }}),
        // Signal 'AmbientLightAdjustBrightnessChanged'
        QtMocHelpers::SignalData<void(bool) const>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'HasAmbientLightSensorChanged'
        QtMocHelpers::SignalData<void(bool) const>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'WallpaperURlsChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'WorkspaceSwitched'
        QtMocHelpers::SignalData<void(int, int)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 31 }, { QMetaType::Int, 32 },
        }}),
        // Slot 'ApplyChanges'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(33, 2, QMC::AccessPublic, 0x80000000 | 34),
        // Slot 'AssociateTouch'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(35, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::QString, 36 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'AssociateTouchByUUID'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(38, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::QString, 36 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'ChangeBrightness'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(39, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::Bool, 36 },
        }}),
        // Slot 'DeleteCustomMode'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(40, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::QString, 36 },
        }}),
        // Slot 'GetRealDisplayMode'
        QtMocHelpers::SlotData<QDBusPendingReply<uchar>()>(41, 2, QMC::AccessPublic, 0x80000000 | 42),
        // Slot 'ListOutputNames'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(43, 2, QMC::AccessPublic, 0x80000000 | 44),
        // Slot 'ListOutputsCommonModes'
        QtMocHelpers::SlotData<QDBusPendingReply<ResolutionList>()>(45, 2, QMC::AccessPublic, 0x80000000 | 46),
        // Slot 'ModifyConfigName'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(47, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::QString, 36 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'RefreshBrightness'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(48, 2, QMC::AccessPublic, 0x80000000 | 34),
        // Slot 'Reset'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(49, 2, QMC::AccessPublic, 0x80000000 | 34),
        // Slot 'ResetChanges'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(50, 2, QMC::AccessPublic, 0x80000000 | 34),
        // Slot 'Save'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(51, 2, QMC::AccessPublic, 0x80000000 | 34),
        // Slot 'SetAndSaveBrightness'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, double)>(52, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::QString, 36 }, { QMetaType::Double, 37 },
        }}),
        // Slot 'SetBrightness'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, double)>(53, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::QString, 36 }, { QMetaType::Double, 37 },
        }}),
        // Slot 'SetColorTemperature'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(54, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::Int, 36 },
        }}),
        // Slot 'SetCustomColorTempTimePeriod'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(55, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::QString, 36 },
        }}),
        // Slot 'SetMethodAdjustCCT'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(56, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::Int, 36 },
        }}),
        // Slot 'SetPrimary'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(57, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::QString, 36 },
        }}),
        // Slot 'SwitchMode'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uchar, const QString &)>(58, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::UChar, 36 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'CanSetBrightnessSync'
        QtMocHelpers::SlotData<QDBusReply<bool>(const QString &)>(59, 2, QMC::AccessPublic, 0x80000000 | 60, {{
            { QMetaType::QString, 61 },
        }}),
        // Slot 'SupportSetColorTemperatureSync'
        QtMocHelpers::SlotData<QDBusReply<bool>()>(62, 2, QMC::AccessPublic, 0x80000000 | 60),
        // Slot 'GetScaleFactor'
        QtMocHelpers::SlotData<QDBusPendingReply<double>()>(63, 2, QMC::AccessPublic, 0x80000000 | 64),
        // Slot 'GetScreenScaleFactors'
        QtMocHelpers::SlotData<QDBusPendingReply<QMap<QString,double> >()>(65, 2, QMC::AccessPublic, 0x80000000 | 66),
        // Slot 'SetScaleFactor'
        QtMocHelpers::SlotData<QDBusPendingReply<>(double)>(67, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::Double, 36 },
        }}),
        // Slot 'SetScreenScaleFactors'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QMap<QString,double> &)>(68, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { 0x80000000 | 69, 70 },
        }}),
        // Slot 'GetCurrentWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(71, 2, QMC::AccessPublic, 0x80000000 | 72, {{
            { QMetaType::QString, 73 },
        }}),
        // Slot 'GetConfig'
        QtMocHelpers::SlotData<QString()>(74, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'SetConfig'
        QtMocHelpers::SlotData<void(QString)>(75, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 76 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Brightness'
        QtMocHelpers::PropertyData<BrightnessMap>(77, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'ColorTemperatureEnabled'
        QtMocHelpers::PropertyData<bool>(78, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 1),
        // property 'ColorTemperatureManual'
        QtMocHelpers::PropertyData<int>(79, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'ColorTemperatureMode'
        QtMocHelpers::PropertyData<int>(80, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
        // property 'CustomColorTempTimePeriod'
        QtMocHelpers::PropertyData<QString>(81, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 4),
        // property 'CurrentCustomId'
        QtMocHelpers::PropertyData<QString>(82, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'CustomIdList'
        QtMocHelpers::PropertyData<QStringList>(83, QMetaType::QStringList, QMC::DefaultPropertyFlags, 6),
        // property 'DisplayMode'
        QtMocHelpers::PropertyData<uchar>(84, QMetaType::UChar, QMC::DefaultPropertyFlags, 7),
        // property 'HasChanged'
        QtMocHelpers::PropertyData<bool>(85, QMetaType::Bool, QMC::DefaultPropertyFlags, 8),
        // property 'MaxBacklightBrightness'
        QtMocHelpers::PropertyData<uint>(86, QMetaType::UInt, QMC::DefaultPropertyFlags, 9),
        // property 'Monitors'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(87, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 10),
        // property 'Primary'
        QtMocHelpers::PropertyData<QString>(88, QMetaType::QString, QMC::DefaultPropertyFlags, 11),
        // property 'PrimaryRect'
        QtMocHelpers::PropertyData<ScreenRect>(89, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 12),
        // property 'ScreenHeight'
        QtMocHelpers::PropertyData<ushort>(90, QMetaType::UShort, QMC::DefaultPropertyFlags, 13),
        // property 'ScreenWidth'
        QtMocHelpers::PropertyData<ushort>(91, QMetaType::UShort, QMC::DefaultPropertyFlags, 14),
        // property 'TouchMap'
        QtMocHelpers::PropertyData<TouchscreenMap>(92, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 15),
        // property 'Touchscreens'
        QtMocHelpers::PropertyData<TouchscreenInfoList>(93, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 16),
        // property 'TouchscreensV2'
        QtMocHelpers::PropertyData<TouchscreenInfoList_V2>(94, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 17),
        // property 'AmbientLightAdjustBrightness'
        QtMocHelpers::PropertyData<bool>(95, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'HasAmbientLightSensor'
        QtMocHelpers::PropertyData<bool>(96, QMetaType::Bool, QMC::DefaultPropertyFlags, 19),
        // property 'WallpaperURls'
        QtMocHelpers::PropertyData<QString>(97, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 20),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DisplayDBusProxy, qt_meta_tag_ZN16DisplayDBusProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DisplayDBusProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DisplayDBusProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DisplayDBusProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16DisplayDBusProxyE_t>.metaTypes,
    nullptr
} };

void DisplayDBusProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DisplayDBusProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->BrightnessChanged((*reinterpret_cast<std::add_pointer_t<BrightnessMap>>(_a[1]))); break;
        case 1: _t->ColorTemperatureEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->ColorTemperatureManualChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->ColorTemperatureModeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->CustomColorTempTimePeriodChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->CurrentCustomIdChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->CustomIdListChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 7: _t->DisplayModeChanged((*reinterpret_cast<std::add_pointer_t<uchar>>(_a[1]))); break;
        case 8: _t->HasChangedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->MaxBacklightBrightnessChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 10: _t->MonitorsChanged((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1]))); break;
        case 11: _t->PrimaryChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->PrimaryRectChanged((*reinterpret_cast<std::add_pointer_t<ScreenRect>>(_a[1]))); break;
        case 13: _t->ScreenHeightChanged((*reinterpret_cast<std::add_pointer_t<ushort>>(_a[1]))); break;
        case 14: _t->ScreenWidthChanged((*reinterpret_cast<std::add_pointer_t<ushort>>(_a[1]))); break;
        case 15: _t->TouchMapChanged((*reinterpret_cast<std::add_pointer_t<TouchscreenMap>>(_a[1]))); break;
        case 16: _t->TouchscreensChanged((*reinterpret_cast<std::add_pointer_t<TouchscreenInfoList>>(_a[1]))); break;
        case 17: _t->TouchscreensV2Changed((*reinterpret_cast<std::add_pointer_t<TouchscreenInfoList_V2>>(_a[1]))); break;
        case 18: _t->AmbientLightAdjustBrightnessChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->HasAmbientLightSensorChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->WallpaperURlsChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->WorkspaceSwitched((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 22: { QDBusPendingReply<> _r = _t->ApplyChanges();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<> _r = _t->AssociateTouch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<> _r = _t->AssociateTouchByUUID((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<> _r = _t->ChangeBrightness((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 26: { QDBusPendingReply<> _r = _t->DeleteCustomMode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 27: { QDBusPendingReply<uchar> _r = _t->GetRealDisplayMode();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<uchar>*>(_a[0]) = std::move(_r); }  break;
        case 28: { QDBusPendingReply<QStringList> _r = _t->ListOutputNames();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 29: { QDBusPendingReply<ResolutionList> _r = _t->ListOutputsCommonModes();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<ResolutionList>*>(_a[0]) = std::move(_r); }  break;
        case 30: { QDBusPendingReply<> _r = _t->ModifyConfigName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 31: { QDBusPendingReply<> _r = _t->RefreshBrightness();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 32: { QDBusPendingReply<> _r = _t->Reset();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 33: { QDBusPendingReply<> _r = _t->ResetChanges();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 34: { QDBusPendingReply<> _r = _t->Save();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 35: { QDBusPendingReply<> _r = _t->SetAndSaveBrightness((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 36: { QDBusPendingReply<> _r = _t->SetBrightness((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 37: { QDBusPendingReply<> _r = _t->SetColorTemperature((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 38: { QDBusPendingReply<> _r = _t->SetCustomColorTempTimePeriod((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 39: { QDBusPendingReply<> _r = _t->SetMethodAdjustCCT((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 40: { QDBusPendingReply<> _r = _t->SetPrimary((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 41: { QDBusPendingReply<> _r = _t->SwitchMode((*reinterpret_cast<std::add_pointer_t<uchar>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 42: { QDBusReply<bool> _r = _t->CanSetBrightnessSync((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 43: { QDBusReply<bool> _r = _t->SupportSetColorTemperatureSync();
            if (_a[0]) *reinterpret_cast<QDBusReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 44: { QDBusPendingReply<double> _r = _t->GetScaleFactor();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<double>*>(_a[0]) = std::move(_r); }  break;
        case 45: { QDBusPendingReply<QMap<QString,double>> _r = _t->GetScreenScaleFactors();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QMap<QString,double>>*>(_a[0]) = std::move(_r); }  break;
        case 46: { QDBusPendingReply<> _r = _t->SetScaleFactor((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 47: { QDBusPendingReply<> _r = _t->SetScreenScaleFactors((*reinterpret_cast<std::add_pointer_t<QMap<QString,double>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 48: { QDBusPendingReply<QString> _r = _t->GetCurrentWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 49: { QString _r = _t->GetConfig();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 50: _t->SetConfig((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDBusObjectPath> >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ScreenRect >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TouchscreenInfoList >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TouchscreenInfoList_V2 >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DisplayDBusProxy::*)(BrightnessMap ) const>(_a, &DisplayDBusProxy::BrightnessChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayDBusProxy::*)(bool ) const>(_a, &DisplayDBusProxy::ColorTemperatureEnabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayDBusProxy::*)(int ) const>(_a, &DisplayDBusProxy::ColorTemperatureManualChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayDBusProxy::*)(int ) const>(_a, &DisplayDBusProxy::ColorTemperatureModeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayDBusProxy::*)(const QString & ) const>(_a, &DisplayDBusProxy::CustomColorTempTimePeriodChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayDBusProxy::*)(const QString & ) const>(_a, &DisplayDBusProxy::CurrentCustomIdChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayDBusProxy::*)(const QStringList & ) const>(_a, &DisplayDBusProxy::CustomIdListChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayDBusProxy::*)(uchar ) const>(_a, &DisplayDBusProxy::DisplayModeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayDBusProxy::*)(bool ) const>(_a, &DisplayDBusProxy::HasChangedChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayDBusProxy::*)(uint ) const>(_a, &DisplayDBusProxy::MaxBacklightBrightnessChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayDBusProxy::*)(const QList<QDBusObjectPath> & ) const>(_a, &DisplayDBusProxy::MonitorsChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayDBusProxy::*)(const QString & ) const>(_a, &DisplayDBusProxy::PrimaryChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayDBusProxy::*)(ScreenRect ) const>(_a, &DisplayDBusProxy::PrimaryRectChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayDBusProxy::*)(ushort ) const>(_a, &DisplayDBusProxy::ScreenHeightChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayDBusProxy::*)(ushort ) const>(_a, &DisplayDBusProxy::ScreenWidthChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayDBusProxy::*)(TouchscreenMap ) const>(_a, &DisplayDBusProxy::TouchMapChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayDBusProxy::*)(TouchscreenInfoList ) const>(_a, &DisplayDBusProxy::TouchscreensChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayDBusProxy::*)(TouchscreenInfoList_V2 ) const>(_a, &DisplayDBusProxy::TouchscreensV2Changed, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayDBusProxy::*)(bool ) const>(_a, &DisplayDBusProxy::AmbientLightAdjustBrightnessChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayDBusProxy::*)(bool ) const>(_a, &DisplayDBusProxy::HasAmbientLightSensorChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayDBusProxy::*)(const QString & ) const>(_a, &DisplayDBusProxy::WallpaperURlsChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayDBusProxy::*)(int , int )>(_a, &DisplayDBusProxy::WorkspaceSwitched, 21))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 10:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QDBusObjectPath> >(); break;
        case 12:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ScreenRect >(); break;
        case 16:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< TouchscreenInfoList >(); break;
        case 17:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< TouchscreenInfoList_V2 >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<BrightnessMap*>(_v) = _t->brightness(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->colorTemperatureEnabled(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->colorTemperatureManual(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->colorTemperatureMode(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->customColorTempTimePeriod(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->currentCustomId(); break;
        case 6: *reinterpret_cast<QStringList*>(_v) = _t->customIdList(); break;
        case 7: *reinterpret_cast<uchar*>(_v) = _t->displayMode(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->hasChanged(); break;
        case 9: *reinterpret_cast<uint*>(_v) = _t->maxBacklightBrightness(); break;
        case 10: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->monitors(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->primary(); break;
        case 12: *reinterpret_cast<ScreenRect*>(_v) = _t->primaryRect(); break;
        case 13: *reinterpret_cast<ushort*>(_v) = _t->screenHeight(); break;
        case 14: *reinterpret_cast<ushort*>(_v) = _t->screenWidth(); break;
        case 15: *reinterpret_cast<TouchscreenMap*>(_v) = _t->touchMap(); break;
        case 16: *reinterpret_cast<TouchscreenInfoList*>(_v) = _t->touchscreens(); break;
        case 17: *reinterpret_cast<TouchscreenInfoList_V2*>(_v) = _t->touchscreensV2(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->ambientLightAdjustBrightness(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->hasAmbientLightSensor(); break;
        case 20: *reinterpret_cast<QString*>(_v) = _t->wallpaperURls(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setColorTemperatureEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setAmbientLightAdjustBrightness(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DisplayDBusProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DisplayDBusProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DisplayDBusProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DisplayDBusProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 51)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 51;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 51)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 51;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void DisplayDBusProxy::BrightnessChanged(BrightnessMap _t1)const
{
    QMetaObject::activate<void>(const_cast< DisplayDBusProxy *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DisplayDBusProxy::ColorTemperatureEnabledChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< DisplayDBusProxy *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DisplayDBusProxy::ColorTemperatureManualChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< DisplayDBusProxy *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DisplayDBusProxy::ColorTemperatureModeChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< DisplayDBusProxy *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DisplayDBusProxy::CustomColorTempTimePeriodChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< DisplayDBusProxy *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DisplayDBusProxy::CurrentCustomIdChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< DisplayDBusProxy *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DisplayDBusProxy::CustomIdListChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< DisplayDBusProxy *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void DisplayDBusProxy::DisplayModeChanged(uchar _t1)const
{
    QMetaObject::activate<void>(const_cast< DisplayDBusProxy *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void DisplayDBusProxy::HasChangedChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< DisplayDBusProxy *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void DisplayDBusProxy::MaxBacklightBrightnessChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< DisplayDBusProxy *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void DisplayDBusProxy::MonitorsChanged(const QList<QDBusObjectPath> & _t1)const
{
    QMetaObject::activate<void>(const_cast< DisplayDBusProxy *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void DisplayDBusProxy::PrimaryChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< DisplayDBusProxy *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void DisplayDBusProxy::PrimaryRectChanged(ScreenRect _t1)const
{
    QMetaObject::activate<void>(const_cast< DisplayDBusProxy *>(this), &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void DisplayDBusProxy::ScreenHeightChanged(ushort _t1)const
{
    QMetaObject::activate<void>(const_cast< DisplayDBusProxy *>(this), &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void DisplayDBusProxy::ScreenWidthChanged(ushort _t1)const
{
    QMetaObject::activate<void>(const_cast< DisplayDBusProxy *>(this), &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void DisplayDBusProxy::TouchMapChanged(TouchscreenMap _t1)const
{
    QMetaObject::activate<void>(const_cast< DisplayDBusProxy *>(this), &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void DisplayDBusProxy::TouchscreensChanged(TouchscreenInfoList _t1)const
{
    QMetaObject::activate<void>(const_cast< DisplayDBusProxy *>(this), &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void DisplayDBusProxy::TouchscreensV2Changed(TouchscreenInfoList_V2 _t1)const
{
    QMetaObject::activate<void>(const_cast< DisplayDBusProxy *>(this), &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void DisplayDBusProxy::AmbientLightAdjustBrightnessChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< DisplayDBusProxy *>(this), &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void DisplayDBusProxy::HasAmbientLightSensorChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< DisplayDBusProxy *>(this), &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void DisplayDBusProxy::WallpaperURlsChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< DisplayDBusProxy *>(this), &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void DisplayDBusProxy::WorkspaceSwitched(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1, _t2);
}
QT_WARNING_POP
