/****************************************************************************
** Meta object code from reading C++ file 'dccquickdbusinterface_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/dde-control-center/frame/dccquickdbusinterface_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dccquickdbusinterface_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6dccV2520DccQuickDBusCallbackE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::DccQuickDBusCallback::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV2520DccQuickDBusCallbackE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::DccQuickDBusCallback",
        "returnMethod",
        "",
        "QDBusMessage",
        "msg",
        "errorMethod",
        "QDBusError",
        "error"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'returnMethod'
        QtMocHelpers::SlotData<void(const QDBusMessage &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'errorMethod'
        QtMocHelpers::SlotData<void(const QDBusError &, const QDBusMessage &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DccQuickDBusCallback, qt_meta_tag_ZN6dccV2520DccQuickDBusCallbackE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dccV25::DccQuickDBusCallback::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2520DccQuickDBusCallbackE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2520DccQuickDBusCallbackE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV2520DccQuickDBusCallbackE_t>.metaTypes,
    nullptr
} };

void dccV25::DccQuickDBusCallback::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DccQuickDBusCallback *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->returnMethod((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        case 1: _t->errorMethod((*reinterpret_cast<std::add_pointer_t<QDBusError>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *dccV25::DccQuickDBusCallback::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::DccQuickDBusCallback::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2520DccQuickDBusCallbackE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dccV25::DccQuickDBusCallback::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN6dccV2521DccDBusSignalCallbackE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::DccDBusSignalCallback::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV2521DccDBusSignalCallbackE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::DccDBusSignalCallback",
        "returnMethod",
        "",
        "QDBusMessage",
        "msg"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'returnMethod'
        QtMocHelpers::SlotData<void(const QDBusMessage &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DccDBusSignalCallback, qt_meta_tag_ZN6dccV2521DccDBusSignalCallbackE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dccV25::DccDBusSignalCallback::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2521DccDBusSignalCallbackE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2521DccDBusSignalCallbackE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV2521DccDBusSignalCallbackE_t>.metaTypes,
    nullptr
} };

void dccV25::DccDBusSignalCallback::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DccDBusSignalCallback *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->returnMethod((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *dccV25::DccDBusSignalCallback::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::DccDBusSignalCallback::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2521DccDBusSignalCallbackE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dccV25::DccDBusSignalCallback::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN6dccV2521DccQuickDBusInterface7PrivateE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::DccQuickDBusInterface::Private::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV2521DccQuickDBusInterface7PrivateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::DccQuickDBusInterface::Private",
        "onAllProperties",
        "",
        "QVariantMap",
        "changedProperties",
        "onGetPropertiesErr",
        "QDBusError",
        "e",
        "onPropertiesChanged",
        "interfaceName",
        "invalidatedProperties",
        "getProperty",
        "QVariant",
        "propname",
        "setProperty",
        "value",
        "onPropertySpy",
        "const char*"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onAllProperties'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'onGetPropertiesErr'
        QtMocHelpers::SlotData<void(const QDBusError &)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'onPropertiesChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &, const QStringList &)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { 0x80000000 | 3, 4 }, { QMetaType::QStringList, 10 },
        }}),
        // Slot 'getProperty'
        QtMocHelpers::SlotData<QVariant(const QString &)>(11, 2, QMC::AccessPrivate, 0x80000000 | 12, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'setProperty'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { 0x80000000 | 12, 15 },
        }}),
        // Slot 'onPropertySpy'
        QtMocHelpers::SlotData<void(const char *, const QVariant &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 13 }, { 0x80000000 | 12, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Private, qt_meta_tag_ZN6dccV2521DccQuickDBusInterface7PrivateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dccV25::DccQuickDBusInterface::Private::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2521DccQuickDBusInterface7PrivateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2521DccQuickDBusInterface7PrivateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV2521DccQuickDBusInterface7PrivateE_t>.metaTypes,
    nullptr
} };

void dccV25::DccQuickDBusInterface::Private::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Private *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onAllProperties((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 1: _t->onGetPropertiesErr((*reinterpret_cast<std::add_pointer_t<QDBusError>>(_a[1]))); break;
        case 2: _t->onPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 3: { QVariant _r = _t->getProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->setProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 5: _t->onPropertySpy((*reinterpret_cast<std::add_pointer_t<const char*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *dccV25::DccQuickDBusInterface::Private::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::DccQuickDBusInterface::Private::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2521DccQuickDBusInterface7PrivateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dccV25::DccQuickDBusInterface::Private::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
