// This file was generated by qtwaylandscanner
// source file is treeland-personalization-manager-v1.xml

#include "qwayland-treeland-personalization-manager-v1.h"

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {

static inline void *wlRegistryBind(struct ::wl_registry *registry, uint32_t name, const struct ::wl_interface *interface, uint32_t version)
{
    const uint32_t bindOpCode = 0;
    return (void *) wl_proxy_marshal_constructor_versioned((struct wl_proxy *) registry,
    bindOpCode, interface, version, name, interface->name, version, nullptr);
}

    treeland_personalization_manager_v1::treeland_personalization_manager_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    treeland_personalization_manager_v1::treeland_personalization_manager_v1(struct ::treeland_personalization_manager_v1 *obj)
        : m_treeland_personalization_manager_v1(obj)
    {
    }

    treeland_personalization_manager_v1::treeland_personalization_manager_v1()
        : m_treeland_personalization_manager_v1(nullptr)
    {
    }

    treeland_personalization_manager_v1::~treeland_personalization_manager_v1()
    {
    }

    void treeland_personalization_manager_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_treeland_personalization_manager_v1 = static_cast<struct ::treeland_personalization_manager_v1 *>(wlRegistryBind(registry, id, &treeland_personalization_manager_v1_interface, version));
    }

    void treeland_personalization_manager_v1::init(struct ::treeland_personalization_manager_v1 *obj)
    {
        m_treeland_personalization_manager_v1 = obj;
    }

    treeland_personalization_manager_v1 *treeland_personalization_manager_v1::fromObject(struct ::treeland_personalization_manager_v1 *object)
    {
        return static_cast<treeland_personalization_manager_v1 *>(treeland_personalization_manager_v1_get_user_data(object));
    }

    bool treeland_personalization_manager_v1::isInitialized() const
    {
        return m_treeland_personalization_manager_v1 != nullptr;
    }

    uint32_t treeland_personalization_manager_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_treeland_personalization_manager_v1));
    }

    const struct wl_interface *treeland_personalization_manager_v1::interface()
    {
        return &::treeland_personalization_manager_v1_interface;
    }

    struct ::treeland_personalization_window_context_v1 *treeland_personalization_manager_v1::get_window_context(struct ::wl_surface *surface)
    {
        struct ::treeland_personalization_window_context_v1 * id = ::treeland_personalization_manager_v1_get_window_context(
            m_treeland_personalization_manager_v1,
            surface);
        return id;
    }

    struct ::treeland_personalization_wallpaper_context_v1 *treeland_personalization_manager_v1::get_wallpaper_context()
    {
        struct ::treeland_personalization_wallpaper_context_v1 * id = ::treeland_personalization_manager_v1_get_wallpaper_context(
            m_treeland_personalization_manager_v1);
        return id;
    }

    struct ::treeland_personalization_cursor_context_v1 *treeland_personalization_manager_v1::get_cursor_context()
    {
        struct ::treeland_personalization_cursor_context_v1 * id = ::treeland_personalization_manager_v1_get_cursor_context(
            m_treeland_personalization_manager_v1);
        return id;
    }

    struct ::treeland_personalization_font_context_v1 *treeland_personalization_manager_v1::get_font_context()
    {
        struct ::treeland_personalization_font_context_v1 * id = ::treeland_personalization_manager_v1_get_font_context(
            m_treeland_personalization_manager_v1);
        return id;
    }

    struct ::treeland_personalization_appearance_context_v1 *treeland_personalization_manager_v1::get_appearance_context()
    {
        struct ::treeland_personalization_appearance_context_v1 * id = ::treeland_personalization_manager_v1_get_appearance_context(
            m_treeland_personalization_manager_v1);
        return id;
    }

    treeland_personalization_wallpaper_context_v1::treeland_personalization_wallpaper_context_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    treeland_personalization_wallpaper_context_v1::treeland_personalization_wallpaper_context_v1(struct ::treeland_personalization_wallpaper_context_v1 *obj)
        : m_treeland_personalization_wallpaper_context_v1(obj)
    {
        init_listener();
    }

    treeland_personalization_wallpaper_context_v1::treeland_personalization_wallpaper_context_v1()
        : m_treeland_personalization_wallpaper_context_v1(nullptr)
    {
    }

    treeland_personalization_wallpaper_context_v1::~treeland_personalization_wallpaper_context_v1()
    {
    }

    void treeland_personalization_wallpaper_context_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_treeland_personalization_wallpaper_context_v1 = static_cast<struct ::treeland_personalization_wallpaper_context_v1 *>(wlRegistryBind(registry, id, &treeland_personalization_wallpaper_context_v1_interface, version));
        init_listener();
    }

    void treeland_personalization_wallpaper_context_v1::init(struct ::treeland_personalization_wallpaper_context_v1 *obj)
    {
        m_treeland_personalization_wallpaper_context_v1 = obj;
        init_listener();
    }

    treeland_personalization_wallpaper_context_v1 *treeland_personalization_wallpaper_context_v1::fromObject(struct ::treeland_personalization_wallpaper_context_v1 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_treeland_personalization_wallpaper_context_v1_listener)
            return nullptr;
        return static_cast<treeland_personalization_wallpaper_context_v1 *>(treeland_personalization_wallpaper_context_v1_get_user_data(object));
    }

    bool treeland_personalization_wallpaper_context_v1::isInitialized() const
    {
        return m_treeland_personalization_wallpaper_context_v1 != nullptr;
    }

    uint32_t treeland_personalization_wallpaper_context_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_treeland_personalization_wallpaper_context_v1));
    }

    const struct wl_interface *treeland_personalization_wallpaper_context_v1::interface()
    {
        return &::treeland_personalization_wallpaper_context_v1_interface;
    }

    void treeland_personalization_wallpaper_context_v1::set_fd(int32_t fd, const QString &metadata)
    {
        ::treeland_personalization_wallpaper_context_v1_set_fd(
            m_treeland_personalization_wallpaper_context_v1,
            fd,
            metadata.toUtf8().constData());
    }

    void treeland_personalization_wallpaper_context_v1::set_identifier(const QString &identifier)
    {
        ::treeland_personalization_wallpaper_context_v1_set_identifier(
            m_treeland_personalization_wallpaper_context_v1,
            identifier.toUtf8().constData());
    }

    void treeland_personalization_wallpaper_context_v1::set_output(const QString &output)
    {
        ::treeland_personalization_wallpaper_context_v1_set_output(
            m_treeland_personalization_wallpaper_context_v1,
            output.toUtf8().constData());
    }

    void treeland_personalization_wallpaper_context_v1::set_on(uint32_t options)
    {
        ::treeland_personalization_wallpaper_context_v1_set_on(
            m_treeland_personalization_wallpaper_context_v1,
            options);
    }

    void treeland_personalization_wallpaper_context_v1::set_isdark(uint32_t isdark)
    {
        ::treeland_personalization_wallpaper_context_v1_set_isdark(
            m_treeland_personalization_wallpaper_context_v1,
            isdark);
    }

    void treeland_personalization_wallpaper_context_v1::commit()
    {
        ::treeland_personalization_wallpaper_context_v1_commit(
            m_treeland_personalization_wallpaper_context_v1);
    }

    void treeland_personalization_wallpaper_context_v1::get_metadata()
    {
        ::treeland_personalization_wallpaper_context_v1_get_metadata(
            m_treeland_personalization_wallpaper_context_v1);
    }

    void treeland_personalization_wallpaper_context_v1::destroy()
    {
        ::treeland_personalization_wallpaper_context_v1_destroy(
            m_treeland_personalization_wallpaper_context_v1);
        m_treeland_personalization_wallpaper_context_v1 = nullptr;
    }

    void treeland_personalization_wallpaper_context_v1::treeland_personalization_wallpaper_context_v1_metadata(const QString &)
    {
    }

    void treeland_personalization_wallpaper_context_v1::handle_metadata(
        void *data,
        struct ::treeland_personalization_wallpaper_context_v1 *object,
        const char *metadata)
    {
        Q_UNUSED(object);
        static_cast<treeland_personalization_wallpaper_context_v1 *>(data)->treeland_personalization_wallpaper_context_v1_metadata(
            QString::fromUtf8(metadata));
    }

    const struct treeland_personalization_wallpaper_context_v1_listener treeland_personalization_wallpaper_context_v1::m_treeland_personalization_wallpaper_context_v1_listener = {
        treeland_personalization_wallpaper_context_v1::handle_metadata,
    };

    void treeland_personalization_wallpaper_context_v1::init_listener()
    {
        treeland_personalization_wallpaper_context_v1_add_listener(m_treeland_personalization_wallpaper_context_v1, &m_treeland_personalization_wallpaper_context_v1_listener, this);
    }

    treeland_personalization_cursor_context_v1::treeland_personalization_cursor_context_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    treeland_personalization_cursor_context_v1::treeland_personalization_cursor_context_v1(struct ::treeland_personalization_cursor_context_v1 *obj)
        : m_treeland_personalization_cursor_context_v1(obj)
    {
        init_listener();
    }

    treeland_personalization_cursor_context_v1::treeland_personalization_cursor_context_v1()
        : m_treeland_personalization_cursor_context_v1(nullptr)
    {
    }

    treeland_personalization_cursor_context_v1::~treeland_personalization_cursor_context_v1()
    {
    }

    void treeland_personalization_cursor_context_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_treeland_personalization_cursor_context_v1 = static_cast<struct ::treeland_personalization_cursor_context_v1 *>(wlRegistryBind(registry, id, &treeland_personalization_cursor_context_v1_interface, version));
        init_listener();
    }

    void treeland_personalization_cursor_context_v1::init(struct ::treeland_personalization_cursor_context_v1 *obj)
    {
        m_treeland_personalization_cursor_context_v1 = obj;
        init_listener();
    }

    treeland_personalization_cursor_context_v1 *treeland_personalization_cursor_context_v1::fromObject(struct ::treeland_personalization_cursor_context_v1 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_treeland_personalization_cursor_context_v1_listener)
            return nullptr;
        return static_cast<treeland_personalization_cursor_context_v1 *>(treeland_personalization_cursor_context_v1_get_user_data(object));
    }

    bool treeland_personalization_cursor_context_v1::isInitialized() const
    {
        return m_treeland_personalization_cursor_context_v1 != nullptr;
    }

    uint32_t treeland_personalization_cursor_context_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_treeland_personalization_cursor_context_v1));
    }

    const struct wl_interface *treeland_personalization_cursor_context_v1::interface()
    {
        return &::treeland_personalization_cursor_context_v1_interface;
    }

    void treeland_personalization_cursor_context_v1::set_theme(const QString &name)
    {
        ::treeland_personalization_cursor_context_v1_set_theme(
            m_treeland_personalization_cursor_context_v1,
            name.toUtf8().constData());
    }

    void treeland_personalization_cursor_context_v1::get_theme()
    {
        ::treeland_personalization_cursor_context_v1_get_theme(
            m_treeland_personalization_cursor_context_v1);
    }

    void treeland_personalization_cursor_context_v1::set_size(uint32_t size)
    {
        ::treeland_personalization_cursor_context_v1_set_size(
            m_treeland_personalization_cursor_context_v1,
            size);
    }

    void treeland_personalization_cursor_context_v1::get_size()
    {
        ::treeland_personalization_cursor_context_v1_get_size(
            m_treeland_personalization_cursor_context_v1);
    }

    void treeland_personalization_cursor_context_v1::commit()
    {
        ::treeland_personalization_cursor_context_v1_commit(
            m_treeland_personalization_cursor_context_v1);
    }

    void treeland_personalization_cursor_context_v1::destroy()
    {
        ::treeland_personalization_cursor_context_v1_destroy(
            m_treeland_personalization_cursor_context_v1);
        m_treeland_personalization_cursor_context_v1 = nullptr;
    }

    void treeland_personalization_cursor_context_v1::treeland_personalization_cursor_context_v1_verfity(int32_t )
    {
    }

    void treeland_personalization_cursor_context_v1::handle_verfity(
        void *data,
        struct ::treeland_personalization_cursor_context_v1 *object,
        int32_t success)
    {
        Q_UNUSED(object);
        static_cast<treeland_personalization_cursor_context_v1 *>(data)->treeland_personalization_cursor_context_v1_verfity(
            success);
    }

    void treeland_personalization_cursor_context_v1::treeland_personalization_cursor_context_v1_theme(const QString &)
    {
    }

    void treeland_personalization_cursor_context_v1::handle_theme(
        void *data,
        struct ::treeland_personalization_cursor_context_v1 *object,
        const char *name)
    {
        Q_UNUSED(object);
        static_cast<treeland_personalization_cursor_context_v1 *>(data)->treeland_personalization_cursor_context_v1_theme(
            QString::fromUtf8(name));
    }

    void treeland_personalization_cursor_context_v1::treeland_personalization_cursor_context_v1_size(uint32_t )
    {
    }

    void treeland_personalization_cursor_context_v1::handle_size(
        void *data,
        struct ::treeland_personalization_cursor_context_v1 *object,
        uint32_t size)
    {
        Q_UNUSED(object);
        static_cast<treeland_personalization_cursor_context_v1 *>(data)->treeland_personalization_cursor_context_v1_size(
            size);
    }

    const struct treeland_personalization_cursor_context_v1_listener treeland_personalization_cursor_context_v1::m_treeland_personalization_cursor_context_v1_listener = {
        treeland_personalization_cursor_context_v1::handle_verfity,
        treeland_personalization_cursor_context_v1::handle_theme,
        treeland_personalization_cursor_context_v1::handle_size,
    };

    void treeland_personalization_cursor_context_v1::init_listener()
    {
        treeland_personalization_cursor_context_v1_add_listener(m_treeland_personalization_cursor_context_v1, &m_treeland_personalization_cursor_context_v1_listener, this);
    }

    treeland_personalization_window_context_v1::treeland_personalization_window_context_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    treeland_personalization_window_context_v1::treeland_personalization_window_context_v1(struct ::treeland_personalization_window_context_v1 *obj)
        : m_treeland_personalization_window_context_v1(obj)
    {
    }

    treeland_personalization_window_context_v1::treeland_personalization_window_context_v1()
        : m_treeland_personalization_window_context_v1(nullptr)
    {
    }

    treeland_personalization_window_context_v1::~treeland_personalization_window_context_v1()
    {
    }

    void treeland_personalization_window_context_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_treeland_personalization_window_context_v1 = static_cast<struct ::treeland_personalization_window_context_v1 *>(wlRegistryBind(registry, id, &treeland_personalization_window_context_v1_interface, version));
    }

    void treeland_personalization_window_context_v1::init(struct ::treeland_personalization_window_context_v1 *obj)
    {
        m_treeland_personalization_window_context_v1 = obj;
    }

    treeland_personalization_window_context_v1 *treeland_personalization_window_context_v1::fromObject(struct ::treeland_personalization_window_context_v1 *object)
    {
        return static_cast<treeland_personalization_window_context_v1 *>(treeland_personalization_window_context_v1_get_user_data(object));
    }

    bool treeland_personalization_window_context_v1::isInitialized() const
    {
        return m_treeland_personalization_window_context_v1 != nullptr;
    }

    uint32_t treeland_personalization_window_context_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_treeland_personalization_window_context_v1));
    }

    const struct wl_interface *treeland_personalization_window_context_v1::interface()
    {
        return &::treeland_personalization_window_context_v1_interface;
    }

    void treeland_personalization_window_context_v1::set_blend_mode(int32_t mode)
    {
        ::treeland_personalization_window_context_v1_set_blend_mode(
            m_treeland_personalization_window_context_v1,
            mode);
    }

    void treeland_personalization_window_context_v1::set_round_corner_radius(int32_t radius)
    {
        ::treeland_personalization_window_context_v1_set_round_corner_radius(
            m_treeland_personalization_window_context_v1,
            radius);
    }

    void treeland_personalization_window_context_v1::set_shadow(int32_t radius, int32_t offset_x, int32_t offset_y, int32_t r, int32_t g, int32_t b, int32_t a)
    {
        ::treeland_personalization_window_context_v1_set_shadow(
            m_treeland_personalization_window_context_v1,
            radius,
            offset_x,
            offset_y,
            r,
            g,
            b,
            a);
    }

    void treeland_personalization_window_context_v1::set_border(int32_t width, int32_t r, int32_t g, int32_t b, int32_t a)
    {
        ::treeland_personalization_window_context_v1_set_border(
            m_treeland_personalization_window_context_v1,
            width,
            r,
            g,
            b,
            a);
    }

    void treeland_personalization_window_context_v1::set_titlebar(int32_t mode)
    {
        ::treeland_personalization_window_context_v1_set_titlebar(
            m_treeland_personalization_window_context_v1,
            mode);
    }

    void treeland_personalization_window_context_v1::destroy()
    {
        ::treeland_personalization_window_context_v1_destroy(
            m_treeland_personalization_window_context_v1);
        m_treeland_personalization_window_context_v1 = nullptr;
    }

    treeland_personalization_font_context_v1::treeland_personalization_font_context_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    treeland_personalization_font_context_v1::treeland_personalization_font_context_v1(struct ::treeland_personalization_font_context_v1 *obj)
        : m_treeland_personalization_font_context_v1(obj)
    {
        init_listener();
    }

    treeland_personalization_font_context_v1::treeland_personalization_font_context_v1()
        : m_treeland_personalization_font_context_v1(nullptr)
    {
    }

    treeland_personalization_font_context_v1::~treeland_personalization_font_context_v1()
    {
    }

    void treeland_personalization_font_context_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_treeland_personalization_font_context_v1 = static_cast<struct ::treeland_personalization_font_context_v1 *>(wlRegistryBind(registry, id, &treeland_personalization_font_context_v1_interface, version));
        init_listener();
    }

    void treeland_personalization_font_context_v1::init(struct ::treeland_personalization_font_context_v1 *obj)
    {
        m_treeland_personalization_font_context_v1 = obj;
        init_listener();
    }

    treeland_personalization_font_context_v1 *treeland_personalization_font_context_v1::fromObject(struct ::treeland_personalization_font_context_v1 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_treeland_personalization_font_context_v1_listener)
            return nullptr;
        return static_cast<treeland_personalization_font_context_v1 *>(treeland_personalization_font_context_v1_get_user_data(object));
    }

    bool treeland_personalization_font_context_v1::isInitialized() const
    {
        return m_treeland_personalization_font_context_v1 != nullptr;
    }

    uint32_t treeland_personalization_font_context_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_treeland_personalization_font_context_v1));
    }

    const struct wl_interface *treeland_personalization_font_context_v1::interface()
    {
        return &::treeland_personalization_font_context_v1_interface;
    }

    void treeland_personalization_font_context_v1::set_font_size(uint32_t size)
    {
        ::treeland_personalization_font_context_v1_set_font_size(
            m_treeland_personalization_font_context_v1,
            size);
    }

    void treeland_personalization_font_context_v1::get_font_size()
    {
        ::treeland_personalization_font_context_v1_get_font_size(
            m_treeland_personalization_font_context_v1);
    }

    void treeland_personalization_font_context_v1::set_font(const QString &font_name)
    {
        ::treeland_personalization_font_context_v1_set_font(
            m_treeland_personalization_font_context_v1,
            font_name.toUtf8().constData());
    }

    void treeland_personalization_font_context_v1::get_font()
    {
        ::treeland_personalization_font_context_v1_get_font(
            m_treeland_personalization_font_context_v1);
    }

    void treeland_personalization_font_context_v1::set_monospace_font(const QString &font_name)
    {
        ::treeland_personalization_font_context_v1_set_monospace_font(
            m_treeland_personalization_font_context_v1,
            font_name.toUtf8().constData());
    }

    void treeland_personalization_font_context_v1::get_monospace_font()
    {
        ::treeland_personalization_font_context_v1_get_monospace_font(
            m_treeland_personalization_font_context_v1);
    }

    void treeland_personalization_font_context_v1::destroy()
    {
        ::treeland_personalization_font_context_v1_destroy(
            m_treeland_personalization_font_context_v1);
        m_treeland_personalization_font_context_v1 = nullptr;
    }

    void treeland_personalization_font_context_v1::treeland_personalization_font_context_v1_font(const QString &)
    {
    }

    void treeland_personalization_font_context_v1::handle_font(
        void *data,
        struct ::treeland_personalization_font_context_v1 *object,
        const char *font_name)
    {
        Q_UNUSED(object);
        static_cast<treeland_personalization_font_context_v1 *>(data)->treeland_personalization_font_context_v1_font(
            QString::fromUtf8(font_name));
    }

    void treeland_personalization_font_context_v1::treeland_personalization_font_context_v1_monospace_font(const QString &)
    {
    }

    void treeland_personalization_font_context_v1::handle_monospace_font(
        void *data,
        struct ::treeland_personalization_font_context_v1 *object,
        const char *font_name)
    {
        Q_UNUSED(object);
        static_cast<treeland_personalization_font_context_v1 *>(data)->treeland_personalization_font_context_v1_monospace_font(
            QString::fromUtf8(font_name));
    }

    void treeland_personalization_font_context_v1::treeland_personalization_font_context_v1_font_size(uint32_t )
    {
    }

    void treeland_personalization_font_context_v1::handle_font_size(
        void *data,
        struct ::treeland_personalization_font_context_v1 *object,
        uint32_t font_size)
    {
        Q_UNUSED(object);
        static_cast<treeland_personalization_font_context_v1 *>(data)->treeland_personalization_font_context_v1_font_size(
            font_size);
    }

    const struct treeland_personalization_font_context_v1_listener treeland_personalization_font_context_v1::m_treeland_personalization_font_context_v1_listener = {
        treeland_personalization_font_context_v1::handle_font,
        treeland_personalization_font_context_v1::handle_monospace_font,
        treeland_personalization_font_context_v1::handle_font_size,
    };

    void treeland_personalization_font_context_v1::init_listener()
    {
        treeland_personalization_font_context_v1_add_listener(m_treeland_personalization_font_context_v1, &m_treeland_personalization_font_context_v1_listener, this);
    }

    treeland_personalization_appearance_context_v1::treeland_personalization_appearance_context_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    treeland_personalization_appearance_context_v1::treeland_personalization_appearance_context_v1(struct ::treeland_personalization_appearance_context_v1 *obj)
        : m_treeland_personalization_appearance_context_v1(obj)
    {
        init_listener();
    }

    treeland_personalization_appearance_context_v1::treeland_personalization_appearance_context_v1()
        : m_treeland_personalization_appearance_context_v1(nullptr)
    {
    }

    treeland_personalization_appearance_context_v1::~treeland_personalization_appearance_context_v1()
    {
    }

    void treeland_personalization_appearance_context_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_treeland_personalization_appearance_context_v1 = static_cast<struct ::treeland_personalization_appearance_context_v1 *>(wlRegistryBind(registry, id, &treeland_personalization_appearance_context_v1_interface, version));
        init_listener();
    }

    void treeland_personalization_appearance_context_v1::init(struct ::treeland_personalization_appearance_context_v1 *obj)
    {
        m_treeland_personalization_appearance_context_v1 = obj;
        init_listener();
    }

    treeland_personalization_appearance_context_v1 *treeland_personalization_appearance_context_v1::fromObject(struct ::treeland_personalization_appearance_context_v1 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_treeland_personalization_appearance_context_v1_listener)
            return nullptr;
        return static_cast<treeland_personalization_appearance_context_v1 *>(treeland_personalization_appearance_context_v1_get_user_data(object));
    }

    bool treeland_personalization_appearance_context_v1::isInitialized() const
    {
        return m_treeland_personalization_appearance_context_v1 != nullptr;
    }

    uint32_t treeland_personalization_appearance_context_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_treeland_personalization_appearance_context_v1));
    }

    const struct wl_interface *treeland_personalization_appearance_context_v1::interface()
    {
        return &::treeland_personalization_appearance_context_v1_interface;
    }

    void treeland_personalization_appearance_context_v1::set_round_corner_radius(int32_t radius)
    {
        ::treeland_personalization_appearance_context_v1_set_round_corner_radius(
            m_treeland_personalization_appearance_context_v1,
            radius);
    }

    void treeland_personalization_appearance_context_v1::get_round_corner_radius()
    {
        ::treeland_personalization_appearance_context_v1_get_round_corner_radius(
            m_treeland_personalization_appearance_context_v1);
    }

    void treeland_personalization_appearance_context_v1::set_icon_theme(const QString &theme)
    {
        ::treeland_personalization_appearance_context_v1_set_icon_theme(
            m_treeland_personalization_appearance_context_v1,
            theme.toUtf8().constData());
    }

    void treeland_personalization_appearance_context_v1::get_icon_theme()
    {
        ::treeland_personalization_appearance_context_v1_get_icon_theme(
            m_treeland_personalization_appearance_context_v1);
    }

    void treeland_personalization_appearance_context_v1::set_active_color(const QString &color)
    {
        ::treeland_personalization_appearance_context_v1_set_active_color(
            m_treeland_personalization_appearance_context_v1,
            color.toUtf8().constData());
    }

    void treeland_personalization_appearance_context_v1::get_active_color()
    {
        ::treeland_personalization_appearance_context_v1_get_active_color(
            m_treeland_personalization_appearance_context_v1);
    }

    void treeland_personalization_appearance_context_v1::set_window_opacity(uint32_t opacity)
    {
        ::treeland_personalization_appearance_context_v1_set_window_opacity(
            m_treeland_personalization_appearance_context_v1,
            opacity);
    }

    void treeland_personalization_appearance_context_v1::get_window_opacity()
    {
        ::treeland_personalization_appearance_context_v1_get_window_opacity(
            m_treeland_personalization_appearance_context_v1);
    }

    void treeland_personalization_appearance_context_v1::set_window_theme_type(uint32_t type)
    {
        ::treeland_personalization_appearance_context_v1_set_window_theme_type(
            m_treeland_personalization_appearance_context_v1,
            type);
    }

    void treeland_personalization_appearance_context_v1::get_window_theme_type()
    {
        ::treeland_personalization_appearance_context_v1_get_window_theme_type(
            m_treeland_personalization_appearance_context_v1);
    }

    void treeland_personalization_appearance_context_v1::set_window_titlebar_height(uint32_t height)
    {
        ::treeland_personalization_appearance_context_v1_set_window_titlebar_height(
            m_treeland_personalization_appearance_context_v1,
            height);
    }

    void treeland_personalization_appearance_context_v1::get_window_titlebar_height()
    {
        ::treeland_personalization_appearance_context_v1_get_window_titlebar_height(
            m_treeland_personalization_appearance_context_v1);
    }

    void treeland_personalization_appearance_context_v1::destroy()
    {
        ::treeland_personalization_appearance_context_v1_destroy(
            m_treeland_personalization_appearance_context_v1);
        m_treeland_personalization_appearance_context_v1 = nullptr;
    }

    void treeland_personalization_appearance_context_v1::treeland_personalization_appearance_context_v1_round_corner_radius(int32_t )
    {
    }

    void treeland_personalization_appearance_context_v1::handle_round_corner_radius(
        void *data,
        struct ::treeland_personalization_appearance_context_v1 *object,
        int32_t radius)
    {
        Q_UNUSED(object);
        static_cast<treeland_personalization_appearance_context_v1 *>(data)->treeland_personalization_appearance_context_v1_round_corner_radius(
            radius);
    }

    void treeland_personalization_appearance_context_v1::treeland_personalization_appearance_context_v1_icon_theme(const QString &)
    {
    }

    void treeland_personalization_appearance_context_v1::handle_icon_theme(
        void *data,
        struct ::treeland_personalization_appearance_context_v1 *object,
        const char *theme_name)
    {
        Q_UNUSED(object);
        static_cast<treeland_personalization_appearance_context_v1 *>(data)->treeland_personalization_appearance_context_v1_icon_theme(
            QString::fromUtf8(theme_name));
    }

    void treeland_personalization_appearance_context_v1::treeland_personalization_appearance_context_v1_active_color(const QString &)
    {
    }

    void treeland_personalization_appearance_context_v1::handle_active_color(
        void *data,
        struct ::treeland_personalization_appearance_context_v1 *object,
        const char *active_color)
    {
        Q_UNUSED(object);
        static_cast<treeland_personalization_appearance_context_v1 *>(data)->treeland_personalization_appearance_context_v1_active_color(
            QString::fromUtf8(active_color));
    }

    void treeland_personalization_appearance_context_v1::treeland_personalization_appearance_context_v1_window_opacity(uint32_t )
    {
    }

    void treeland_personalization_appearance_context_v1::handle_window_opacity(
        void *data,
        struct ::treeland_personalization_appearance_context_v1 *object,
        uint32_t opacity)
    {
        Q_UNUSED(object);
        static_cast<treeland_personalization_appearance_context_v1 *>(data)->treeland_personalization_appearance_context_v1_window_opacity(
            opacity);
    }

    void treeland_personalization_appearance_context_v1::treeland_personalization_appearance_context_v1_window_theme_type(uint32_t )
    {
    }

    void treeland_personalization_appearance_context_v1::handle_window_theme_type(
        void *data,
        struct ::treeland_personalization_appearance_context_v1 *object,
        uint32_t type)
    {
        Q_UNUSED(object);
        static_cast<treeland_personalization_appearance_context_v1 *>(data)->treeland_personalization_appearance_context_v1_window_theme_type(
            type);
    }

    void treeland_personalization_appearance_context_v1::treeland_personalization_appearance_context_v1_window_titlebar_height(uint32_t )
    {
    }

    void treeland_personalization_appearance_context_v1::handle_window_titlebar_height(
        void *data,
        struct ::treeland_personalization_appearance_context_v1 *object,
        uint32_t height)
    {
        Q_UNUSED(object);
        static_cast<treeland_personalization_appearance_context_v1 *>(data)->treeland_personalization_appearance_context_v1_window_titlebar_height(
            height);
    }

    const struct treeland_personalization_appearance_context_v1_listener treeland_personalization_appearance_context_v1::m_treeland_personalization_appearance_context_v1_listener = {
        treeland_personalization_appearance_context_v1::handle_round_corner_radius,
        treeland_personalization_appearance_context_v1::handle_icon_theme,
        treeland_personalization_appearance_context_v1::handle_active_color,
        treeland_personalization_appearance_context_v1::handle_window_opacity,
        treeland_personalization_appearance_context_v1::handle_window_theme_type,
        treeland_personalization_appearance_context_v1::handle_window_titlebar_height,
    };

    void treeland_personalization_appearance_context_v1::init_listener()
    {
        treeland_personalization_appearance_context_v1_add_listener(m_treeland_personalization_appearance_context_v1, &m_treeland_personalization_appearance_context_v1_listener, this);
    }
}

QT_WARNING_POP
QT_END_NAMESPACE
