/****************************************************************************
** Meta object code from reading C++ file 'datetimeworker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-datetime/operation/datetimeworker.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'datetimeworker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14DatetimeWorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto DatetimeWorker::qt_create_metaobjectdata<qt_meta_tag_ZN14DatetimeWorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DatetimeWorker",
        "requestSetAutoHide",
        "",
        "visible",
        "setNTP",
        "ntp",
        "setDatetime",
        "time",
        "set24HourType",
        "state",
        "setTimezone",
        "timezone",
        "removeUserTimeZone",
        "zone",
        "addUserTimeZone",
        "setNtpServer",
        "server",
        "weekdayFormat",
        "setWeekdayFormat",
        "type",
        "setShortDateFormat",
        "setLongDateFormat",
        "setLongTimeFormat",
        "setShortTimeFormat",
        "setWeekStartDayFormat",
        "genLocale",
        "localeName",
        "GetZoneInfo",
        "ZoneInfo",
        "zoneId",
        "decimalSymbol",
        "setDecimalSymbol",
        "value",
        "digitGrouping",
        "setDigitGrouping",
        "digitGroupingSymbol",
        "setDigitGroupingSymbol",
        "currencySymbol",
        "setCurrencySymbol",
        "negativeCurrencyFormat",
        "setNegativeCurrencyFormat",
        "positiveCurrencyFormat",
        "setPositiveCurrencyFormat",
        "onTimezoneListChanged",
        "timezones",
        "setAutoHide",
        "setNTPError",
        "setDatetimeStart",
        "setDateFinished",
        "getSampleNTPServersFinished",
        "serverList",
        "SetNTPServerFinished",
        "SetNTPServerError",
        "getZoneInfoFinished",
        "zoneInfo",
        "activate"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestSetAutoHide'
        QtMocHelpers::SignalData<void(const bool) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'setNTP'
        QtMocHelpers::SlotData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setDatetime'
        QtMocHelpers::SlotData<void(const QDateTime &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 7 },
        }}),
        // Slot 'set24HourType'
        QtMocHelpers::SlotData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'setTimezone'
        QtMocHelpers::SlotData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'removeUserTimeZone'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'addUserTimeZone'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'setNtpServer'
        QtMocHelpers::SlotData<void(QString)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'weekdayFormat'
        QtMocHelpers::SlotData<int()>(17, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'setWeekdayFormat'
        QtMocHelpers::SlotData<void(int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'setShortDateFormat'
        QtMocHelpers::SlotData<void(int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'setLongDateFormat'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'setLongTimeFormat'
        QtMocHelpers::SlotData<void(int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'setShortTimeFormat'
        QtMocHelpers::SlotData<void(int)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'setWeekStartDayFormat'
        QtMocHelpers::SlotData<void(int)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'genLocale'
        QtMocHelpers::SlotData<bool(const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'GetZoneInfo'
        QtMocHelpers::SlotData<ZoneInfo(const QString &)>(27, 2, QMC::AccessPublic, 0x80000000 | 28, {{
            { QMetaType::QString, 29 },
        }}),
        // Slot 'decimalSymbol'
        QtMocHelpers::SlotData<QString()>(30, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setDecimalSymbol'
        QtMocHelpers::SlotData<void(const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 },
        }}),
        // Slot 'digitGrouping'
        QtMocHelpers::SlotData<QString()>(33, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setDigitGrouping'
        QtMocHelpers::SlotData<void(const QString &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 },
        }}),
        // Slot 'digitGroupingSymbol'
        QtMocHelpers::SlotData<QString()>(35, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setDigitGroupingSymbol'
        QtMocHelpers::SlotData<void(const QString &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 },
        }}),
        // Slot 'currencySymbol'
        QtMocHelpers::SlotData<QString()>(37, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setCurrencySymbol'
        QtMocHelpers::SlotData<void(const QString &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 },
        }}),
        // Slot 'negativeCurrencyFormat'
        QtMocHelpers::SlotData<QString()>(39, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setNegativeCurrencyFormat'
        QtMocHelpers::SlotData<void(const QString &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 },
        }}),
        // Slot 'positiveCurrencyFormat'
        QtMocHelpers::SlotData<QString()>(41, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setPositiveCurrencyFormat'
        QtMocHelpers::SlotData<void(const QString &)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 },
        }}),
        // Slot 'onTimezoneListChanged'
        QtMocHelpers::SlotData<void(const QStringList &)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 44 },
        }}),
        // Slot 'setAutoHide'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setNTPError'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setDatetimeStart'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setDateFinished'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'getSampleNTPServersFinished'
        QtMocHelpers::SlotData<void(const QStringList &)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 50 },
        }}),
        // Slot 'SetNTPServerFinished'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'SetNTPServerError'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'getZoneInfoFinished'
        QtMocHelpers::SlotData<void(ZoneInfo)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 54 },
        }}),
        // Method 'activate'
        QtMocHelpers::MethodData<void()>(55, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DatetimeWorker, qt_meta_tag_ZN14DatetimeWorkerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DatetimeWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14DatetimeWorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14DatetimeWorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14DatetimeWorkerE_t>.metaTypes,
    nullptr
} };

void DatetimeWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DatetimeWorker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestSetAutoHide((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->setNTP((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->setDatetime((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1]))); break;
        case 3: _t->set24HourType((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->setTimezone((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->removeUserTimeZone((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->addUserTimeZone((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->setNtpServer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: { int _r = _t->weekdayFormat();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->setWeekdayFormat((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->setShortDateFormat((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->setLongDateFormat((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->setLongTimeFormat((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->setShortTimeFormat((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->setWeekStartDayFormat((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: { bool _r = _t->genLocale((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { ZoneInfo _r = _t->GetZoneInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<ZoneInfo*>(_a[0]) = std::move(_r); }  break;
        case 17: { QString _r = _t->decimalSymbol();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->setDecimalSymbol((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: { QString _r = _t->digitGrouping();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->setDigitGrouping((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: { QString _r = _t->digitGroupingSymbol();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->setDigitGroupingSymbol((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: { QString _r = _t->currencySymbol();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 24: _t->setCurrencySymbol((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: { QString _r = _t->negativeCurrencyFormat();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->setNegativeCurrencyFormat((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: { QString _r = _t->positiveCurrencyFormat();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 28: _t->setPositiveCurrencyFormat((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: _t->onTimezoneListChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 30: _t->setAutoHide(); break;
        case 31: _t->setNTPError(); break;
        case 32: _t->setDatetimeStart(); break;
        case 33: _t->setDateFinished(); break;
        case 34: _t->getSampleNTPServersFinished((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 35: _t->SetNTPServerFinished(); break;
        case 36: _t->SetNTPServerError(); break;
        case 37: _t->getZoneInfoFinished((*reinterpret_cast<std::add_pointer_t<ZoneInfo>>(_a[1]))); break;
        case 38: _t->activate(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ZoneInfo >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DatetimeWorker::*)(const bool ) const>(_a, &DatetimeWorker::requestSetAutoHide, 0))
            return;
    }
}

const QMetaObject *DatetimeWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DatetimeWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14DatetimeWorkerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DatetimeWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    return _id;
}

// SIGNAL 0
void DatetimeWorker::requestSetAutoHide(const bool _t1)const
{
    QMetaObject::activate<void>(const_cast< DatetimeWorker *>(this), &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
