/****************************************************************************
** Meta object code from reading C++ file 'keyboardcontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-keyboard/operation/keyboardcontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keyboardcontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6dccV2518KeyboardControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::KeyboardController::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV2518KeyboardControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::KeyboardController",
        "repeatIntervalChanged",
        "",
        "repeatDelayChanged",
        "numLockChanged",
        "capsLockChanged",
        "layoutCountChanged",
        "currentLayoutChanged",
        "requestRestore",
        "requestClear",
        "keyConflicted",
        "oldAccels",
        "newAccels",
        "keyDone",
        "accels",
        "keyEvent",
        "conflictTextChanged",
        "keyboardEnabledChanged",
        "addUserLayout",
        "layout",
        "deleteUserLayout",
        "userLayouts",
        "QMap<QString,QString>",
        "userLayoutAt",
        "index",
        "isValue",
        "userLayoutsContains",
        "key",
        "layoutSearchModel",
        "QSortFilterProxyModel*",
        "shortcutSearchModel",
        "updateKey",
        "id",
        "type",
        "formatKeys",
        "shortcuts",
        "addCustomShortcut",
        "name",
        "cmd",
        "modifyCustomShortcut",
        "modifyShortcut",
        "deleteCustomShortcut",
        "resetAllShortcuts",
        "repeatInterval",
        "repeatDelay",
        "keyboardEnabled",
        "numLock",
        "capsLock",
        "layoutCount",
        "currentLayout",
        "conflictText"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'repeatIntervalChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'repeatDelayChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'numLockChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'capsLockChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'layoutCountChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentLayoutChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestRestore'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestClear'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyConflicted'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 },
        }}),
        // Signal 'keyDone'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'keyEvent'
        QtMocHelpers::SignalData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'conflictTextChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyboardEnabledChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addUserLayout'
        QtMocHelpers::SlotData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'deleteUserLayout'
        QtMocHelpers::SlotData<void(const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'userLayouts'
        QtMocHelpers::SlotData<QMap<QString,QString>() const>(21, 2, QMC::AccessPublic, 0x80000000 | 22),
        // Slot 'userLayoutAt'
        QtMocHelpers::SlotData<QString(int, bool) const>(23, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 24 }, { QMetaType::Bool, 25 },
        }}),
        // Slot 'userLayoutAt'
        QtMocHelpers::SlotData<QString(int) const>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'userLayoutsContains'
        QtMocHelpers::SlotData<bool(const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'layoutSearchModel'
        QtMocHelpers::SlotData<QSortFilterProxyModel *()>(28, 2, QMC::AccessPublic, 0x80000000 | 29),
        // Slot 'shortcutSearchModel'
        QtMocHelpers::SlotData<QSortFilterProxyModel *()>(30, 2, QMC::AccessPublic, 0x80000000 | 29),
        // Slot 'updateKey'
        QtMocHelpers::SlotData<void(const QString &, const int &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 }, { QMetaType::Int, 33 },
        }}),
        // Slot 'formatKeys'
        QtMocHelpers::SlotData<QStringList(const QString &)>(34, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 35 },
        }}),
        // Slot 'addCustomShortcut'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 }, { QMetaType::QString, 38 }, { QMetaType::QString, 14 },
        }}),
        // Slot 'modifyCustomShortcut'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QString &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 }, { QMetaType::QString, 37 }, { QMetaType::QString, 38 }, { QMetaType::QString, 14 },
        }}),
        // Slot 'modifyShortcut'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const int &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 }, { QMetaType::QString, 14 }, { QMetaType::Int, 33 },
        }}),
        // Slot 'deleteCustomShortcut'
        QtMocHelpers::SlotData<void(const QString &)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 },
        }}),
        // Slot 'resetAllShortcuts'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'repeatInterval'
        QtMocHelpers::PropertyData<uint>(43, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0),
        // property 'repeatDelay'
        QtMocHelpers::PropertyData<uint>(44, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 1),
        // property 'keyboardEnabled'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 12),
        // property 'numLock'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 2),
        // property 'capsLock'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 3),
        // property 'layoutCount'
        QtMocHelpers::PropertyData<int>(48, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 4),
        // property 'currentLayout'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 5),
        // property 'conflictText'
        QtMocHelpers::PropertyData<QString>(50, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 11),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KeyboardController, qt_meta_tag_ZN6dccV2518KeyboardControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dccV25::KeyboardController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2518KeyboardControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2518KeyboardControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV2518KeyboardControllerE_t>.metaTypes,
    nullptr
} };

void dccV25::KeyboardController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeyboardController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->repeatIntervalChanged(); break;
        case 1: _t->repeatDelayChanged(); break;
        case 2: _t->numLockChanged(); break;
        case 3: _t->capsLockChanged(); break;
        case 4: _t->layoutCountChanged(); break;
        case 5: _t->currentLayoutChanged(); break;
        case 6: _t->requestRestore(); break;
        case 7: _t->requestClear(); break;
        case 8: _t->keyConflicted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->keyDone((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->keyEvent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->conflictTextChanged(); break;
        case 12: _t->keyboardEnabledChanged(); break;
        case 13: _t->addUserLayout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->deleteUserLayout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: { QMap<QString,QString> _r = _t->userLayouts();
            if (_a[0]) *reinterpret_cast<QMap<QString,QString>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QString _r = _t->userLayoutAt((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 17: { QString _r = _t->userLayoutAt((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->userLayoutsContains((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { QSortFilterProxyModel* _r = _t->layoutSearchModel();
            if (_a[0]) *reinterpret_cast<QSortFilterProxyModel**>(_a[0]) = std::move(_r); }  break;
        case 20: { QSortFilterProxyModel* _r = _t->shortcutSearchModel();
            if (_a[0]) *reinterpret_cast<QSortFilterProxyModel**>(_a[0]) = std::move(_r); }  break;
        case 21: _t->updateKey((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 22: { QStringList _r = _t->formatKeys((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->addCustomShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 24: _t->modifyCustomShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 25: _t->modifyShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 26: _t->deleteCustomShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->resetAllShortcuts(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KeyboardController::*)()>(_a, &KeyboardController::repeatIntervalChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardController::*)()>(_a, &KeyboardController::repeatDelayChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardController::*)()>(_a, &KeyboardController::numLockChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardController::*)()>(_a, &KeyboardController::capsLockChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardController::*)()>(_a, &KeyboardController::layoutCountChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardController::*)()>(_a, &KeyboardController::currentLayoutChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardController::*)()>(_a, &KeyboardController::requestRestore, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardController::*)()>(_a, &KeyboardController::requestClear, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardController::*)(const QString & , const QString & )>(_a, &KeyboardController::keyConflicted, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardController::*)(const QString & )>(_a, &KeyboardController::keyDone, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardController::*)(const QString & )>(_a, &KeyboardController::keyEvent, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardController::*)()>(_a, &KeyboardController::conflictTextChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardController::*)()>(_a, &KeyboardController::keyboardEnabledChanged, 12))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint*>(_v) = _t->repeatInterval(); break;
        case 1: *reinterpret_cast<uint*>(_v) = _t->repeatDelay(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->keyboardEnabled(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->numLock(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->capsLock(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->layoutCount(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->currentLayout(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->conflictText(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setRepeatInterval(*reinterpret_cast<uint*>(_v)); break;
        case 1: _t->setRepeatDelay(*reinterpret_cast<uint*>(_v)); break;
        case 2: _t->setKeyboardEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setNumLock(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setCapsLock(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setCurrentLayout(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setConflictText(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *dccV25::KeyboardController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::KeyboardController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2518KeyboardControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dccV25::KeyboardController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 28;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void dccV25::KeyboardController::repeatIntervalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dccV25::KeyboardController::repeatDelayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dccV25::KeyboardController::numLockChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void dccV25::KeyboardController::capsLockChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void dccV25::KeyboardController::layoutCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void dccV25::KeyboardController::currentLayoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void dccV25::KeyboardController::requestRestore()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void dccV25::KeyboardController::requestClear()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void dccV25::KeyboardController::keyConflicted(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void dccV25::KeyboardController::keyDone(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void dccV25::KeyboardController::keyEvent(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void dccV25::KeyboardController::conflictTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void dccV25::KeyboardController::keyboardEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
