/****************************************************************************
** Meta object code from reading C++ file 'systeminfodbusproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-systeminfo/operation/systeminfodbusproxy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'systeminfodbusproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19SystemInfoDBusProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto SystemInfoDBusProxy::qt_create_metaobjectdata<qt_meta_tag_ZN19SystemInfoDBusProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SystemInfoDBusProxy",
        "StaticHostnameChanged",
        "",
        "value",
        "AuthorizationStateChanged",
        "TimezoneChanged",
        "ShortDateFormatChanged",
        "Show",
        "StaticHostname",
        "AuthorizationState",
        "Timezone",
        "ShortDateFormat"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'StaticHostnameChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'AuthorizationStateChanged'
        QtMocHelpers::SignalData<void(const int) const>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'TimezoneChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'ShortDateFormatChanged'
        QtMocHelpers::SignalData<void(const int) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'Show'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'StaticHostname'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'AuthorizationState'
        QtMocHelpers::PropertyData<int>(9, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'Timezone'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'ShortDateFormat'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SystemInfoDBusProxy, qt_meta_tag_ZN19SystemInfoDBusProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SystemInfoDBusProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19SystemInfoDBusProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19SystemInfoDBusProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19SystemInfoDBusProxyE_t>.metaTypes,
    nullptr
} };

void SystemInfoDBusProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SystemInfoDBusProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->StaticHostnameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->AuthorizationStateChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->TimezoneChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->ShortDateFormatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->Show(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SystemInfoDBusProxy::*)(const QString & ) const>(_a, &SystemInfoDBusProxy::StaticHostnameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoDBusProxy::*)(const int ) const>(_a, &SystemInfoDBusProxy::AuthorizationStateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoDBusProxy::*)(const QString & ) const>(_a, &SystemInfoDBusProxy::TimezoneChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInfoDBusProxy::*)(const int ) const>(_a, &SystemInfoDBusProxy::ShortDateFormatChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->staticHostname(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->authorizationState(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->timezone(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->shortDateFormat(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setStaticHostname(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setAuthorizationState(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setTimezone(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *SystemInfoDBusProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SystemInfoDBusProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19SystemInfoDBusProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SystemInfoDBusProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void SystemInfoDBusProxy::StaticHostnameChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< SystemInfoDBusProxy *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void SystemInfoDBusProxy::AuthorizationStateChanged(const int _t1)const
{
    QMetaObject::activate<void>(const_cast< SystemInfoDBusProxy *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void SystemInfoDBusProxy::TimezoneChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< SystemInfoDBusProxy *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void SystemInfoDBusProxy::ShortDateFormatChanged(const int _t1)const
{
    QMetaObject::activate<void>(const_cast< SystemInfoDBusProxy *>(this), &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
