/****************************************************************************
** Meta object code from reading C++ file 'touchscreenmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-touchscreen/operation/touchscreenmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'touchscreenmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16TouchScreenModelE_t {};
} // unnamed namespace

template <> constexpr inline auto TouchScreenModel::qt_create_metaobjectdata<qt_meta_tag_ZN16TouchScreenModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TouchScreenModel",
        "touchScreenListChanged",
        "",
        "TouchscreenInfoList_V2",
        "newTouchScreenList",
        "monitorsChanged",
        "monitors",
        "touchMapChanged",
        "touchScreenMatchModel",
        "TouchScreenMatchModel*",
        "assoiateTouch",
        "monitor",
        "touchscreenUUID",
        "touchScreenList",
        "touchMap",
        "TouchscreenMap"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'touchScreenListChanged'
        QtMocHelpers::SignalData<void(const TouchscreenInfoList_V2 &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'monitorsChanged'
        QtMocHelpers::SignalData<void(const QStringList)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 6 },
        }}),
        // Signal 'touchMapChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'touchScreenMatchModel'
        QtMocHelpers::SlotData<TouchScreenMatchModel *() const>(8, 2, QMC::AccessPublic, 0x80000000 | 9),
        // Method 'assoiateTouch'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'touchScreenList'
        QtMocHelpers::PropertyData<TouchscreenInfoList_V2>(13, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'monitors'
        QtMocHelpers::PropertyData<QStringList>(6, QMetaType::QStringList, QMC::DefaultPropertyFlags, 1),
        // property 'touchMap'
        QtMocHelpers::PropertyData<TouchscreenMap>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TouchScreenModel, qt_meta_tag_ZN16TouchScreenModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TouchScreenModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16TouchScreenModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16TouchScreenModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16TouchScreenModelE_t>.metaTypes,
    nullptr
} };

void TouchScreenModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TouchScreenModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->touchScreenListChanged((*reinterpret_cast<std::add_pointer_t<TouchscreenInfoList_V2>>(_a[1]))); break;
        case 1: _t->monitorsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 2: _t->touchMapChanged(); break;
        case 3: { TouchScreenMatchModel* _r = _t->touchScreenMatchModel();
            if (_a[0]) *reinterpret_cast<TouchScreenMatchModel**>(_a[0]) = std::move(_r); }  break;
        case 4: _t->assoiateTouch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TouchscreenInfoList_V2 >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TouchScreenModel::*)(const TouchscreenInfoList_V2 & )>(_a, &TouchScreenModel::touchScreenListChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TouchScreenModel::*)(const QStringList )>(_a, &TouchScreenModel::monitorsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TouchScreenModel::*)()>(_a, &TouchScreenModel::touchMapChanged, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< TouchscreenInfoList_V2 >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<TouchscreenInfoList_V2*>(_v) = _t->touchScreenList(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->monitors(); break;
        case 2: *reinterpret_cast<TouchscreenMap*>(_v) = _t->touchMap(); break;
        default: break;
        }
    }
}

const QMetaObject *TouchScreenModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TouchScreenModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16TouchScreenModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int TouchScreenModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void TouchScreenModel::touchScreenListChanged(const TouchscreenInfoList_V2 & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void TouchScreenModel::monitorsChanged(const QStringList _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TouchScreenModel::touchMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
