/****************************************************************************
** Meta object code from reading C++ file 'touchscreenproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-touchscreen/operation/touchscreenproxy.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'touchscreenproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13DCC_NAMESPACE16TouchScreenProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto DCC_NAMESPACE::TouchScreenProxy::qt_create_metaobjectdata<qt_meta_tag_ZN13DCC_NAMESPACE16TouchScreenProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DCC_NAMESPACE::TouchScreenProxy",
        "TouchscreensV2Changed",
        "",
        "TouchscreenInfoList_V2",
        "value",
        "MonitorsChanged",
        "QList<QDBusObjectPath>",
        "TouchMapChanged",
        "TouchscreenMap",
        "AssociateTouchByUUID",
        "QDBusPendingReply<>",
        "in0",
        "in1",
        "TouchscreensV2",
        "TouchMap",
        "Monitors"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'TouchscreensV2Changed'
        QtMocHelpers::SignalData<void(TouchscreenInfoList_V2)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'MonitorsChanged'
        QtMocHelpers::SignalData<void(const QList<QDBusObjectPath> &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 4 },
        }}),
        // Signal 'TouchMapChanged'
        QtMocHelpers::SignalData<void(TouchscreenMap)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 4 },
        }}),
        // Slot 'AssociateTouchByUUID'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(9, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'TouchscreensV2'
        QtMocHelpers::PropertyData<TouchscreenInfoList_V2>(13, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'TouchMap'
        QtMocHelpers::PropertyData<TouchscreenMap>(14, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'Monitors'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(15, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TouchScreenProxy, qt_meta_tag_ZN13DCC_NAMESPACE16TouchScreenProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DCC_NAMESPACE::TouchScreenProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DCC_NAMESPACE16TouchScreenProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DCC_NAMESPACE16TouchScreenProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13DCC_NAMESPACE16TouchScreenProxyE_t>.metaTypes,
    nullptr
} };

void DCC_NAMESPACE::TouchScreenProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TouchScreenProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->TouchscreensV2Changed((*reinterpret_cast<std::add_pointer_t<TouchscreenInfoList_V2>>(_a[1]))); break;
        case 1: _t->MonitorsChanged((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1]))); break;
        case 2: _t->TouchMapChanged((*reinterpret_cast<std::add_pointer_t<TouchscreenMap>>(_a[1]))); break;
        case 3: { QDBusPendingReply<> _r = _t->AssociateTouchByUUID((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< TouchscreenInfoList_V2 >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDBusObjectPath> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TouchScreenProxy::*)(TouchscreenInfoList_V2 )>(_a, &TouchScreenProxy::TouchscreensV2Changed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TouchScreenProxy::*)(const QList<QDBusObjectPath> & )>(_a, &TouchScreenProxy::MonitorsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TouchScreenProxy::*)(TouchscreenMap )>(_a, &TouchScreenProxy::TouchMapChanged, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QDBusObjectPath> >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< TouchscreenInfoList_V2 >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<TouchscreenInfoList_V2*>(_v) = _t->touchscreensV2(); break;
        case 1: *reinterpret_cast<TouchscreenMap*>(_v) = _t->touchMap(); break;
        case 2: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->monitors(); break;
        default: break;
        }
    }
}

const QMetaObject *DCC_NAMESPACE::TouchScreenProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DCC_NAMESPACE::TouchScreenProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DCC_NAMESPACE16TouchScreenProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DCC_NAMESPACE::TouchScreenProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void DCC_NAMESPACE::TouchScreenProxy::TouchscreensV2Changed(TouchscreenInfoList_V2 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DCC_NAMESPACE::TouchScreenProxy::MonitorsChanged(const QList<QDBusObjectPath> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DCC_NAMESPACE::TouchScreenProxy::TouchMapChanged(TouchscreenMap _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
