/****************************************************************************
** Meta object code from reading C++ file 'accountsdbusproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-accounts/operation/accountsdbusproxy.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'accountsdbusproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17AccountsDBusProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto AccountsDBusProxy::qt_create_metaobjectdata<qt_meta_tag_ZN17AccountsDBusProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AccountsDBusProxy",
        "UserAdded",
        "",
        "in0",
        "UserDeleted",
        "UserListChanged",
        "value",
        "GroupListChanged",
        "SessionsChanged",
        "QList<QDBusObjectPath>",
        "CreateUser",
        "QDBusPendingReply<QDBusObjectPath>",
        "in1",
        "in2",
        "DeleteUser",
        "QDBusPendingReply<>",
        "FindUserById",
        "QDBusPendingReply<QString>",
        "FindUserByName",
        "GetGroups",
        "QDBusPendingReply<QStringList>",
        "GetPresetGroups",
        "IsPasswordValid",
        "QDBusPendingReply<bool,QString,int>",
        "IsUsernameValid",
        "RandUserIcon",
        "GetGroupInfoByName",
        "deleteGroup",
        "createGroup",
        "uint32_t",
        "modifyGroup",
        "UserList",
        "GroupList",
        "Sessions"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'UserAdded'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'UserDeleted'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'UserListChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 6 },
        }}),
        // Signal 'GroupListChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 6 },
        }}),
        // Signal 'SessionsChanged'
        QtMocHelpers::SignalData<void(const QList<QDBusObjectPath> &) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 6 },
        }}),
        // Slot 'CreateUser'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &, const QString &, int)>(10, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 12 }, { QMetaType::Int, 13 },
        }}),
        // Slot 'DeleteUser'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, bool)>(14, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 12 },
        }}),
        // Slot 'FindUserById'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const qint64 &)>(16, 2, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::LongLong, 3 },
        }}),
        // Slot 'FindUserByName'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(18, 2, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'GetGroups'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(19, 2, QMC::AccessPublic, 0x80000000 | 20),
        // Slot 'GetPresetGroups'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(int)>(21, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'IsPasswordValid'
        QtMocHelpers::SlotData<QDBusPendingReply<bool,QString,int>(const QString &)>(22, 2, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'IsUsernameValid'
        QtMocHelpers::SlotData<QDBusPendingReply<bool,QString,int>(const QString &)>(24, 2, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'RandUserIcon'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(25, 2, QMC::AccessPublic, 0x80000000 | 17),
        // Slot 'GetGroupInfoByName'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(26, 2, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'deleteGroup'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(27, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'createGroup'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, uint32_t, bool)>(28, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 29, 12 }, { QMetaType::Bool, 13 },
        }}),
        // Slot 'modifyGroup'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, uint32_t)>(30, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 12 }, { 0x80000000 | 29, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'UserList'
        QtMocHelpers::PropertyData<QStringList>(31, QMetaType::QStringList, QMC::DefaultPropertyFlags, 2),
        // property 'GroupList'
        QtMocHelpers::PropertyData<QStringList>(32, QMetaType::QStringList, QMC::DefaultPropertyFlags, 3),
        // property 'Sessions'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(33, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AccountsDBusProxy, qt_meta_tag_ZN17AccountsDBusProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AccountsDBusProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17AccountsDBusProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17AccountsDBusProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17AccountsDBusProxyE_t>.metaTypes,
    nullptr
} };

void AccountsDBusProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AccountsDBusProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->UserAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->UserDeleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->UserListChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 3: _t->GroupListChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 4: _t->SessionsChanged((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1]))); break;
        case 5: { QDBusPendingReply<QDBusObjectPath> _r = _t->CreateUser((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<> _r = _t->DeleteUser((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<QString> _r = _t->FindUserById((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<QString> _r = _t->FindUserByName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<QStringList> _r = _t->GetGroups();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<QStringList> _r = _t->GetPresetGroups((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<bool,QString,int> _r = _t->IsPasswordValid((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool,QString,int>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<bool,QString,int> _r = _t->IsUsernameValid((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool,QString,int>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<QString> _r = _t->RandUserIcon();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<QString> _r = _t->GetGroupInfoByName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<> _r = _t->deleteGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<> _r = _t->createGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<> _r = _t->modifyGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDBusObjectPath> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AccountsDBusProxy::*)(const QString & )>(_a, &AccountsDBusProxy::UserAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsDBusProxy::*)(const QString & )>(_a, &AccountsDBusProxy::UserDeleted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsDBusProxy::*)(const QStringList & ) const>(_a, &AccountsDBusProxy::UserListChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsDBusProxy::*)(const QStringList & )>(_a, &AccountsDBusProxy::GroupListChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsDBusProxy::*)(const QList<QDBusObjectPath> & ) const>(_a, &AccountsDBusProxy::SessionsChanged, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QDBusObjectPath> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->userList(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->groupList(); break;
        case 2: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->sessions(); break;
        default: break;
        }
    }
}

const QMetaObject *AccountsDBusProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AccountsDBusProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17AccountsDBusProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AccountsDBusProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void AccountsDBusProxy::UserAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AccountsDBusProxy::UserDeleted(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AccountsDBusProxy::UserListChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< AccountsDBusProxy *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void AccountsDBusProxy::GroupListChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void AccountsDBusProxy::SessionsChanged(const QList<QDBusObjectPath> & _t1)const
{
    QMetaObject::activate<void>(const_cast< AccountsDBusProxy *>(this), &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
