/****************************************************************************
** Meta object code from reading C++ file 'personalizationdbusproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-personalization/operation/personalizationdbusproxy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'personalizationdbusproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24PersonalizationDBusProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto PersonalizationDBusProxy::qt_create_metaobjectdata<qt_meta_tag_ZN24PersonalizationDBusProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PersonalizationDBusProxy",
        "Changed",
        "",
        "in0",
        "in1",
        "Refreshed",
        "BackgroundChanged",
        "value",
        "CursorThemeChanged",
        "FontSizeChanged",
        "GtkThemeChanged",
        "IconThemeChanged",
        "GlobalThemeChanged",
        "MonospaceFontChanged",
        "OpacityChanged",
        "QtActiveColorChanged",
        "StandardFontChanged",
        "WallpaperSlideShowChanged",
        "WindowRadiusChanged",
        "WMChanged",
        "wm",
        "compositingAllowSwitchChanged",
        "compositingEnabledChanged",
        "compositingPossibleChanged",
        "cursorSizeChanged",
        "ZoneEnabledChanged",
        "DTKSizeModeChanged",
        "scrollBarPolicyChanged",
        "WallpaperURlsChanged",
        "allscreensaverChanged",
        "currentScreenSaverChanged",
        "lockScreenAtAwakeChanged",
        "linePowerScreenSaverTimeoutChanged",
        "batteryScreenSaverTimeoutChanged",
        "WallpaperChanged",
        "mode",
        "urls",
        "OnBatteryChanged",
        "List",
        "ty",
        "receiver",
        "const char*",
        "member",
        "errorSlot",
        "Set",
        "Show",
        "names",
        "Thumbnail",
        "name",
        "activeColors",
        "setActiveColors",
        "loadEffect",
        "unloadEffect",
        "isEffectLoaded",
        "onPropertiesChanged",
        "QDBusMessage",
        "message",
        "Background",
        "CursorTheme",
        "GlobalTheme",
        "FontSize",
        "GtkTheme",
        "IconTheme",
        "MonospaceFont",
        "Opacity",
        "QtActiveColor",
        "StandardFont",
        "WallpaperSlideShow",
        "WindowRadius",
        "compositingAllowSwitch",
        "compositingEnabled",
        "compositingPossible",
        "cursorSize",
        "zoneEnabled",
        "DTKSizeMode",
        "scrollBarPolicy"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Changed'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'Refreshed'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'BackgroundChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'CursorThemeChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'FontSizeChanged'
        QtMocHelpers::SignalData<void(double) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 7 },
        }}),
        // Signal 'GtkThemeChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'IconThemeChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'GlobalThemeChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'MonospaceFontChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'OpacityChanged'
        QtMocHelpers::SignalData<void(double) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 7 },
        }}),
        // Signal 'QtActiveColorChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'StandardFontChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'WallpaperSlideShowChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'WindowRadiusChanged'
        QtMocHelpers::SignalData<void(int) const>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'WMChanged'
        QtMocHelpers::SignalData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Signal 'compositingAllowSwitchChanged'
        QtMocHelpers::SignalData<void(bool) const>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'compositingEnabledChanged'
        QtMocHelpers::SignalData<void(bool) const>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'compositingPossibleChanged'
        QtMocHelpers::SignalData<void(bool) const>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'cursorSizeChanged'
        QtMocHelpers::SignalData<void(int) const>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'ZoneEnabledChanged'
        QtMocHelpers::SignalData<void(bool) const>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'DTKSizeModeChanged'
        QtMocHelpers::SignalData<void(int) const>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'scrollBarPolicyChanged'
        QtMocHelpers::SignalData<void(int) const>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'WallpaperURlsChanged'
        QtMocHelpers::SignalData<void(QString) const>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'allscreensaverChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 7 },
        }}),
        // Signal 'currentScreenSaverChanged'
        QtMocHelpers::SignalData<void(const QString &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'lockScreenAtAwakeChanged'
        QtMocHelpers::SignalData<void(bool)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'linePowerScreenSaverTimeoutChanged'
        QtMocHelpers::SignalData<void(int)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'batteryScreenSaverTimeoutChanged'
        QtMocHelpers::SignalData<void(int)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'WallpaperChanged'
        QtMocHelpers::SignalData<void(const QString &, uint, const QStringList &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::UInt, 35 }, { QMetaType::QStringList, 36 },
        }}),
        // Signal 'OnBatteryChanged'
        QtMocHelpers::SignalData<void(bool)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'List'
        QtMocHelpers::SlotData<QString(const QString &)>(38, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 39 },
        }}),
        // Slot 'List'
        QtMocHelpers::SlotData<bool(const QString &, QObject *, const char *, const char *)>(38, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 39 }, { QMetaType::QObjectStar, 40 }, { 0x80000000 | 41, 42 }, { 0x80000000 | 41, 43 },
        }}),
        // Slot 'Set'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 39 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'Show'
        QtMocHelpers::SlotData<QString(const QString &, const QStringList &)>(45, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 39 }, { QMetaType::QStringList, 46 },
        }}),
        // Slot 'Show'
        QtMocHelpers::SlotData<bool(const QString &, const QStringList &, QObject *, const char *)>(45, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 39 }, { QMetaType::QStringList, 46 }, { QMetaType::QObjectStar, 40 }, { 0x80000000 | 41, 42 },
        }}),
        // Slot 'Thumbnail'
        QtMocHelpers::SlotData<QString(const QString &, const QString &)>(47, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 39 }, { QMetaType::QString, 48 },
        }}),
        // Slot 'Thumbnail'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, QObject *, const char *, const char *)>(47, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 39 }, { QMetaType::QString, 48 }, { QMetaType::QObjectStar, 40 }, { 0x80000000 | 41, 42 },
            { 0x80000000 | 41, 43 },
        }}),
        // Slot 'activeColors'
        QtMocHelpers::SlotData<QString()>(49, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setActiveColors'
        QtMocHelpers::SlotData<void(const QString &)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 49 },
        }}),
        // Slot 'loadEffect'
        QtMocHelpers::SlotData<bool(const QString &)>(51, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'unloadEffect'
        QtMocHelpers::SlotData<void(const QString &)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'isEffectLoaded'
        QtMocHelpers::SlotData<bool(const QString &)>(53, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'isEffectLoaded'
        QtMocHelpers::SlotData<bool(const QString &, QObject *, const char *)>(53, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 48 }, { QMetaType::QObjectStar, 40 }, { 0x80000000 | 41, 42 },
        }}),
        // Slot 'onPropertiesChanged'
        QtMocHelpers::SlotData<void(const QDBusMessage &)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 55, 56 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Background'
        QtMocHelpers::PropertyData<QString>(57, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'CursorTheme'
        QtMocHelpers::PropertyData<QString>(58, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'GlobalTheme'
        QtMocHelpers::PropertyData<QString>(59, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'FontSize'
        QtMocHelpers::PropertyData<double>(60, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'GtkTheme'
        QtMocHelpers::PropertyData<QString>(61, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'IconTheme'
        QtMocHelpers::PropertyData<QString>(62, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'MonospaceFont'
        QtMocHelpers::PropertyData<QString>(63, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'Opacity'
        QtMocHelpers::PropertyData<double>(64, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'QtActiveColor'
        QtMocHelpers::PropertyData<QString>(65, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'StandardFont'
        QtMocHelpers::PropertyData<QString>(66, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'WallpaperSlideShow'
        QtMocHelpers::PropertyData<QString>(67, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'WindowRadius'
        QtMocHelpers::PropertyData<int>(68, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'compositingAllowSwitch'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags, 15),
        // property 'compositingEnabled'
        QtMocHelpers::PropertyData<bool>(70, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'compositingPossible'
        QtMocHelpers::PropertyData<bool>(71, QMetaType::Bool, QMC::DefaultPropertyFlags, 17),
        // property 'cursorSize'
        QtMocHelpers::PropertyData<int>(72, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'zoneEnabled'
        QtMocHelpers::PropertyData<bool>(73, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'DTKSizeMode'
        QtMocHelpers::PropertyData<int>(74, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'scrollBarPolicy'
        QtMocHelpers::PropertyData<int>(75, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PersonalizationDBusProxy, qt_meta_tag_ZN24PersonalizationDBusProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PersonalizationDBusProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24PersonalizationDBusProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24PersonalizationDBusProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24PersonalizationDBusProxyE_t>.metaTypes,
    nullptr
} };

void PersonalizationDBusProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PersonalizationDBusProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Changed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->Refreshed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->BackgroundChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->CursorThemeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->FontSizeChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 5: _t->GtkThemeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->IconThemeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->GlobalThemeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->MonospaceFontChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->OpacityChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 10: _t->QtActiveColorChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->StandardFontChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->WallpaperSlideShowChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->WindowRadiusChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->WMChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->compositingAllowSwitchChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->compositingEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->compositingPossibleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->cursorSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->ZoneEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->DTKSizeModeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->scrollBarPolicyChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->WallpaperURlsChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->allscreensaverChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 24: _t->currentScreenSaverChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->lockScreenAtAwakeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->linePowerScreenSaverTimeoutChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->batteryScreenSaverTimeoutChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->WallpaperChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 29: _t->OnBatteryChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: { QString _r = _t->List((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 31: { bool _r = _t->List((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 32: _t->Set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 33: { QString _r = _t->Show((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 34: { bool _r = _t->Show((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 35: { QString _r = _t->Thumbnail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 36: { bool _r = _t->Thumbnail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[5])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 37: { QString _r = _t->activeColors();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 38: _t->setActiveColors((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 39: { bool _r = _t->loadEffect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 40: _t->unloadEffect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 41: { bool _r = _t->isEffectLoaded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 42: { bool _r = _t->isEffectLoaded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 43: _t->onPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(const QString & , const QString & )>(_a, &PersonalizationDBusProxy::Changed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(const QString & )>(_a, &PersonalizationDBusProxy::Refreshed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(const QString & ) const>(_a, &PersonalizationDBusProxy::BackgroundChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(const QString & ) const>(_a, &PersonalizationDBusProxy::CursorThemeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(double ) const>(_a, &PersonalizationDBusProxy::FontSizeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(const QString & ) const>(_a, &PersonalizationDBusProxy::GtkThemeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(const QString & ) const>(_a, &PersonalizationDBusProxy::IconThemeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(const QString & ) const>(_a, &PersonalizationDBusProxy::GlobalThemeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(const QString & ) const>(_a, &PersonalizationDBusProxy::MonospaceFontChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(double ) const>(_a, &PersonalizationDBusProxy::OpacityChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(const QString & ) const>(_a, &PersonalizationDBusProxy::QtActiveColorChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(const QString & ) const>(_a, &PersonalizationDBusProxy::StandardFontChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(const QString & ) const>(_a, &PersonalizationDBusProxy::WallpaperSlideShowChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(int ) const>(_a, &PersonalizationDBusProxy::WindowRadiusChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(const QString & )>(_a, &PersonalizationDBusProxy::WMChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(bool ) const>(_a, &PersonalizationDBusProxy::compositingAllowSwitchChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(bool ) const>(_a, &PersonalizationDBusProxy::compositingEnabledChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(bool ) const>(_a, &PersonalizationDBusProxy::compositingPossibleChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(int ) const>(_a, &PersonalizationDBusProxy::cursorSizeChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(bool ) const>(_a, &PersonalizationDBusProxy::ZoneEnabledChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(int ) const>(_a, &PersonalizationDBusProxy::DTKSizeModeChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(int ) const>(_a, &PersonalizationDBusProxy::scrollBarPolicyChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(QString ) const>(_a, &PersonalizationDBusProxy::WallpaperURlsChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(const QStringList & )>(_a, &PersonalizationDBusProxy::allscreensaverChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(const QString & )>(_a, &PersonalizationDBusProxy::currentScreenSaverChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(bool )>(_a, &PersonalizationDBusProxy::lockScreenAtAwakeChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(int )>(_a, &PersonalizationDBusProxy::linePowerScreenSaverTimeoutChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(int )>(_a, &PersonalizationDBusProxy::batteryScreenSaverTimeoutChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(const QString & , uint , const QStringList & )>(_a, &PersonalizationDBusProxy::WallpaperChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationDBusProxy::*)(bool )>(_a, &PersonalizationDBusProxy::OnBatteryChanged, 29))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->background(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->cursorTheme(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->globalTheme(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->fontSize(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->gtkTheme(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->iconTheme(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->monospaceFont(); break;
        case 7: *reinterpret_cast<double*>(_v) = _t->opacity(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->qtActiveColor(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->standardFont(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->wallpaperSlideShow(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->windowRadius(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->compositingAllowSwitch(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->compositingEnabled(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->compositingPossible(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->cursorSize(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->zoneEnabled(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->getDTKSizeMode(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->getScrollBarPolicy(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBackground(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setCursorTheme(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setGlobalTheme(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setFontSize(*reinterpret_cast<double*>(_v)); break;
        case 4: _t->setGtkTheme(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setIconTheme(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setMonospaceFont(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setOpacity(*reinterpret_cast<double*>(_v)); break;
        case 8: _t->setQtActiveColor(*reinterpret_cast<QString*>(_v)); break;
        case 9: _t->setStandardFont(*reinterpret_cast<QString*>(_v)); break;
        case 10: _t->setWallpaperSlideShow(*reinterpret_cast<QString*>(_v)); break;
        case 11: _t->setWindowRadius(*reinterpret_cast<int*>(_v)); break;
        case 13: _t->setCompositingEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setCursorSize(*reinterpret_cast<int*>(_v)); break;
        case 16: _t->setZoneEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 17: _t->setDTKSizeMode(*reinterpret_cast<int*>(_v)); break;
        case 18: _t->setScrollBarPolicy(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PersonalizationDBusProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PersonalizationDBusProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24PersonalizationDBusProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PersonalizationDBusProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 44)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 44;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void PersonalizationDBusProxy::Changed(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void PersonalizationDBusProxy::Refreshed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PersonalizationDBusProxy::BackgroundChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< PersonalizationDBusProxy *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PersonalizationDBusProxy::CursorThemeChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< PersonalizationDBusProxy *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void PersonalizationDBusProxy::FontSizeChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< PersonalizationDBusProxy *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void PersonalizationDBusProxy::GtkThemeChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< PersonalizationDBusProxy *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void PersonalizationDBusProxy::IconThemeChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< PersonalizationDBusProxy *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void PersonalizationDBusProxy::GlobalThemeChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< PersonalizationDBusProxy *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void PersonalizationDBusProxy::MonospaceFontChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< PersonalizationDBusProxy *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void PersonalizationDBusProxy::OpacityChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< PersonalizationDBusProxy *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void PersonalizationDBusProxy::QtActiveColorChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< PersonalizationDBusProxy *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void PersonalizationDBusProxy::StandardFontChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< PersonalizationDBusProxy *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void PersonalizationDBusProxy::WallpaperSlideShowChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< PersonalizationDBusProxy *>(this), &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void PersonalizationDBusProxy::WindowRadiusChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< PersonalizationDBusProxy *>(this), &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void PersonalizationDBusProxy::WMChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void PersonalizationDBusProxy::compositingAllowSwitchChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< PersonalizationDBusProxy *>(this), &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void PersonalizationDBusProxy::compositingEnabledChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< PersonalizationDBusProxy *>(this), &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void PersonalizationDBusProxy::compositingPossibleChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< PersonalizationDBusProxy *>(this), &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void PersonalizationDBusProxy::cursorSizeChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< PersonalizationDBusProxy *>(this), &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void PersonalizationDBusProxy::ZoneEnabledChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< PersonalizationDBusProxy *>(this), &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void PersonalizationDBusProxy::DTKSizeModeChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< PersonalizationDBusProxy *>(this), &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void PersonalizationDBusProxy::scrollBarPolicyChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< PersonalizationDBusProxy *>(this), &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void PersonalizationDBusProxy::WallpaperURlsChanged(QString _t1)const
{
    QMetaObject::activate<void>(const_cast< PersonalizationDBusProxy *>(this), &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void PersonalizationDBusProxy::allscreensaverChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void PersonalizationDBusProxy::currentScreenSaverChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void PersonalizationDBusProxy::lockScreenAtAwakeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}

// SIGNAL 26
void PersonalizationDBusProxy::linePowerScreenSaverTimeoutChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void PersonalizationDBusProxy::batteryScreenSaverTimeoutChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1);
}

// SIGNAL 28
void PersonalizationDBusProxy::WallpaperChanged(const QString & _t1, uint _t2, const QStringList & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1, _t2, _t3);
}

// SIGNAL 29
void PersonalizationDBusProxy::OnBatteryChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 29, nullptr, _t1);
}
QT_WARNING_POP
