/****************************************************************************
** Meta object code from reading C++ file 'accountscontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-accounts/operation/accountscontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'accountscontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6dccV2518AccountsControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::AccountsController::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV2518AccountsControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::AccountsController",
        "currentUserNameChanged",
        "",
        "userIdListChanged",
        "userRemoved",
        "userId",
        "onlineUserListChanged",
        "avatarChanged",
        "avatar",
        "userTypeChanged",
        "userType",
        "fullnameChanged",
        "fullname",
        "autoLoginChanged",
        "enable",
        "quickLoginChanged",
        "nopasswdLoginChanged",
        "passwordAgeChanged",
        "age",
        "passwordModifyFinished",
        "exitCode",
        "msg",
        "groupsChanged",
        "groups",
        "groupsUpdate",
        "groupsUpdateFailed",
        "groupName",
        "requestCreateGroup",
        "requestClearEmptyGroup",
        "showSafetyPage",
        "errorTips",
        "accountCreationFinished",
        "CreationResult::ResultType",
        "resultType",
        "message",
        "currentUserId",
        "curUserIsSysAdmin",
        "id",
        "setAvatar",
        "url",
        "avatars",
        "filter",
        "section",
        "userName",
        "fullName",
        "setFullname",
        "name",
        "setUserType",
        "index",
        "userTypeName",
        "userTypes",
        "createUser",
        "isDeleteAble",
        "isAutoLoginVisable",
        "autoLogin",
        "setAutoLogin",
        "getOtherUserAutoLogin",
        "isQuickLoginVisible",
        "quickLogin",
        "setQuickLogin",
        "isNoPassWordLoginVisable",
        "nopasswdLogin",
        "setNopasswdLogin",
        "isOnline",
        "needShowGroups",
        "allGroups",
        "updateGroups",
        "updateAllGroups",
        "setGroup",
        "group",
        "on",
        "groupContains",
        "groupEnabled",
        "groupEditAble",
        "groupExists",
        "createGroup",
        "deleteGroup",
        "modifyGroup",
        "oldName",
        "newName",
        "addUser",
        "QVariantMap",
        "userInfo",
        "removeUser",
        "deleteHome",
        "setPassword",
        "info",
        "setPasswordHint",
        "pwdHint",
        "passwordAge",
        "setPasswordAge",
        "avatarFilterModel",
        "QSortFilterProxyModel*",
        "avatarTypesModel",
        "QAbstractListModel*",
        "accountsModel",
        "groupsModel",
        "passwordLevel",
        "pwd",
        "checkUsername",
        "checkFullname",
        "checkPassword",
        "checkPasswordResult",
        "code",
        "showDefender",
        "playSystemSound",
        "soundType",
        "updateSingleUserGroups",
        "currentUserName",
        "userIdList",
        "onlineUserList"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentUserNameChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'userIdListChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'userRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'onlineUserListChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'avatarChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'userTypeChanged'
        QtMocHelpers::SignalData<void(const QString &, const int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Int, 10 },
        }}),
        // Signal 'fullnameChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 12 },
        }}),
        // Signal 'autoLoginChanged'
        QtMocHelpers::SignalData<void(const QString &, bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Bool, 14 },
        }}),
        // Signal 'quickLoginChanged'
        QtMocHelpers::SignalData<void(const QString &, bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Bool, 14 },
        }}),
        // Signal 'nopasswdLoginChanged'
        QtMocHelpers::SignalData<void(const QString &, bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Bool, 14 },
        }}),
        // Signal 'passwordAgeChanged'
        QtMocHelpers::SignalData<void(const QString &, const int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Int, 18 },
        }}),
        // Signal 'passwordModifyFinished'
        QtMocHelpers::SignalData<void(const QString &, const int, const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Int, 20 }, { QMetaType::QString, 21 },
        }}),
        // Signal 'groupsChanged'
        QtMocHelpers::SignalData<void(const QString &, const QStringList &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QStringList, 23 },
        }}),
        // Signal 'groupsUpdate'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'groupsUpdateFailed'
        QtMocHelpers::SignalData<void(const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Signal 'requestCreateGroup'
        QtMocHelpers::SignalData<void(const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'requestClearEmptyGroup'
        QtMocHelpers::SignalData<void(const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'showSafetyPage'
        QtMocHelpers::SignalData<void(const QString &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
        // Signal 'accountCreationFinished'
        QtMocHelpers::SignalData<void(CreationResult::ResultType, const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 }, { QMetaType::QString, 34 },
        }}),
        // Slot 'currentUserId'
        QtMocHelpers::SlotData<QString() const>(35, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'curUserIsSysAdmin'
        QtMocHelpers::SlotData<bool() const>(36, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'avatar'
        QtMocHelpers::SlotData<QString(const QString &) const>(8, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'setAvatar'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 }, { QMetaType::QString, 39 },
        }}),
        // Slot 'avatars'
        QtMocHelpers::SlotData<QStringList(const QString &, const QString &, const QString &)>(40, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 37 }, { QMetaType::QString, 41 }, { QMetaType::QString, 42 },
        }}),
        // Slot 'userName'
        QtMocHelpers::SlotData<QString(const QString &) const>(43, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'fullName'
        QtMocHelpers::SlotData<QString(const QString &) const>(44, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'setFullname'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 }, { QMetaType::QString, 46 },
        }}),
        // Slot 'userType'
        QtMocHelpers::SlotData<int(const QString &) const>(10, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'setUserType'
        QtMocHelpers::SlotData<void(const QString &, int)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 }, { QMetaType::Int, 48 },
        }}),
        // Slot 'userTypeName'
        QtMocHelpers::SlotData<QString(const QString &) const>(49, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'userTypes'
        QtMocHelpers::SlotData<QStringList(bool) const>(50, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::Bool, 51 },
        }}),
        // Slot 'userTypes'
        QtMocHelpers::SlotData<QStringList() const>(50, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QStringList),
        // Slot 'isDeleteAble'
        QtMocHelpers::SlotData<bool(const QString &) const>(52, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'isAutoLoginVisable'
        QtMocHelpers::SlotData<bool() const>(53, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'autoLogin'
        QtMocHelpers::SlotData<bool(const QString &) const>(54, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'setAutoLogin'
        QtMocHelpers::SlotData<void(const QString &, const bool)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 }, { QMetaType::Bool, 14 },
        }}),
        // Slot 'getOtherUserAutoLogin'
        QtMocHelpers::SlotData<QString() const>(56, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'isQuickLoginVisible'
        QtMocHelpers::SlotData<bool() const>(57, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'quickLogin'
        QtMocHelpers::SlotData<bool(const QString &) const>(58, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'setQuickLogin'
        QtMocHelpers::SlotData<void(const QString &, const bool)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 }, { QMetaType::Bool, 14 },
        }}),
        // Slot 'isNoPassWordLoginVisable'
        QtMocHelpers::SlotData<bool() const>(60, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'nopasswdLogin'
        QtMocHelpers::SlotData<bool(const QString &)>(61, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'setNopasswdLogin'
        QtMocHelpers::SlotData<void(const QString &, const bool)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 }, { QMetaType::Bool, 14 },
        }}),
        // Slot 'isOnline'
        QtMocHelpers::SlotData<bool(const QString &)>(63, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'needShowGroups'
        QtMocHelpers::SlotData<bool()>(64, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'allGroups'
        QtMocHelpers::SlotData<QStringList() const>(65, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'groups'
        QtMocHelpers::SlotData<QStringList(const QString &)>(23, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'updateGroups'
        QtMocHelpers::SlotData<void(const QString &)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'updateAllGroups'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setGroup'
        QtMocHelpers::SlotData<void(const QString &, const QString &, bool)>(68, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 }, { QMetaType::QString, 69 }, { QMetaType::Bool, 70 },
        }}),
        // Slot 'groupContains'
        QtMocHelpers::SlotData<bool(const QString &, const QString &) const>(71, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 37 }, { QMetaType::QString, 46 },
        }}),
        // Slot 'groupEnabled'
        QtMocHelpers::SlotData<bool(const QString &, const QString &) const>(72, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 37 }, { QMetaType::QString, 46 },
        }}),
        // Slot 'groupEditAble'
        QtMocHelpers::SlotData<bool(const QString &, const QString &) const>(73, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 37 }, { QMetaType::QString, 46 },
        }}),
        // Slot 'groupExists'
        QtMocHelpers::SlotData<bool(const QString &) const>(74, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 46 },
        }}),
        // Slot 'createGroup'
        QtMocHelpers::SlotData<void(const QString &)>(75, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 46 },
        }}),
        // Slot 'deleteGroup'
        QtMocHelpers::SlotData<void(const QString &)>(76, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 46 },
        }}),
        // Slot 'modifyGroup'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(77, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 78 }, { QMetaType::QString, 79 },
        }}),
        // Slot 'addUser'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(80, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 81, 82 },
        }}),
        // Slot 'removeUser'
        QtMocHelpers::SlotData<void(const QString &, const bool)>(83, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 }, { QMetaType::Bool, 84 },
        }}),
        // Slot 'setPassword'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &)>(85, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 }, { 0x80000000 | 81, 86 },
        }}),
        // Slot 'setPasswordHint'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(87, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 }, { QMetaType::QString, 88 },
        }}),
        // Slot 'passwordAge'
        QtMocHelpers::SlotData<int(const QString &) const>(89, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'setPasswordAge'
        QtMocHelpers::SlotData<void(const QString &, const int)>(90, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 }, { QMetaType::Int, 18 },
        }}),
        // Slot 'avatarFilterModel'
        QtMocHelpers::SlotData<QSortFilterProxyModel *()>(91, 2, QMC::AccessPublic, 0x80000000 | 92),
        // Slot 'avatarTypesModel'
        QtMocHelpers::SlotData<QAbstractListModel *()>(93, 2, QMC::AccessPublic, 0x80000000 | 94),
        // Slot 'accountsModel'
        QtMocHelpers::SlotData<QAbstractListModel *()>(95, 2, QMC::AccessPublic, 0x80000000 | 94),
        // Slot 'groupsModel'
        QtMocHelpers::SlotData<QAbstractListModel *(const QString &)>(96, 2, QMC::AccessPublic, 0x80000000 | 94, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'passwordLevel'
        QtMocHelpers::SlotData<int(const QString &)>(97, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 98 },
        }}),
        // Slot 'checkUsername'
        QtMocHelpers::SlotData<QString(const QString &)>(99, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 46 },
        }}),
        // Slot 'checkFullname'
        QtMocHelpers::SlotData<QString(const QString &)>(100, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 46 },
        }}),
        // Slot 'checkPassword'
        QtMocHelpers::SlotData<QString(const QString &, const QString &)>(101, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 46 }, { QMetaType::QString, 98 },
        }}),
        // Slot 'checkPasswordResult'
        QtMocHelpers::SlotData<QVariantMap(int, const QString &, const QString &, const QString &)>(102, 2, QMC::AccessPublic, 0x80000000 | 81, {{
            { QMetaType::Int, 103 }, { QMetaType::QString, 21 }, { QMetaType::QString, 46 }, { QMetaType::QString, 98 },
        }}),
        // Slot 'showDefender'
        QtMocHelpers::SlotData<void()>(104, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'playSystemSound'
        QtMocHelpers::SlotData<void(int)>(105, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 106 },
        }}),
        // Slot 'updateSingleUserGroups'
        QtMocHelpers::SlotData<void(const QString &)>(107, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'currentUserName'
        QtMocHelpers::PropertyData<QString>(108, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 0),
        // property 'userIdList'
        QtMocHelpers::PropertyData<QStringList>(109, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Final, 1),
        // property 'onlineUserList'
        QtMocHelpers::PropertyData<QStringList>(110, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Final, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AccountsController, qt_meta_tag_ZN6dccV2518AccountsControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dccV25::AccountsController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2518AccountsControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2518AccountsControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV2518AccountsControllerE_t>.metaTypes,
    nullptr
} };

void dccV25::AccountsController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AccountsController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentUserNameChanged(); break;
        case 1: _t->userIdListChanged(); break;
        case 2: _t->userRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->onlineUserListChanged(); break;
        case 4: _t->avatarChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->userTypeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 6: _t->fullnameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->autoLoginChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: _t->quickLoginChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 9: _t->nopasswdLoginChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 10: _t->passwordAgeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 11: _t->passwordModifyFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 12: _t->groupsChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 13: _t->groupsUpdate(); break;
        case 14: _t->groupsUpdateFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->requestCreateGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->requestClearEmptyGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->showSafetyPage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->accountCreationFinished((*reinterpret_cast<std::add_pointer_t<CreationResult::ResultType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 19: { QString _r = _t->currentUserId();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 20: { bool _r = _t->curUserIsSysAdmin();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 21: { QString _r = _t->avatar((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->setAvatar((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 23: { QStringList _r = _t->avatars((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 24: { QString _r = _t->userName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 25: { QString _r = _t->fullName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->setFullname((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 27: { int _r = _t->userType((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 28: _t->setUserType((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 29: { QString _r = _t->userTypeName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 30: { QStringList _r = _t->userTypes((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 31: { QStringList _r = _t->userTypes();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 32: { bool _r = _t->isDeleteAble((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 33: { bool _r = _t->isAutoLoginVisable();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 34: { bool _r = _t->autoLogin((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 35: _t->setAutoLogin((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 36: { QString _r = _t->getOtherUserAutoLogin();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 37: { bool _r = _t->isQuickLoginVisible();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 38: { bool _r = _t->quickLogin((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 39: _t->setQuickLogin((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 40: { bool _r = _t->isNoPassWordLoginVisable();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 41: { bool _r = _t->nopasswdLogin((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 42: _t->setNopasswdLogin((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 43: { bool _r = _t->isOnline((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 44: { bool _r = _t->needShowGroups();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 45: { QStringList _r = _t->allGroups();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 46: { QStringList _r = _t->groups((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 47: _t->updateGroups((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 48: _t->updateAllGroups(); break;
        case 49: _t->setGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 50: { bool _r = _t->groupContains((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 51: { bool _r = _t->groupEnabled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 52: { bool _r = _t->groupEditAble((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 53: { bool _r = _t->groupExists((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 54: _t->createGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 55: _t->deleteGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 56: _t->modifyGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 57: _t->addUser((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 58: _t->removeUser((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 59: _t->setPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 60: _t->setPasswordHint((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 61: { int _r = _t->passwordAge((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 62: _t->setPasswordAge((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 63: { QSortFilterProxyModel* _r = _t->avatarFilterModel();
            if (_a[0]) *reinterpret_cast<QSortFilterProxyModel**>(_a[0]) = std::move(_r); }  break;
        case 64: { QAbstractListModel* _r = _t->avatarTypesModel();
            if (_a[0]) *reinterpret_cast<QAbstractListModel**>(_a[0]) = std::move(_r); }  break;
        case 65: { QAbstractListModel* _r = _t->accountsModel();
            if (_a[0]) *reinterpret_cast<QAbstractListModel**>(_a[0]) = std::move(_r); }  break;
        case 66: { QAbstractListModel* _r = _t->groupsModel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QAbstractListModel**>(_a[0]) = std::move(_r); }  break;
        case 67: { int _r = _t->passwordLevel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 68: { QString _r = _t->checkUsername((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 69: { QString _r = _t->checkFullname((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 70: { QString _r = _t->checkPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 71: { QVariantMap _r = _t->checkPasswordResult((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 72: _t->showDefender(); break;
        case 73: _t->playSystemSound((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 74: _t->updateSingleUserGroups((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AccountsController::*)()>(_a, &AccountsController::currentUserNameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsController::*)()>(_a, &AccountsController::userIdListChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsController::*)(const QString & )>(_a, &AccountsController::userRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsController::*)()>(_a, &AccountsController::onlineUserListChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsController::*)(const QString & , const QString & )>(_a, &AccountsController::avatarChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsController::*)(const QString & , const int )>(_a, &AccountsController::userTypeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsController::*)(const QString & , const QString & )>(_a, &AccountsController::fullnameChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsController::*)(const QString & , bool )>(_a, &AccountsController::autoLoginChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsController::*)(const QString & , bool )>(_a, &AccountsController::quickLoginChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsController::*)(const QString & , bool )>(_a, &AccountsController::nopasswdLoginChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsController::*)(const QString & , const int )>(_a, &AccountsController::passwordAgeChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsController::*)(const QString & , const int , const QString & )>(_a, &AccountsController::passwordModifyFinished, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsController::*)(const QString & , const QStringList & )>(_a, &AccountsController::groupsChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsController::*)()>(_a, &AccountsController::groupsUpdate, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsController::*)(const QString & )>(_a, &AccountsController::groupsUpdateFailed, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsController::*)(const QString & )>(_a, &AccountsController::requestCreateGroup, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsController::*)(const QString & )>(_a, &AccountsController::requestClearEmptyGroup, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsController::*)(const QString & )>(_a, &AccountsController::showSafetyPage, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsController::*)(CreationResult::ResultType , const QString & )>(_a, &AccountsController::accountCreationFinished, 18))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->currentUserName(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->userIdList(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->onlineUserList(); break;
        default: break;
        }
    }
}

const QMetaObject *dccV25::AccountsController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::AccountsController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2518AccountsControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dccV25::AccountsController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 75)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 75;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 75)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 75;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void dccV25::AccountsController::currentUserNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dccV25::AccountsController::userIdListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dccV25::AccountsController::userRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dccV25::AccountsController::onlineUserListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void dccV25::AccountsController::avatarChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void dccV25::AccountsController::userTypeChanged(const QString & _t1, const int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void dccV25::AccountsController::fullnameChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void dccV25::AccountsController::autoLoginChanged(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void dccV25::AccountsController::quickLoginChanged(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void dccV25::AccountsController::nopasswdLoginChanged(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void dccV25::AccountsController::passwordAgeChanged(const QString & _t1, const int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void dccV25::AccountsController::passwordModifyFinished(const QString & _t1, const int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2, _t3);
}

// SIGNAL 12
void dccV25::AccountsController::groupsChanged(const QString & _t1, const QStringList & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void dccV25::AccountsController::groupsUpdate()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void dccV25::AccountsController::groupsUpdateFailed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void dccV25::AccountsController::requestCreateGroup(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void dccV25::AccountsController::requestClearEmptyGroup(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void dccV25::AccountsController::showSafetyPage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void dccV25::AccountsController::accountCreationFinished(CreationResult::ResultType _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1, _t2);
}
QT_WARNING_POP
