/****************************************************************************
** Meta object code from reading C++ file 'commoninfoproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-commoninfo/operation/commoninfoproxy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'commoninfoproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15CommonInfoProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto CommonInfoProxy::qt_create_metaobjectdata<qt_meta_tag_ZN15CommonInfoProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CommonInfoProxy",
        "IsLoginChanged",
        "",
        "value",
        "DeviceUnlockedChanged",
        "DeveloperModeChanged",
        "EnableThemeChanged",
        "UpdatingChanged",
        "DefaultEntryChanged",
        "entry",
        "TimeoutChanged",
        "EnabledUsersChanged",
        "users",
        "BackgroundChanged",
        "AuthorizationStateChanged",
        "code",
        "LicenseStateChanged",
        "DeepinIdError",
        "msg",
        "resetEnableTheme",
        "resetGrubEditAuthEnabled",
        "IsLogin",
        "DeviceUnlocked",
        "EnableTheme",
        "Updating",
        "DefaultEntry",
        "Timeout",
        "EnabledUsers",
        "Background",
        "AuthorizationState",
        "LicenseState",
        "DeveloperMode"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'IsLoginChanged'
        QtMocHelpers::SignalData<void(const bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'DeviceUnlockedChanged'
        QtMocHelpers::SignalData<void(const bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'DeveloperModeChanged'
        QtMocHelpers::SignalData<void(const bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'EnableThemeChanged'
        QtMocHelpers::SignalData<void(const bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'UpdatingChanged'
        QtMocHelpers::SignalData<void(const bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'DefaultEntryChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'TimeoutChanged'
        QtMocHelpers::SignalData<void(const uint)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'EnabledUsersChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 12 },
        }}),
        // Signal 'BackgroundChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AuthorizationStateChanged'
        QtMocHelpers::SignalData<void(const int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Signal 'LicenseStateChanged'
        QtMocHelpers::SignalData<void(const int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Signal 'DeepinIdError'
        QtMocHelpers::SignalData<void(const int, const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::QString, 18 },
        }}),
        // Signal 'resetEnableTheme'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resetGrubEditAuthEnabled'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'IsLogin'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'DeviceUnlocked'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'EnableTheme'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'Updating'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'DefaultEntry'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'Timeout'
        QtMocHelpers::PropertyData<uint>(26, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'EnabledUsers'
        QtMocHelpers::PropertyData<QStringList>(27, QMetaType::QStringList, QMC::DefaultPropertyFlags, 7),
        // property 'Background'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'AuthorizationState'
        QtMocHelpers::PropertyData<int>(29, QMetaType::Int, QMC::DefaultPropertyFlags, 9),
        // property 'LicenseState'
        QtMocHelpers::PropertyData<int>(30, QMetaType::Int, QMC::DefaultPropertyFlags, 10),
        // property 'DeveloperMode'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CommonInfoProxy, qt_meta_tag_ZN15CommonInfoProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CommonInfoProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CommonInfoProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CommonInfoProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15CommonInfoProxyE_t>.metaTypes,
    nullptr
} };

void CommonInfoProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CommonInfoProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->IsLoginChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->DeviceUnlockedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->DeveloperModeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->EnableThemeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->UpdatingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->DefaultEntryChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->TimeoutChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 7: _t->EnabledUsersChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 8: _t->BackgroundChanged(); break;
        case 9: _t->AuthorizationStateChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->LicenseStateChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->DeepinIdError((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 12: _t->resetEnableTheme(); break;
        case 13: _t->resetGrubEditAuthEnabled(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CommonInfoProxy::*)(const bool )>(_a, &CommonInfoProxy::IsLoginChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoProxy::*)(const bool )>(_a, &CommonInfoProxy::DeviceUnlockedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoProxy::*)(const bool )>(_a, &CommonInfoProxy::DeveloperModeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoProxy::*)(const bool )>(_a, &CommonInfoProxy::EnableThemeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoProxy::*)(const bool )>(_a, &CommonInfoProxy::UpdatingChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoProxy::*)(const QString & )>(_a, &CommonInfoProxy::DefaultEntryChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoProxy::*)(const uint )>(_a, &CommonInfoProxy::TimeoutChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoProxy::*)(const QStringList & )>(_a, &CommonInfoProxy::EnabledUsersChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoProxy::*)()>(_a, &CommonInfoProxy::BackgroundChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoProxy::*)(const int )>(_a, &CommonInfoProxy::AuthorizationStateChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoProxy::*)(const int )>(_a, &CommonInfoProxy::LicenseStateChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoProxy::*)(const int , const QString & )>(_a, &CommonInfoProxy::DeepinIdError, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoProxy::*)()>(_a, &CommonInfoProxy::resetEnableTheme, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommonInfoProxy::*)()>(_a, &CommonInfoProxy::resetGrubEditAuthEnabled, 13))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->IsLogin(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->DeviceUnlocked(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->EnableTheme(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->Updating(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->DefaultEntry(); break;
        case 5: *reinterpret_cast<uint*>(_v) = _t->Timeout(); break;
        case 6: *reinterpret_cast<QStringList*>(_v) = _t->EnabledUsers(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->Background(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->AuthorizationState(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->LicenseState(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->DeveloperMode(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setEnableTheme(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setDefaultEntry(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setTimeout(*reinterpret_cast<uint*>(_v)); break;
        case 7: _t->setBackground(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *CommonInfoProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CommonInfoProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CommonInfoProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int CommonInfoProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void CommonInfoProxy::IsLoginChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void CommonInfoProxy::DeviceUnlockedChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void CommonInfoProxy::DeveloperModeChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void CommonInfoProxy::EnableThemeChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void CommonInfoProxy::UpdatingChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void CommonInfoProxy::DefaultEntryChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void CommonInfoProxy::TimeoutChanged(const uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void CommonInfoProxy::EnabledUsersChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void CommonInfoProxy::BackgroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void CommonInfoProxy::AuthorizationStateChanged(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void CommonInfoProxy::LicenseStateChanged(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void CommonInfoProxy::DeepinIdError(const int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}

// SIGNAL 12
void CommonInfoProxy::resetEnableTheme()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void CommonInfoProxy::resetGrubEditAuthEnabled()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}
QT_WARNING_POP
