// This file is autogenerated. Changes will be overwritten.
#include "MTJHVBGFB2/moc_systeminfodbusproxy.cpp"
#include "MTJHVBGFB2/moc_systeminfointeraction.cpp"
#include "MTJHVBGFB2/moc_systeminfomodel.cpp"
#include "MTJHVBGFB2/moc_systeminfowork.cpp"
