/****************************************************************************
** Meta object code from reading C++ file 'dccmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/dde-control-center/dccmanager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSet>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dccmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6dccV2510DccManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::DccManager::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV2510DccManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::DccManager",
        "activeItemChanged",
        "",
        "QQuickItem*",
        "item",
        "hideModuleChanged",
        "QSet<QString>",
        "hideModule",
        "object",
        "DccObject*",
        "name",
        "addObject",
        "obj",
        "removeObject",
        "showPage",
        "url",
        "cmd",
        "toBack",
        "mainWindow",
        "QWindow*",
        "navModel",
        "QAbstractItemModel*",
        "searchModel",
        "QSortFilterProxyModel*",
        "show",
        "showHelp",
        "search",
        "json",
        "searchProxy",
        "stop",
        "action",
        "GetAllModule",
        "saveSize",
        "waitShowPage",
        "QDBusMessage",
        "message",
        "clearShowParam",
        "tryShow",
        "doShowPage",
        "updateModuleConfig",
        "key",
        "onVisible",
        "visible",
        "onObjectAdded",
        "onObjectRemoved",
        "onObjectDisplayChanged",
        "addObjectToParent",
        "removeObjectFromParent",
        "clearData",
        "waitLoadFinished",
        "doGetAllModule",
        "currentObjects",
        "uosEdition",
        "DccApp::UosEdition",
        "productType",
        "Dtk::Core::DSysInfo::ProductType",
        "isTreeland"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'activeItemChanged'
        QtMocHelpers::SignalData<void(QQuickItem *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'hideModuleChanged'
        QtMocHelpers::SignalData<void(const QSet<QString> &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'object'
        QtMocHelpers::SlotData<DccObject *(const QString &)>(8, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'addObject'
        QtMocHelpers::SlotData<void(DccObject *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 12 },
        }}),
        // Slot 'removeObject'
        QtMocHelpers::SlotData<void(DccObject *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 12 },
        }}),
        // Slot 'removeObject'
        QtMocHelpers::SlotData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'showPage'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'showPage'
        QtMocHelpers::SlotData<void(DccObject *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 12 },
        }}),
        // Slot 'showPage'
        QtMocHelpers::SlotData<void(DccObject *, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 12 }, { QMetaType::QString, 16 },
        }}),
        // Slot 'toBack'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'mainWindow'
        QtMocHelpers::SlotData<QWindow *() const>(18, 2, QMC::AccessPublic, 0x80000000 | 19),
        // Slot 'navModel'
        QtMocHelpers::SlotData<QAbstractItemModel *() const>(20, 2, QMC::AccessPublic, 0x80000000 | 21),
        // Slot 'searchModel'
        QtMocHelpers::SlotData<QSortFilterProxyModel *() const>(22, 2, QMC::AccessPublic, 0x80000000 | 23),
        // Slot 'show'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showHelp'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'search'
        QtMocHelpers::SlotData<QString(const QString &) const>(26, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'searchProxy'
        QtMocHelpers::SlotData<QString(const QString &) const>(28, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'stop'
        QtMocHelpers::SlotData<bool(const QString &)>(29, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'action'
        QtMocHelpers::SlotData<bool(const QString &)>(30, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'GetAllModule'
        QtMocHelpers::SlotData<QString()>(31, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'saveSize'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'waitShowPage'
        QtMocHelpers::SlotData<void(const QString &, const QDBusMessage)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 15 }, { 0x80000000 | 34, 35 },
        }}),
        // Slot 'clearShowParam'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'tryShow'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'doShowPage'
        QtMocHelpers::SlotData<void(DccObject *, const QString &)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 12 }, { QMetaType::QString, 16 },
        }}),
        // Slot 'updateModuleConfig'
        QtMocHelpers::SlotData<void(const QString &)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 40 },
        }}),
        // Slot 'onVisible'
        QtMocHelpers::SlotData<void(bool)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Slot 'onObjectAdded'
        QtMocHelpers::SlotData<void(DccObject *)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 12 },
        }}),
        // Slot 'onObjectRemoved'
        QtMocHelpers::SlotData<void(DccObject *)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 12 },
        }}),
        // Slot 'onObjectDisplayChanged'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addObjectToParent'
        QtMocHelpers::SlotData<bool(DccObject *)>(46, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { 0x80000000 | 9, 12 },
        }}),
        // Slot 'removeObjectFromParent'
        QtMocHelpers::SlotData<bool(DccObject *)>(47, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { 0x80000000 | 9, 12 },
        }}),
        // Slot 'clearData'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'waitLoadFinished'
        QtMocHelpers::SlotData<void() const>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'doGetAllModule'
        QtMocHelpers::SlotData<void(const QDBusMessage) const>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Method 'currentObjects'
        QtMocHelpers::MethodData<void() const>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'uosEdition'
        QtMocHelpers::MethodData<DccApp::UosEdition() const>(52, 2, QMC::AccessPublic, 0x80000000 | 53),
        // Method 'productType'
        QtMocHelpers::MethodData<Dtk::Core::DSysInfo::ProductType() const>(54, 2, QMC::AccessPublic, 0x80000000 | 55),
        // Method 'isTreeland'
        QtMocHelpers::MethodData<bool() const>(56, 2, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DccManager, qt_meta_tag_ZN6dccV2510DccManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dccV25::DccManager::staticMetaObject = { {
    QMetaObject::SuperData::link<DccApp::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2510DccManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2510DccManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV2510DccManagerE_t>.metaTypes,
    nullptr
} };

void dccV25::DccManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DccManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activeItemChanged((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1]))); break;
        case 1: _t->hideModuleChanged((*reinterpret_cast<std::add_pointer_t<QSet<QString>>>(_a[1]))); break;
        case 2: { DccObject* _r = _t->object((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DccObject**>(_a[0]) = std::move(_r); }  break;
        case 3: _t->addObject((*reinterpret_cast<std::add_pointer_t<DccObject*>>(_a[1]))); break;
        case 4: _t->removeObject((*reinterpret_cast<std::add_pointer_t<DccObject*>>(_a[1]))); break;
        case 5: _t->removeObject((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->showPage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->showPage((*reinterpret_cast<std::add_pointer_t<DccObject*>>(_a[1]))); break;
        case 8: _t->showPage((*reinterpret_cast<std::add_pointer_t<DccObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->toBack(); break;
        case 10: { QWindow* _r = _t->mainWindow();
            if (_a[0]) *reinterpret_cast<QWindow**>(_a[0]) = std::move(_r); }  break;
        case 11: { QAbstractItemModel* _r = _t->navModel();
            if (_a[0]) *reinterpret_cast<QAbstractItemModel**>(_a[0]) = std::move(_r); }  break;
        case 12: { QSortFilterProxyModel* _r = _t->searchModel();
            if (_a[0]) *reinterpret_cast<QSortFilterProxyModel**>(_a[0]) = std::move(_r); }  break;
        case 13: _t->show(); break;
        case 14: _t->showHelp(); break;
        case 15: { QString _r = _t->search((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 16: { QString _r = _t->searchProxy((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->stop((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->action((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { QString _r = _t->GetAllModule();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->saveSize(); break;
        case 21: _t->waitShowPage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[2]))); break;
        case 22: _t->clearShowParam(); break;
        case 23: _t->tryShow(); break;
        case 24: _t->doShowPage((*reinterpret_cast<std::add_pointer_t<DccObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 25: _t->updateModuleConfig((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: _t->onVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->onObjectAdded((*reinterpret_cast<std::add_pointer_t<DccObject*>>(_a[1]))); break;
        case 28: _t->onObjectRemoved((*reinterpret_cast<std::add_pointer_t<DccObject*>>(_a[1]))); break;
        case 29: _t->onObjectDisplayChanged(); break;
        case 30: { bool _r = _t->addObjectToParent((*reinterpret_cast<std::add_pointer_t<DccObject*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 31: { bool _r = _t->removeObjectFromParent((*reinterpret_cast<std::add_pointer_t<DccObject*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 32: _t->clearData(); break;
        case 33: _t->waitLoadFinished(); break;
        case 34: _t->doGetAllModule((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        case 35: _t->currentObjects(); break;
        case 36: { DccApp::UosEdition _r = _t->uosEdition();
            if (_a[0]) *reinterpret_cast<DccApp::UosEdition*>(_a[0]) = std::move(_r); }  break;
        case 37: { Dtk::Core::DSysInfo::ProductType _r = _t->productType();
            if (_a[0]) *reinterpret_cast<Dtk::Core::DSysInfo::ProductType*>(_a[0]) = std::move(_r); }  break;
        case 38: { bool _r = _t->isTreeland();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickItem* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QString> >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DccObject* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DccObject* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DccObject* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DccObject* >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DccObject* >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DccObject* >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DccObject* >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DccObject* >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DccObject* >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DccManager::*)(QQuickItem * )>(_a, &DccManager::activeItemChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccManager::*)(const QSet<QString> & )>(_a, &DccManager::hideModuleChanged, 1))
            return;
    }
}

const QMetaObject *dccV25::DccManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::DccManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2510DccManagerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return DccApp::qt_metacast(_clname);
}

int dccV25::DccManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DccApp::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    return _id;
}

// SIGNAL 0
void dccV25::DccManager::activeItemChanged(QQuickItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dccV25::DccManager::hideModuleChanged(const QSet<QString> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
