/****************************************************************************
** Meta object code from reading C++ file 'personalizationworker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-personalization/operation/personalizationworker.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'personalizationworker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21PersonalizationWorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto PersonalizationWorker::qt_create_metaobjectdata<qt_meta_tag_ZN21PersonalizationWorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PersonalizationWorker",
        "personalizationChanged",
        "",
        "propertyName",
        "value",
        "setDiabledCompactToTitleHeight",
        "setScrollBarPolicy",
        "policy",
        "setCompactDisplay",
        "goDownloadTheme",
        "setActiveColors",
        "activeColors",
        "addCustomWallpaper",
        "url",
        "addSolidWallpaper",
        "QColor",
        "color",
        "deleteWallpaper",
        "str",
        "setScreenSaver",
        "setWallpaperSlideShow",
        "monitorName",
        "sliderShow",
        "startScreenSaverPreview",
        "stopScreenSaverPreview",
        "setLockScreenAtAwake",
        "setScreenSaverIdleTime",
        "setCurrentScreenSaverPicMode",
        "mode",
        "requestScreenSaverConfig",
        "name",
        "setDefaultByType",
        "type",
        "setDefault",
        "QJsonObject",
        "setFontSize",
        "pixelSize",
        "setOpacity",
        "opcaity",
        "setWindowEffect",
        "setMiniEffect",
        "effect",
        "setMovedWindowOpacity",
        "setActiveColor",
        "hexColor",
        "setWindowRadius",
        "radius",
        "setTitleBarHeight",
        "setGlobalTheme",
        "themeId",
        "setAppearanceTheme",
        "id",
        "keepAuto",
        "setIconTheme",
        "setCursorTheme",
        "setWallpaperForMonitor",
        "screen",
        "isDark",
        "PersonalizationExport::WallpaperSetOption",
        "option",
        "setBackgroundForMonitor",
        "screenName",
        "setLockBackForMonitor",
        "FontSizeChanged",
        "onGetFontFinished",
        "category",
        "json",
        "onGetThemeFinished",
        "onGetPicFinished",
        "onRefreshedChanged",
        "setFontList",
        "FontModel*",
        "model",
        "list",
        "onWindowRadiusChanged",
        "onCompactDisplayChanged",
        "onWindowEffectChanged",
        "onScreensChanged",
        "onCurrentScreenSaverChanged",
        "onLockScreenAtAwakeChanged",
        "onLinePowerScreenSaverTimeoutChanged",
        "onBatteryScreenSaverTimeoutChanged",
        "onWallpaperSlideShowChanged",
        "updateWallpaperSelected"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'personalizationChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'setDiabledCompactToTitleHeight'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setScrollBarPolicy'
        QtMocHelpers::SlotData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'setCompactDisplay'
        QtMocHelpers::SlotData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'goDownloadTheme'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setActiveColors'
        QtMocHelpers::SlotData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'addCustomWallpaper'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'addSolidWallpaper'
        QtMocHelpers::SlotData<void(const QColor &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'deleteWallpaper'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'setScreenSaver'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'setWallpaperSlideShow'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 22 },
        }}),
        // Slot 'startScreenSaverPreview'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stopScreenSaverPreview'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setLockScreenAtAwake'
        QtMocHelpers::SlotData<void(bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'setScreenSaverIdleTime'
        QtMocHelpers::SlotData<void(int)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'setCurrentScreenSaverPicMode'
        QtMocHelpers::SlotData<void(const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'requestScreenSaverConfig'
        QtMocHelpers::SlotData<void(const QString &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
        // Slot 'setDefaultByType'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'setDefault'
        QtMocHelpers::SlotData<void(const QJsonObject &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 4 },
        }}),
        // Slot 'setFontSize'
        QtMocHelpers::SlotData<void(const int)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 36 },
        }}),
        // Slot 'setOpacity'
        QtMocHelpers::SlotData<void(int)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 38 },
        }}),
        // Slot 'setWindowEffect'
        QtMocHelpers::SlotData<void(int)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'setMiniEffect'
        QtMocHelpers::SlotData<void(int)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 41 },
        }}),
        // Slot 'setMovedWindowOpacity'
        QtMocHelpers::SlotData<void(bool)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'setActiveColor'
        QtMocHelpers::SlotData<void(const QString &)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 44 },
        }}),
        // Slot 'setWindowRadius'
        QtMocHelpers::SlotData<void(int)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 46 },
        }}),
        // Slot 'setTitleBarHeight'
        QtMocHelpers::SlotData<void(int)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'setGlobalTheme'
        QtMocHelpers::SlotData<void(const QString &)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 49 },
        }}),
        // Slot 'setAppearanceTheme'
        QtMocHelpers::SlotData<void(const QString &, bool)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 51 }, { QMetaType::Bool, 52 },
        }}),
        // Slot 'setAppearanceTheme'
        QtMocHelpers::SlotData<void(const QString &)>(50, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 51 },
        }}),
        // Slot 'setIconTheme'
        QtMocHelpers::SlotData<void(const QString &)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 51 },
        }}),
        // Slot 'setCursorTheme'
        QtMocHelpers::SlotData<void(const QString &)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 51 },
        }}),
        // Slot 'setWallpaperForMonitor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, bool, PersonalizationExport::WallpaperSetOption)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 56 }, { QMetaType::QString, 13 }, { QMetaType::Bool, 57 }, { 0x80000000 | 58, 59 },
        }}),
        // Slot 'setBackgroundForMonitor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, bool)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 61 }, { QMetaType::QString, 13 }, { QMetaType::Bool, 57 },
        }}),
        // Slot 'setLockBackForMonitor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, bool)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 61 }, { QMetaType::QString, 13 }, { QMetaType::Bool, 57 },
        }}),
        // Slot 'FontSizeChanged'
        QtMocHelpers::SlotData<void(const double) const>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 4 },
        }}),
        // Slot 'onGetFontFinished'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(64, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 65 }, { QMetaType::QString, 66 },
        }}),
        // Slot 'onGetThemeFinished'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(67, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 65 }, { QMetaType::QString, 66 },
        }}),
        // Slot 'onGetPicFinished'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(68, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 65 }, { QMetaType::QString, 51 }, { QMetaType::QString, 66 },
        }}),
        // Slot 'onRefreshedChanged'
        QtMocHelpers::SlotData<void(const QString &)>(69, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 32 },
        }}),
        // Slot 'setFontList'
        QtMocHelpers::SlotData<void(FontModel *, const QString &, const QString &)>(70, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 71, 72 }, { QMetaType::QString, 32 }, { QMetaType::QString, 73 },
        }}),
        // Slot 'onWindowRadiusChanged'
        QtMocHelpers::SlotData<void(int)>(74, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'onCompactDisplayChanged'
        QtMocHelpers::SlotData<void(int)>(75, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'onWindowEffectChanged'
        QtMocHelpers::SlotData<void(int)>(76, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'onScreensChanged'
        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onCurrentScreenSaverChanged'
        QtMocHelpers::SlotData<void(const QString &)>(78, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'onLockScreenAtAwakeChanged'
        QtMocHelpers::SlotData<void(bool)>(79, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'onLinePowerScreenSaverTimeoutChanged'
        QtMocHelpers::SlotData<void(int)>(80, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'onBatteryScreenSaverTimeoutChanged'
        QtMocHelpers::SlotData<void(int)>(81, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'onWallpaperSlideShowChanged'
        QtMocHelpers::SlotData<void()>(82, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateWallpaperSelected'
        QtMocHelpers::SlotData<void()>(83, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PersonalizationWorker, qt_meta_tag_ZN21PersonalizationWorkerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PersonalizationWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21PersonalizationWorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21PersonalizationWorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21PersonalizationWorkerE_t>.metaTypes,
    nullptr
} };

void PersonalizationWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PersonalizationWorker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->personalizationChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->setDiabledCompactToTitleHeight(); break;
        case 2: _t->setScrollBarPolicy((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->setCompactDisplay((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->goDownloadTheme(); break;
        case 5: _t->setActiveColors((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->addCustomWallpaper((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->addSolidWallpaper((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 8: _t->deleteWallpaper((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->setScreenSaver((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->setWallpaperSlideShow((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 11: _t->startScreenSaverPreview(); break;
        case 12: _t->stopScreenSaverPreview(); break;
        case 13: _t->setLockScreenAtAwake((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->setScreenSaverIdleTime((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->setCurrentScreenSaverPicMode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->requestScreenSaverConfig((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->setDefaultByType((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 18: _t->setDefault((*reinterpret_cast<std::add_pointer_t<QJsonObject>>(_a[1]))); break;
        case 19: _t->setFontSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->setOpacity((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->setWindowEffect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->setMiniEffect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 23: _t->setMovedWindowOpacity((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: _t->setActiveColor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->setWindowRadius((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->setTitleBarHeight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->setGlobalTheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->setAppearanceTheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 29: _t->setAppearanceTheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 30: _t->setIconTheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 31: _t->setCursorTheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 32: _t->setWallpaperForMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<PersonalizationExport::WallpaperSetOption>>(_a[4]))); break;
        case 33: _t->setBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 34: _t->setLockBackForMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 35: _t->FontSizeChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 36: _t->onGetFontFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 37: _t->onGetThemeFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 38: _t->onGetPicFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 39: _t->onRefreshedChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 40: _t->setFontList((*reinterpret_cast<std::add_pointer_t<FontModel*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 41: _t->onWindowRadiusChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 42: _t->onCompactDisplayChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 43: _t->onWindowEffectChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 44: _t->onScreensChanged(); break;
        case 45: _t->onCurrentScreenSaverChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 46: _t->onLockScreenAtAwakeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 47: _t->onLinePowerScreenSaverTimeoutChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 48: _t->onBatteryScreenSaverTimeoutChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 49: _t->onWallpaperSlideShowChanged(); break;
        case 50: _t->updateWallpaperSelected(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PersonalizationWorker::*)(const QString & , const QString & )>(_a, &PersonalizationWorker::personalizationChanged, 0))
            return;
    }
}

const QMetaObject *PersonalizationWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PersonalizationWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21PersonalizationWorkerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PersonalizationWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 51)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 51;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 51)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 51;
    }
    return _id;
}

// SIGNAL 0
void PersonalizationWorker::personalizationChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN22PersonalizationWatcherE_t {};
} // unnamed namespace

template <> constexpr inline auto PersonalizationWatcher::qt_create_metaobjectdata<qt_meta_tag_ZN22PersonalizationWatcherE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PersonalizationWatcher",
        "onShow",
        "",
        "json",
        "onList",
        "onGetFont",
        "onThumbnail",
        "errorSlot",
        "QDBusError",
        "err"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onShow'
        QtMocHelpers::SlotData<void(const QString &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'onList'
        QtMocHelpers::SlotData<void(const QString &)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'onGetFont'
        QtMocHelpers::SlotData<void(const QString &)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'onThumbnail'
        QtMocHelpers::SlotData<void(const QString &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'errorSlot'
        QtMocHelpers::SlotData<void(const QDBusError &)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PersonalizationWatcher, qt_meta_tag_ZN22PersonalizationWatcherE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PersonalizationWatcher::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22PersonalizationWatcherE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22PersonalizationWatcherE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22PersonalizationWatcherE_t>.metaTypes,
    nullptr
} };

void PersonalizationWatcher::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PersonalizationWatcher *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onShow((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->onList((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->onGetFont((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->onThumbnail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->errorSlot((*reinterpret_cast<std::add_pointer_t<QDBusError>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *PersonalizationWatcher::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PersonalizationWatcher::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22PersonalizationWatcherE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PersonalizationWatcher::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
