/****************************************************************************
** Meta object code from reading C++ file 'datetimedbusproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-datetime/operation/datetimedbusproxy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'datetimedbusproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17DatetimeDBusProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto DatetimeDBusProxy::qt_create_metaobjectdata<qt_meta_tag_ZN17DatetimeDBusProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DatetimeDBusProxy",
        "CanNTPChanged",
        "",
        "value",
        "DSTOffsetChanged",
        "LocalRTCChanged",
        "LongDateFormatChanged",
        "LongTimeFormatChanged",
        "NTPChanged",
        "NTPServerChanged",
        "ShortDateFormatChanged",
        "ShortTimeFormatChanged",
        "TimezoneChanged",
        "Use24HourFormatChanged",
        "UserTimezonesChanged",
        "WeekBeginsChanged",
        "WeekdayFormatChanged",
        "DecimalSymbolChanged",
        "DigitGroupingChanged",
        "DigitGroupingSymbolChanged",
        "CurrencySymbolChanged",
        "NegativeCurrencyFormatChanged",
        "PositiveCurrencyFormatChanged",
        "SetNTP",
        "useNTP",
        "receiver",
        "const char*",
        "member",
        "errorSlot",
        "SetDate",
        "year",
        "month",
        "day",
        "hour",
        "min",
        "sec",
        "nsec",
        "datetime",
        "DeleteUserTimezone",
        "zone",
        "AddUserTimezone",
        "GetSampleNTPServers",
        "GetZoneInfo",
        "ZoneInfo",
        "SetTimezone",
        "timezone",
        "SetNTPServer",
        "server",
        "message",
        "onPropertiesChanged",
        "QDBusMessage",
        "Use24HourFormat",
        "WeekdayFormat",
        "LongDateFormat",
        "ShortDateFormat",
        "LongTimeFormat",
        "ShortTimeFormat",
        "WeekBegins",
        "NTPServer",
        "Timezone",
        "NTP",
        "UserTimezones",
        "decimalSymbol",
        "digitGrouping",
        "digitGroupingSymbol",
        "currencySymbol",
        "negativeCurrencyFormat",
        "positiveCurrencyFormat"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'CanNTPChanged'
        QtMocHelpers::SignalData<void(bool) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'DSTOffsetChanged'
        QtMocHelpers::SignalData<void(int) const>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'LocalRTCChanged'
        QtMocHelpers::SignalData<void(bool) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'LongDateFormatChanged'
        QtMocHelpers::SignalData<void(int) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'LongTimeFormatChanged'
        QtMocHelpers::SignalData<void(int) const>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'NTPChanged'
        QtMocHelpers::SignalData<void(bool) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'NTPServerChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'ShortDateFormatChanged'
        QtMocHelpers::SignalData<void(int) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'ShortTimeFormatChanged'
        QtMocHelpers::SignalData<void(int) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'TimezoneChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'Use24HourFormatChanged'
        QtMocHelpers::SignalData<void(bool) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'UserTimezonesChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Signal 'WeekBeginsChanged'
        QtMocHelpers::SignalData<void(int) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'WeekdayFormatChanged'
        QtMocHelpers::SignalData<void(int) const>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'DecimalSymbolChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'DigitGroupingChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'DigitGroupingSymbolChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'CurrencySymbolChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'NegativeCurrencyFormatChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'PositiveCurrencyFormatChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'SetNTP'
        QtMocHelpers::SlotData<void(bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'SetNTP'
        QtMocHelpers::SlotData<void(bool, QObject *, const char *, const char *)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 }, { QMetaType::QObjectStar, 25 }, { 0x80000000 | 26, 27 }, { 0x80000000 | 26, 28 },
        }}),
        // Slot 'SetDate'
        QtMocHelpers::SlotData<void(int, int, int, int, int, int, int)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 30 }, { QMetaType::Int, 31 }, { QMetaType::Int, 32 }, { QMetaType::Int, 33 },
            { QMetaType::Int, 34 }, { QMetaType::Int, 35 }, { QMetaType::Int, 36 },
        }}),
        // Slot 'SetDate'
        QtMocHelpers::SlotData<void(const QDateTime &, QObject *, const char *)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 37 }, { QMetaType::QObjectStar, 25 }, { 0x80000000 | 26, 27 },
        }}),
        // Slot 'DeleteUserTimezone'
        QtMocHelpers::SlotData<void(const QString &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 39 },
        }}),
        // Slot 'AddUserTimezone'
        QtMocHelpers::SlotData<void(const QString &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 39 },
        }}),
        // Slot 'GetSampleNTPServers'
        QtMocHelpers::SlotData<QStringList()>(41, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'GetSampleNTPServers'
        QtMocHelpers::SlotData<bool(QObject *, const char *)>(41, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QObjectStar, 25 }, { 0x80000000 | 26, 27 },
        }}),
        // Slot 'GetZoneInfo'
        QtMocHelpers::SlotData<ZoneInfo(const QString &)>(42, 2, QMC::AccessPublic, 0x80000000 | 43, {{
            { QMetaType::QString, 39 },
        }}),
        // Slot 'GetZoneInfo'
        QtMocHelpers::SlotData<bool(const QString &, QObject *, const char *)>(42, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 39 }, { QMetaType::QObjectStar, 25 }, { 0x80000000 | 26, 27 },
        }}),
        // Slot 'SetTimezone'
        QtMocHelpers::SlotData<void(const QString &)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 45 },
        }}),
        // Slot 'SetNTPServer'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 47 }, { QMetaType::QString, 48 },
        }}),
        // Slot 'SetNTPServer'
        QtMocHelpers::SlotData<void(const QString &, const QString &, QObject *, const char *, const char *)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 47 }, { QMetaType::QString, 48 }, { QMetaType::QObjectStar, 25 }, { 0x80000000 | 26, 27 },
            { 0x80000000 | 26, 28 },
        }}),
        // Slot 'onPropertiesChanged'
        QtMocHelpers::SlotData<void(const QDBusMessage &)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 50, 48 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Use24HourFormat'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'WeekdayFormat'
        QtMocHelpers::PropertyData<int>(52, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'LongDateFormat'
        QtMocHelpers::PropertyData<int>(53, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'ShortDateFormat'
        QtMocHelpers::PropertyData<int>(54, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'LongTimeFormat'
        QtMocHelpers::PropertyData<int>(55, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'ShortTimeFormat'
        QtMocHelpers::PropertyData<int>(56, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'WeekBegins'
        QtMocHelpers::PropertyData<int>(57, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'NTPServer'
        QtMocHelpers::PropertyData<QString>(58, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'Timezone'
        QtMocHelpers::PropertyData<QString>(59, QMetaType::QString, QMC::DefaultPropertyFlags, 9),
        // property 'NTP'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'UserTimezones'
        QtMocHelpers::PropertyData<QStringList>(61, QMetaType::QStringList, QMC::DefaultPropertyFlags, 11),
        // property 'decimalSymbol'
        QtMocHelpers::PropertyData<QString>(62, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'digitGrouping'
        QtMocHelpers::PropertyData<QString>(63, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'digitGroupingSymbol'
        QtMocHelpers::PropertyData<QString>(64, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'currencySymbol'
        QtMocHelpers::PropertyData<QString>(65, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'negativeCurrencyFormat'
        QtMocHelpers::PropertyData<QString>(66, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'positiveCurrencyFormat'
        QtMocHelpers::PropertyData<QString>(67, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DatetimeDBusProxy, qt_meta_tag_ZN17DatetimeDBusProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DatetimeDBusProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DatetimeDBusProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DatetimeDBusProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17DatetimeDBusProxyE_t>.metaTypes,
    nullptr
} };

void DatetimeDBusProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DatetimeDBusProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->CanNTPChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->DSTOffsetChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->LocalRTCChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->LongDateFormatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->LongTimeFormatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->NTPChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->NTPServerChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->ShortDateFormatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->ShortTimeFormatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->TimezoneChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->Use24HourFormatChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->UserTimezonesChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 12: _t->WeekBeginsChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->WeekdayFormatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->DecimalSymbolChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->DigitGroupingChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->DigitGroupingSymbolChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->CurrencySymbolChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->NegativeCurrencyFormatChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->PositiveCurrencyFormatChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->SetNTP((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->SetNTP((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[4]))); break;
        case 22: _t->SetDate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7]))); break;
        case 23: _t->SetDate((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[3]))); break;
        case 24: _t->DeleteUserTimezone((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->AddUserTimezone((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: { QStringList _r = _t->GetSampleNTPServers();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->GetSampleNTPServers((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { ZoneInfo _r = _t->GetZoneInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<ZoneInfo*>(_a[0]) = std::move(_r); }  break;
        case 29: { bool _r = _t->GetZoneInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 30: _t->SetTimezone((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 31: _t->SetNTPServer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 32: _t->SetNTPServer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[5]))); break;
        case 33: _t->onPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DatetimeDBusProxy::*)(bool ) const>(_a, &DatetimeDBusProxy::CanNTPChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatetimeDBusProxy::*)(int ) const>(_a, &DatetimeDBusProxy::DSTOffsetChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatetimeDBusProxy::*)(bool ) const>(_a, &DatetimeDBusProxy::LocalRTCChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatetimeDBusProxy::*)(int ) const>(_a, &DatetimeDBusProxy::LongDateFormatChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatetimeDBusProxy::*)(int ) const>(_a, &DatetimeDBusProxy::LongTimeFormatChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatetimeDBusProxy::*)(bool ) const>(_a, &DatetimeDBusProxy::NTPChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatetimeDBusProxy::*)(const QString & ) const>(_a, &DatetimeDBusProxy::NTPServerChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatetimeDBusProxy::*)(int ) const>(_a, &DatetimeDBusProxy::ShortDateFormatChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatetimeDBusProxy::*)(int ) const>(_a, &DatetimeDBusProxy::ShortTimeFormatChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatetimeDBusProxy::*)(const QString & ) const>(_a, &DatetimeDBusProxy::TimezoneChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatetimeDBusProxy::*)(bool ) const>(_a, &DatetimeDBusProxy::Use24HourFormatChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatetimeDBusProxy::*)(const QStringList & ) const>(_a, &DatetimeDBusProxy::UserTimezonesChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatetimeDBusProxy::*)(int ) const>(_a, &DatetimeDBusProxy::WeekBeginsChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatetimeDBusProxy::*)(int ) const>(_a, &DatetimeDBusProxy::WeekdayFormatChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatetimeDBusProxy::*)(const QString & ) const>(_a, &DatetimeDBusProxy::DecimalSymbolChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatetimeDBusProxy::*)(const QString & ) const>(_a, &DatetimeDBusProxy::DigitGroupingChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatetimeDBusProxy::*)(const QString & ) const>(_a, &DatetimeDBusProxy::DigitGroupingSymbolChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatetimeDBusProxy::*)(const QString & ) const>(_a, &DatetimeDBusProxy::CurrencySymbolChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatetimeDBusProxy::*)(const QString & ) const>(_a, &DatetimeDBusProxy::NegativeCurrencyFormatChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatetimeDBusProxy::*)(const QString & ) const>(_a, &DatetimeDBusProxy::PositiveCurrencyFormatChanged, 19))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->use24HourFormat(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->weekdayFormat(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->longDateFormat(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->shortDateFormat(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->longTimeFormat(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->shortTimeFormat(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->weekBegins(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->nTPServer(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->timezone(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->nTP(); break;
        case 10: *reinterpret_cast<QStringList*>(_v) = _t->userTimezones(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->decimalSymbol(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->digitGrouping(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->digitGroupingSymbol(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->currencySymbol(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->negativeCurrencyFormat(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->positiveCurrencyFormat(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setUse24HourFormat(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setWeekdayFormat(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setLongDateFormat(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setShortDateFormat(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setLongTimeFormat(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setShortTimeFormat(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setWeekBegins(*reinterpret_cast<int*>(_v)); break;
        case 11: _t->setDecimalSymbol(*reinterpret_cast<QString*>(_v)); break;
        case 12: _t->setDigitGrouping(*reinterpret_cast<QString*>(_v)); break;
        case 13: _t->setDigitGroupingSymbol(*reinterpret_cast<QString*>(_v)); break;
        case 14: _t->setCurrencySymbol(*reinterpret_cast<QString*>(_v)); break;
        case 15: _t->setNegativeCurrencyFormat(*reinterpret_cast<QString*>(_v)); break;
        case 16: _t->setPositiveCurrencyFormat(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DatetimeDBusProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DatetimeDBusProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DatetimeDBusProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DatetimeDBusProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 34)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 34;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void DatetimeDBusProxy::CanNTPChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< DatetimeDBusProxy *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DatetimeDBusProxy::DSTOffsetChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< DatetimeDBusProxy *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DatetimeDBusProxy::LocalRTCChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< DatetimeDBusProxy *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DatetimeDBusProxy::LongDateFormatChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< DatetimeDBusProxy *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DatetimeDBusProxy::LongTimeFormatChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< DatetimeDBusProxy *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DatetimeDBusProxy::NTPChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< DatetimeDBusProxy *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DatetimeDBusProxy::NTPServerChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< DatetimeDBusProxy *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void DatetimeDBusProxy::ShortDateFormatChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< DatetimeDBusProxy *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void DatetimeDBusProxy::ShortTimeFormatChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< DatetimeDBusProxy *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void DatetimeDBusProxy::TimezoneChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< DatetimeDBusProxy *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void DatetimeDBusProxy::Use24HourFormatChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< DatetimeDBusProxy *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void DatetimeDBusProxy::UserTimezonesChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< DatetimeDBusProxy *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void DatetimeDBusProxy::WeekBeginsChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< DatetimeDBusProxy *>(this), &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void DatetimeDBusProxy::WeekdayFormatChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< DatetimeDBusProxy *>(this), &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void DatetimeDBusProxy::DecimalSymbolChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< DatetimeDBusProxy *>(this), &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void DatetimeDBusProxy::DigitGroupingChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< DatetimeDBusProxy *>(this), &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void DatetimeDBusProxy::DigitGroupingSymbolChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< DatetimeDBusProxy *>(this), &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void DatetimeDBusProxy::CurrencySymbolChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< DatetimeDBusProxy *>(this), &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void DatetimeDBusProxy::NegativeCurrencyFormatChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< DatetimeDBusProxy *>(this), &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void DatetimeDBusProxy::PositiveCurrencyFormatChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< DatetimeDBusProxy *>(this), &staticMetaObject, 19, nullptr, _t1);
}
QT_WARNING_POP
