/****************************************************************************
** Meta object code from reading C++ file 'bluetoothdbusproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-bluetooth/operation/bluetoothdbusproxy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bluetoothdbusproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18BluetoothDBusProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto BluetoothDBusProxy::qt_create_metaobjectdata<qt_meta_tag_ZN18BluetoothDBusProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BluetoothDBusProxy",
        "AdapterAdded",
        "",
        "adapterJSON",
        "AdapterRemoved",
        "AdapterPropertiesChanged",
        "DeviceAdded",
        "devJSON",
        "DeviceRemoved",
        "DevicePropertiesChanged",
        "Cancelled",
        "QDBusObjectPath",
        "device",
        "RequestAuthorization",
        "RequestConfirmation",
        "passkey",
        "RequestPasskey",
        "RequestPinCode",
        "DisplayPasskey",
        "entered",
        "DisplayPinCode",
        "pinCode",
        "StateChanged",
        "value",
        "TransportableChanged",
        "CanSendFileChanged",
        "DisplaySwitchChanged",
        "EnabledChanged",
        "ClearUnpairedDevice",
        "receiver",
        "const char*",
        "member",
        "SetAdapterPowered",
        "adapter",
        "powered",
        "errorSlot",
        "DisconnectDevice",
        "RemoveDevice",
        "ConnectDevice",
        "GetDevices",
        "GetAdapters",
        "SetAdapterAlias",
        "alias",
        "SetDeviceAlias",
        "RequestDiscovery",
        "Confirm",
        "accept",
        "SetAdapterDiscovering",
        "discovering",
        "SetAdapterDiscoverable",
        "discoverable",
        "State",
        "Transportable",
        "CanSendFile",
        "DisplaySwitch",
        "Enabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'AdapterAdded'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'AdapterRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'AdapterPropertiesChanged'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'DeviceAdded'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'DeviceRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'DevicePropertiesChanged'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'Cancelled'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'RequestAuthorization'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'RequestConfirmation'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::QString, 15 },
        }}),
        // Signal 'RequestPasskey'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'RequestPinCode'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'DisplayPasskey'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, uint, uint)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::UInt, 15 }, { QMetaType::UInt, 19 },
        }}),
        // Signal 'DisplayPinCode'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::QString, 21 },
        }}),
        // Signal 'StateChanged'
        QtMocHelpers::SignalData<void(uint) const>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 23 },
        }}),
        // Signal 'TransportableChanged'
        QtMocHelpers::SignalData<void(bool) const>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Signal 'CanSendFileChanged'
        QtMocHelpers::SignalData<void(bool) const>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Signal 'DisplaySwitchChanged'
        QtMocHelpers::SignalData<void(bool) const>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Signal 'EnabledChanged'
        QtMocHelpers::SignalData<void(bool) const>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'ClearUnpairedDevice'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ClearUnpairedDevice'
        QtMocHelpers::SlotData<void(QObject *, const char *)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 29 }, { 0x80000000 | 30, 31 },
        }}),
        // Slot 'SetAdapterPowered'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, bool)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 33 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'SetAdapterPowered'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, bool, QObject *, const char *, const char *)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 33 }, { QMetaType::Bool, 34 }, { QMetaType::QObjectStar, 29 }, { 0x80000000 | 30, 31 },
            { 0x80000000 | 30, 35 },
        }}),
        // Slot 'DisconnectDevice'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'RemoveDevice'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QDBusObjectPath &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 33 }, { 0x80000000 | 11, 12 },
        }}),
        // Slot 'ConnectDevice'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QDBusObjectPath &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 11, 33 },
        }}),
        // Slot 'GetDevices'
        QtMocHelpers::SlotData<QString(const QDBusObjectPath &)>(39, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 11, 33 },
        }}),
        // Slot 'GetDevices'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, QObject *, const char *)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 33 }, { QMetaType::QObjectStar, 29 }, { 0x80000000 | 30, 31 },
        }}),
        // Slot 'GetAdapters'
        QtMocHelpers::SlotData<QString()>(40, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'SetAdapterAlias'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QString &)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 33 }, { QMetaType::QString, 42 },
        }}),
        // Slot 'SetDeviceAlias'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QString &)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::QString, 42 },
        }}),
        // Slot 'RequestDiscovery'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 33 },
        }}),
        // Slot 'Confirm'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, bool)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::Bool, 46 },
        }}),
        // Slot 'SetAdapterDiscovering'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, bool)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 33 }, { QMetaType::Bool, 48 },
        }}),
        // Slot 'SetAdapterDiscoverable'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, bool)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 33 }, { QMetaType::Bool, 50 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'State'
        QtMocHelpers::PropertyData<uint>(51, QMetaType::UInt, QMC::DefaultPropertyFlags, 13),
        // property 'Transportable'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags, 14),
        // property 'CanSendFile'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags, 15),
        // property 'DisplaySwitch'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'Enabled'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags, 17),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BluetoothDBusProxy, qt_meta_tag_ZN18BluetoothDBusProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BluetoothDBusProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18BluetoothDBusProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18BluetoothDBusProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18BluetoothDBusProxyE_t>.metaTypes,
    nullptr
} };

void BluetoothDBusProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BluetoothDBusProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->AdapterAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->AdapterRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->AdapterPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->DeviceAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->DeviceRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->DevicePropertiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->Cancelled((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 7: _t->RequestAuthorization((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 8: _t->RequestConfirmation((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->RequestPasskey((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 10: _t->RequestPinCode((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 11: _t->DisplayPasskey((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3]))); break;
        case 12: _t->DisplayPinCode((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->StateChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 14: _t->TransportableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->CanSendFileChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->DisplaySwitchChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->EnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->ClearUnpairedDevice(); break;
        case 19: _t->ClearUnpairedDevice((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[2]))); break;
        case 20: _t->SetAdapterPowered((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 21: _t->SetAdapterPowered((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[5]))); break;
        case 22: _t->DisconnectDevice((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 23: _t->RemoveDevice((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 24: _t->ConnectDevice((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 25: { QString _r = _t->GetDevices((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->GetDevices((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[3]))); break;
        case 27: { QString _r = _t->GetAdapters();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 28: _t->SetAdapterAlias((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 29: _t->SetDeviceAlias((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 30: _t->RequestDiscovery((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 31: _t->Confirm((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 32: _t->SetAdapterDiscovering((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 33: _t->SetAdapterDiscoverable((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BluetoothDBusProxy::*)(const QString & )>(_a, &BluetoothDBusProxy::AdapterAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDBusProxy::*)(const QString & )>(_a, &BluetoothDBusProxy::AdapterRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDBusProxy::*)(const QString & )>(_a, &BluetoothDBusProxy::AdapterPropertiesChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDBusProxy::*)(const QString & )>(_a, &BluetoothDBusProxy::DeviceAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDBusProxy::*)(const QString & )>(_a, &BluetoothDBusProxy::DeviceRemoved, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDBusProxy::*)(const QString & )>(_a, &BluetoothDBusProxy::DevicePropertiesChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDBusProxy::*)(const QDBusObjectPath & )>(_a, &BluetoothDBusProxy::Cancelled, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDBusProxy::*)(const QDBusObjectPath & )>(_a, &BluetoothDBusProxy::RequestAuthorization, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDBusProxy::*)(const QDBusObjectPath & , const QString & )>(_a, &BluetoothDBusProxy::RequestConfirmation, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDBusProxy::*)(const QDBusObjectPath & )>(_a, &BluetoothDBusProxy::RequestPasskey, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDBusProxy::*)(const QDBusObjectPath & )>(_a, &BluetoothDBusProxy::RequestPinCode, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDBusProxy::*)(const QDBusObjectPath & , uint , uint )>(_a, &BluetoothDBusProxy::DisplayPasskey, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDBusProxy::*)(const QDBusObjectPath & , const QString & )>(_a, &BluetoothDBusProxy::DisplayPinCode, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDBusProxy::*)(uint ) const>(_a, &BluetoothDBusProxy::StateChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDBusProxy::*)(bool ) const>(_a, &BluetoothDBusProxy::TransportableChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDBusProxy::*)(bool ) const>(_a, &BluetoothDBusProxy::CanSendFileChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDBusProxy::*)(bool ) const>(_a, &BluetoothDBusProxy::DisplaySwitchChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDBusProxy::*)(bool ) const>(_a, &BluetoothDBusProxy::EnabledChanged, 17))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint*>(_v) = _t->state(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->transportable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->canSendFile(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->displaySwitch(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setDisplaySwitch(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *BluetoothDBusProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BluetoothDBusProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18BluetoothDBusProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BluetoothDBusProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void BluetoothDBusProxy::AdapterAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BluetoothDBusProxy::AdapterRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void BluetoothDBusProxy::AdapterPropertiesChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void BluetoothDBusProxy::DeviceAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void BluetoothDBusProxy::DeviceRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void BluetoothDBusProxy::DevicePropertiesChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void BluetoothDBusProxy::Cancelled(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void BluetoothDBusProxy::RequestAuthorization(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void BluetoothDBusProxy::RequestConfirmation(const QDBusObjectPath & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void BluetoothDBusProxy::RequestPasskey(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void BluetoothDBusProxy::RequestPinCode(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void BluetoothDBusProxy::DisplayPasskey(const QDBusObjectPath & _t1, uint _t2, uint _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2, _t3);
}

// SIGNAL 12
void BluetoothDBusProxy::DisplayPinCode(const QDBusObjectPath & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void BluetoothDBusProxy::StateChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< BluetoothDBusProxy *>(this), &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void BluetoothDBusProxy::TransportableChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< BluetoothDBusProxy *>(this), &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void BluetoothDBusProxy::CanSendFileChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< BluetoothDBusProxy *>(this), &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void BluetoothDBusProxy::DisplaySwitchChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< BluetoothDBusProxy *>(this), &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void BluetoothDBusProxy::EnabledChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< BluetoothDBusProxy *>(this), &staticMetaObject, 17, nullptr, _t1);
}
QT_WARNING_POP
