/****************************************************************************
** Meta object code from reading C++ file 'dccquickdbusinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/include/dccquickdbusinterface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dccquickdbusinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6dccV2521DccQuickDBusInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::DccQuickDBusInterface::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV2521DccQuickDBusInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::DccQuickDBusInterface",
        "QML.Element",
        "auto",
        "serviceChanged",
        "",
        "service",
        "pathChanged",
        "path",
        "interfaceChanged",
        "interface",
        "connectionChanged",
        "BusType",
        "connection",
        "suffixChanged",
        "suffix",
        "callWithCallback",
        "method",
        "QList<QVariant>",
        "args",
        "QJSValue",
        "member",
        "errorSlot",
        "inter",
        "SessionBus",
        "SystemBus"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'serviceChanged'
        QtMocHelpers::SignalData<void(const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'pathChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'interfaceChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'connectionChanged'
        QtMocHelpers::SignalData<void(const BusType &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'suffixChanged'
        QtMocHelpers::SignalData<void(const QString &)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'callWithCallback'
        QtMocHelpers::SlotData<bool(const QString &, const QList<QVariant> &, const QJSValue, const QJSValue)>(15, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 16 }, { 0x80000000 | 17, 18 }, { 0x80000000 | 19, 20 }, { 0x80000000 | 19, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'service'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'path'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'inter'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'connection'
        QtMocHelpers::PropertyData<enum BusType>(12, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'suffix'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'BusType'
        QtMocHelpers::EnumData<enum BusType>(11, 11, QMC::EnumFlags{}).add({
            {   23, BusType::SessionBus },
            {   24, BusType::SystemBus },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DccQuickDBusInterface, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject dccV25::DccQuickDBusInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2521DccQuickDBusInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2521DccQuickDBusInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV2521DccQuickDBusInterfaceE_t>.metaTypes,
    nullptr
} };

void dccV25::DccQuickDBusInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DccQuickDBusInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->serviceChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->pathChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->interfaceChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->connectionChanged((*reinterpret_cast<std::add_pointer_t<enum BusType>>(_a[1]))); break;
        case 4: _t->suffixChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: { bool _r = _t->callWithCallback((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DccQuickDBusInterface::*)(const QString & )>(_a, &DccQuickDBusInterface::serviceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccQuickDBusInterface::*)(const QString & )>(_a, &DccQuickDBusInterface::pathChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccQuickDBusInterface::*)(const QString & )>(_a, &DccQuickDBusInterface::interfaceChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccQuickDBusInterface::*)(const BusType & )>(_a, &DccQuickDBusInterface::connectionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccQuickDBusInterface::*)(const QString & )>(_a, &DccQuickDBusInterface::suffixChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->service(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->path(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->interface(); break;
        case 3: *reinterpret_cast<enum BusType*>(_v) = _t->connection(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->suffix(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setService(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setPath(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setInterface(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setConnection(*reinterpret_cast<enum BusType*>(_v)); break;
        case 4: _t->setSuffix(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *dccV25::DccQuickDBusInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::DccQuickDBusInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2521DccQuickDBusInterfaceE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int dccV25::DccQuickDBusInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void dccV25::DccQuickDBusInterface::serviceChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dccV25::DccQuickDBusInterface::pathChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dccV25::DccQuickDBusInterface::interfaceChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dccV25::DccQuickDBusInterface::connectionChanged(const BusType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dccV25::DccQuickDBusInterface::suffixChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
