/****************************************************************************
** Meta object code from reading C++ file 'displayworker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-display/operation/private/displayworker.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'displayworker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6dccV2513DisplayWorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::DisplayWorker::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV2513DisplayWorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::DisplayWorker",
        "requestUpdateModeList",
        "",
        "saveChanges",
        "switchMode",
        "mode",
        "name",
        "setPrimary",
        "setMonitorEnable",
        "Monitor*",
        "monitor",
        "enable",
        "applyChanges",
        "setColorTemperatureEnabled",
        "enabled",
        "setColorTemperature",
        "value",
        "SetMethodAdjustCCT",
        "setCustomColorTempTimePeriod",
        "timePeriod",
        "setMonitorRotate",
        "mon",
        "rotate",
        "setMonitorResolution",
        "setMonitorBrightness",
        "brightness",
        "setMonitorPosition",
        "QHash<Monitor*,std::pair<int,int>>",
        "monitorPosition",
        "setUiScale",
        "setIndividualScaling",
        "m",
        "scaling",
        "setNightMode",
        "nightmode",
        "setTouchScreenAssociation",
        "touchscreenUUID",
        "setMonitorResolutionBySize",
        "width",
        "height",
        "setAmbientLightAdjustBrightness",
        "setCurrentFillMode",
        "fillMode",
        "backupConfig",
        "clearBackup",
        "resetBackup",
        "onMonitorListChanged",
        "QList<QDBusObjectPath>",
        "mons",
        "onMonitorsBrightnessChanged",
        "BrightnessMap",
        "onGetScaleFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onGetScreenScalesFinished",
        "onWlMonitorListChanged",
        "updateWallpaper",
        "updateMonitorWallpaper"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestUpdateModeList'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveChanges'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'switchMode'
        QtMocHelpers::SlotData<void(const int, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'setPrimary'
        QtMocHelpers::SlotData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'setMonitorEnable'
        QtMocHelpers::SlotData<void(Monitor *, const bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::Bool, 11 },
        }}),
        // Slot 'applyChanges'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setColorTemperatureEnabled'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'setColorTemperature'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'SetMethodAdjustCCT'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'setCustomColorTempTimePeriod'
        QtMocHelpers::SlotData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'setMonitorRotate'
        QtMocHelpers::SlotData<void(Monitor *, const quint16)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 21 }, { QMetaType::UShort, 22 },
        }}),
        // Slot 'setMonitorResolution'
        QtMocHelpers::SlotData<void(Monitor *, const int)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 21 }, { QMetaType::Int, 5 },
        }}),
        // Slot 'setMonitorBrightness'
        QtMocHelpers::SlotData<void(Monitor *, const double)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 21 }, { QMetaType::Double, 25 },
        }}),
        // Slot 'setMonitorPosition'
        QtMocHelpers::SlotData<void(QHash<Monitor*,QPair<int,int>>)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'setUiScale'
        QtMocHelpers::SlotData<void(const double)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 16 },
        }}),
        // Slot 'setIndividualScaling'
        QtMocHelpers::SlotData<void(Monitor *, const double)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 31 }, { QMetaType::Double, 32 },
        }}),
        // Slot 'setNightMode'
        QtMocHelpers::SlotData<void(const bool)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 34 },
        }}),
        // Slot 'setTouchScreenAssociation'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 36 },
        }}),
        // Slot 'setMonitorResolutionBySize'
        QtMocHelpers::SlotData<void(Monitor *, const int, const int)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 21 }, { QMetaType::Int, 38 }, { QMetaType::Int, 39 },
        }}),
        // Slot 'setAmbientLightAdjustBrightness'
        QtMocHelpers::SlotData<void(bool)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'setCurrentFillMode'
        QtMocHelpers::SlotData<void(Monitor *, const QString)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 21 }, { QMetaType::QString, 42 },
        }}),
        // Slot 'backupConfig'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearBackup'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetBackup'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onMonitorListChanged'
        QtMocHelpers::SlotData<void(const QList<QDBusObjectPath> &)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 47, 48 },
        }}),
        // Slot 'onMonitorsBrightnessChanged'
        QtMocHelpers::SlotData<void(const BrightnessMap &)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 50, 25 },
        }}),
        // Slot 'onGetScaleFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 52, 53 },
        }}),
        // Slot 'onGetScreenScalesFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 52, 53 },
        }}),
        // Slot 'onWlMonitorListChanged'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateWallpaper'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateMonitorWallpaper'
        QtMocHelpers::SlotData<void(Monitor *)>(57, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DisplayWorker, qt_meta_tag_ZN6dccV2513DisplayWorkerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dccV25::DisplayWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2513DisplayWorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2513DisplayWorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV2513DisplayWorkerE_t>.metaTypes,
    nullptr
} };

void dccV25::DisplayWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DisplayWorker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestUpdateModeList(); break;
        case 1: _t->saveChanges(); break;
        case 2: _t->switchMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->setPrimary((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->setMonitorEnable((*reinterpret_cast<std::add_pointer_t<Monitor*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 5: _t->applyChanges(); break;
        case 6: _t->setColorTemperatureEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->setColorTemperature((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->SetMethodAdjustCCT((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->setCustomColorTempTimePeriod((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->setMonitorRotate((*reinterpret_cast<std::add_pointer_t<Monitor*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint16>>(_a[2]))); break;
        case 11: _t->setMonitorResolution((*reinterpret_cast<std::add_pointer_t<Monitor*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 12: _t->setMonitorBrightness((*reinterpret_cast<std::add_pointer_t<Monitor*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 13: _t->setMonitorPosition((*reinterpret_cast<std::add_pointer_t<QHash<Monitor*,std::pair<int,int>>>>(_a[1]))); break;
        case 14: _t->setUiScale((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 15: _t->setIndividualScaling((*reinterpret_cast<std::add_pointer_t<Monitor*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 16: _t->setNightMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->setTouchScreenAssociation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 18: _t->setMonitorResolutionBySize((*reinterpret_cast<std::add_pointer_t<Monitor*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 19: _t->setAmbientLightAdjustBrightness((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->setCurrentFillMode((*reinterpret_cast<std::add_pointer_t<Monitor*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 21: _t->backupConfig(); break;
        case 22: _t->clearBackup(); break;
        case 23: _t->resetBackup(); break;
        case 24: _t->onMonitorListChanged((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1]))); break;
        case 25: _t->onMonitorsBrightnessChanged((*reinterpret_cast<std::add_pointer_t<BrightnessMap>>(_a[1]))); break;
        case 26: _t->onGetScaleFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 27: _t->onGetScreenScalesFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 28: _t->onWlMonitorListChanged(); break;
        case 29: _t->updateWallpaper(); break;
        case 30: _t->updateMonitorWallpaper((*reinterpret_cast<std::add_pointer_t<Monitor*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Monitor* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Monitor* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Monitor* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Monitor* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Monitor* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Monitor* >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Monitor* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDBusObjectPath> >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Monitor* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DisplayWorker::*)()>(_a, &DisplayWorker::requestUpdateModeList, 0))
            return;
    }
}

const QMetaObject *dccV25::DisplayWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::DisplayWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2513DisplayWorkerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dccV25::DisplayWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    return _id;
}

// SIGNAL 0
void dccV25::DisplayWorker::requestUpdateModeList()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
