/****************************************************************************
** Meta object code from reading C++ file 'sounddbusproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-sound/operation/sounddbusproxy.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sounddbusproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14SoundDBusProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto SoundDBusProxy::qt_create_metaobjectdata<qt_meta_tag_ZN14SoundDBusProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SoundDBusProxy",
        "PortEnabledChanged",
        "",
        "in0",
        "in1",
        "in2",
        "BluetoothAudioModeChanged",
        "value",
        "BluetoothAudioModeOptsChanged",
        "CardsChanged",
        "CardsWithoutUnavailableChanged",
        "DefaultSinkChanged",
        "QDBusObjectPath",
        "DefaultSourceChanged",
        "IncreaseVolumeChanged",
        "MaxUIVolumeChanged",
        "ReduceNoiseChanged",
        "PausePlayerChanged",
        "SinkInputsChanged",
        "QList<QDBusObjectPath>",
        "SinksChanged",
        "SourcesChanged",
        "CurrentAudioServerChanged",
        "AudioServerStateChanged",
        "state",
        "EnabledChanged",
        "pendingCallWatcherFinished",
        "QMap<QString,bool>",
        "map",
        "HasBatteryChanged",
        "MuteSinkChanged",
        "BalanceSinkChanged",
        "BaseVolumeSinkChanged",
        "CardSinkChanged",
        "VolumeSinkChanged",
        "ActivePortSinkChanged",
        "AudioPort",
        "MuteSourceChanged",
        "VolumeSourceChanged",
        "ActivePortSourceChanged",
        "CardSourceChanged",
        "VolumeMeterChanged",
        "AudioMonoChanged",
        "MaxUIVolume",
        "IncreaseVolume",
        "ReduceNoise",
        "PausePlayer",
        "CurrentAudioServer",
        "AudioServerState",
        "BluetoothAudioMode",
        "BluetoothAudioModeOpts",
        "CardsWithoutUnavailable",
        "DefaultSource",
        "DefaultSink",
        "SinkInputs",
        "Sinks",
        "Sources",
        "MuteSink",
        "BalanceSink",
        "BaseVolumeSink",
        "CardSink",
        "VolumeSink",
        "ActivePortSink",
        "MuteSource",
        "CardSource",
        "VolumeSource",
        "ActivePortSource",
        "HasBattery",
        "Enabled",
        "VolumeMeter",
        "AudioMono"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'PortEnabledChanged'
        QtMocHelpers::SignalData<void(uint, const QString &, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::QString, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'BluetoothAudioModeChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'BluetoothAudioModeOptsChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 7 },
        }}),
        // Signal 'CardsChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'CardsWithoutUnavailableChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'DefaultSinkChanged'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 7 },
        }}),
        // Signal 'DefaultSourceChanged'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 7 },
        }}),
        // Signal 'IncreaseVolumeChanged'
        QtMocHelpers::SignalData<void(bool) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'MaxUIVolumeChanged'
        QtMocHelpers::SignalData<void(double) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 7 },
        }}),
        // Signal 'ReduceNoiseChanged'
        QtMocHelpers::SignalData<void(bool) const>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'PausePlayerChanged'
        QtMocHelpers::SignalData<void(bool) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'SinkInputsChanged'
        QtMocHelpers::SignalData<void(const QList<QDBusObjectPath> &) const>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 7 },
        }}),
        // Signal 'SinksChanged'
        QtMocHelpers::SignalData<void(const QList<QDBusObjectPath> &) const>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 7 },
        }}),
        // Signal 'SourcesChanged'
        QtMocHelpers::SignalData<void(const QList<QDBusObjectPath> &) const>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 7 },
        }}),
        // Signal 'CurrentAudioServerChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'AudioServerStateChanged'
        QtMocHelpers::SignalData<void(const bool) const>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Signal 'EnabledChanged'
        QtMocHelpers::SignalData<void(bool) const>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'pendingCallWatcherFinished'
        QtMocHelpers::SignalData<void(QMap<QString,bool>)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Signal 'HasBatteryChanged'
        QtMocHelpers::SignalData<void(bool) const>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'MuteSinkChanged'
        QtMocHelpers::SignalData<void(bool) const>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'BalanceSinkChanged'
        QtMocHelpers::SignalData<void(double) const>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 7 },
        }}),
        // Signal 'BaseVolumeSinkChanged'
        QtMocHelpers::SignalData<void(double) const>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 7 },
        }}),
        // Signal 'CardSinkChanged'
        QtMocHelpers::SignalData<void(uint) const>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 7 },
        }}),
        // Signal 'VolumeSinkChanged'
        QtMocHelpers::SignalData<void(double) const>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 7 },
        }}),
        // Signal 'ActivePortSinkChanged'
        QtMocHelpers::SignalData<void(AudioPort) const>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 7 },
        }}),
        // Signal 'MuteSourceChanged'
        QtMocHelpers::SignalData<void(bool) const>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'VolumeSourceChanged'
        QtMocHelpers::SignalData<void(double) const>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 7 },
        }}),
        // Signal 'ActivePortSourceChanged'
        QtMocHelpers::SignalData<void(AudioPort) const>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 7 },
        }}),
        // Signal 'CardSourceChanged'
        QtMocHelpers::SignalData<void(uint) const>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 7 },
        }}),
        // Signal 'VolumeMeterChanged'
        QtMocHelpers::SignalData<void(double) const>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 7 },
        }}),
        // Signal 'AudioMonoChanged'
        QtMocHelpers::SignalData<void(bool) const>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'MaxUIVolume'
        QtMocHelpers::PropertyData<double>(43, QMetaType::Double, QMC::DefaultPropertyFlags, 8),
        // property 'IncreaseVolume'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'ReduceNoise'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'PausePlayer'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'CurrentAudioServer'
        QtMocHelpers::PropertyData<QString>(47, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 14),
        // property 'AudioServerState'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags, 15),
        // property 'BluetoothAudioMode'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'BluetoothAudioModeOpts'
        QtMocHelpers::PropertyData<QStringList>(50, QMetaType::QStringList, QMC::DefaultPropertyFlags, 2),
        // property 'CardsWithoutUnavailable'
        QtMocHelpers::PropertyData<QString>(51, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'DefaultSource'
        QtMocHelpers::PropertyData<QDBusObjectPath>(52, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
        // property 'DefaultSink'
        QtMocHelpers::PropertyData<QDBusObjectPath>(53, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'SinkInputs'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(54, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 11),
        // property 'Sinks'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(55, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 12),
        // property 'Sources'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(56, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 13),
        // property 'MuteSink'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags, 19),
        // property 'BalanceSink'
        QtMocHelpers::PropertyData<double>(58, QMetaType::Double, QMC::DefaultPropertyFlags, 20),
        // property 'BaseVolumeSink'
        QtMocHelpers::PropertyData<double>(59, QMetaType::Double, QMC::DefaultPropertyFlags, 21),
        // property 'CardSink'
        QtMocHelpers::PropertyData<uint>(60, QMetaType::UInt, QMC::DefaultPropertyFlags, 22),
        // property 'VolumeSink'
        QtMocHelpers::PropertyData<double>(61, QMetaType::Double, QMC::DefaultPropertyFlags, 23),
        // property 'ActivePortSink'
        QtMocHelpers::PropertyData<AudioPort>(62, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 24),
        // property 'MuteSource'
        QtMocHelpers::PropertyData<bool>(63, QMetaType::Bool, QMC::DefaultPropertyFlags, 25),
        // property 'CardSource'
        QtMocHelpers::PropertyData<uint>(64, QMetaType::UInt, QMC::DefaultPropertyFlags, 28),
        // property 'VolumeSource'
        QtMocHelpers::PropertyData<double>(65, QMetaType::Double, QMC::DefaultPropertyFlags, 26),
        // property 'ActivePortSource'
        QtMocHelpers::PropertyData<AudioPort>(66, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 27),
        // property 'HasBattery'
        QtMocHelpers::PropertyData<bool>(67, QMetaType::Bool, QMC::DefaultPropertyFlags, 18),
        // property 'Enabled'
        QtMocHelpers::PropertyData<bool>(68, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'VolumeMeter'
        QtMocHelpers::PropertyData<double>(69, QMetaType::Double, QMC::DefaultPropertyFlags, 29),
        // property 'AudioMono'
        QtMocHelpers::PropertyData<bool>(70, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 30),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SoundDBusProxy, qt_meta_tag_ZN14SoundDBusProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SoundDBusProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SoundDBusProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SoundDBusProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14SoundDBusProxyE_t>.metaTypes,
    nullptr
} };

void SoundDBusProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SoundDBusProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->PortEnabledChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 1: _t->BluetoothAudioModeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->BluetoothAudioModeOptsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 3: _t->CardsChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->CardsWithoutUnavailableChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->DefaultSinkChanged((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 6: _t->DefaultSourceChanged((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 7: _t->IncreaseVolumeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->MaxUIVolumeChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 9: _t->ReduceNoiseChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->PausePlayerChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->SinkInputsChanged((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1]))); break;
        case 12: _t->SinksChanged((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1]))); break;
        case 13: _t->SourcesChanged((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1]))); break;
        case 14: _t->CurrentAudioServerChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->AudioServerStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->EnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->pendingCallWatcherFinished((*reinterpret_cast<std::add_pointer_t<QMap<QString,bool>>>(_a[1]))); break;
        case 18: _t->HasBatteryChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->MuteSinkChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->BalanceSinkChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 21: _t->BaseVolumeSinkChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 22: _t->CardSinkChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 23: _t->VolumeSinkChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 24: _t->ActivePortSinkChanged((*reinterpret_cast<std::add_pointer_t<AudioPort>>(_a[1]))); break;
        case 25: _t->MuteSourceChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->VolumeSourceChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 27: _t->ActivePortSourceChanged((*reinterpret_cast<std::add_pointer_t<AudioPort>>(_a[1]))); break;
        case 28: _t->CardSourceChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 29: _t->VolumeMeterChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 30: _t->AudioMonoChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDBusObjectPath> >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDBusObjectPath> >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDBusObjectPath> >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AudioPort >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AudioPort >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(uint , const QString & , bool )>(_a, &SoundDBusProxy::PortEnabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(const QString & ) const>(_a, &SoundDBusProxy::BluetoothAudioModeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(const QStringList & ) const>(_a, &SoundDBusProxy::BluetoothAudioModeOptsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(const QString & ) const>(_a, &SoundDBusProxy::CardsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(const QString & ) const>(_a, &SoundDBusProxy::CardsWithoutUnavailableChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(const QDBusObjectPath & ) const>(_a, &SoundDBusProxy::DefaultSinkChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(const QDBusObjectPath & ) const>(_a, &SoundDBusProxy::DefaultSourceChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(bool ) const>(_a, &SoundDBusProxy::IncreaseVolumeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(double ) const>(_a, &SoundDBusProxy::MaxUIVolumeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(bool ) const>(_a, &SoundDBusProxy::ReduceNoiseChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(bool ) const>(_a, &SoundDBusProxy::PausePlayerChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(const QList<QDBusObjectPath> & ) const>(_a, &SoundDBusProxy::SinkInputsChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(const QList<QDBusObjectPath> & ) const>(_a, &SoundDBusProxy::SinksChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(const QList<QDBusObjectPath> & ) const>(_a, &SoundDBusProxy::SourcesChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(const QString & ) const>(_a, &SoundDBusProxy::CurrentAudioServerChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(const bool ) const>(_a, &SoundDBusProxy::AudioServerStateChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(bool ) const>(_a, &SoundDBusProxy::EnabledChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(QMap<QString,bool> )>(_a, &SoundDBusProxy::pendingCallWatcherFinished, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(bool ) const>(_a, &SoundDBusProxy::HasBatteryChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(bool ) const>(_a, &SoundDBusProxy::MuteSinkChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(double ) const>(_a, &SoundDBusProxy::BalanceSinkChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(double ) const>(_a, &SoundDBusProxy::BaseVolumeSinkChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(uint ) const>(_a, &SoundDBusProxy::CardSinkChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(double ) const>(_a, &SoundDBusProxy::VolumeSinkChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(AudioPort ) const>(_a, &SoundDBusProxy::ActivePortSinkChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(bool ) const>(_a, &SoundDBusProxy::MuteSourceChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(double ) const>(_a, &SoundDBusProxy::VolumeSourceChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(AudioPort ) const>(_a, &SoundDBusProxy::ActivePortSourceChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(uint ) const>(_a, &SoundDBusProxy::CardSourceChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(double ) const>(_a, &SoundDBusProxy::VolumeMeterChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (SoundDBusProxy::*)(bool ) const>(_a, &SoundDBusProxy::AudioMonoChanged, 30))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 23:
        case 19:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AudioPort >(); break;
        case 10:
        case 9:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusObjectPath >(); break;
        case 13:
        case 12:
        case 11:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QDBusObjectPath> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<double*>(_v) = _t->maxUIVolume(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->increaseVolume(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->reduceNoise(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->pausePlayer(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->audioServer(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->audioServerState(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->bluetoothAudioMode(); break;
        case 7: *reinterpret_cast<QStringList*>(_v) = _t->bluetoothAudioModeOpts(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->cardsWithoutUnavailable(); break;
        case 9: *reinterpret_cast<QDBusObjectPath*>(_v) = _t->defaultSource(); break;
        case 10: *reinterpret_cast<QDBusObjectPath*>(_v) = _t->defaultSink(); break;
        case 11: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->sinkInputs(); break;
        case 12: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->sinks(); break;
        case 13: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->sources(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->muteSink(); break;
        case 15: *reinterpret_cast<double*>(_v) = _t->balanceSink(); break;
        case 16: *reinterpret_cast<double*>(_v) = _t->baseVolumeSink(); break;
        case 17: *reinterpret_cast<uint*>(_v) = _t->cardSink(); break;
        case 18: *reinterpret_cast<double*>(_v) = _t->volumeSink(); break;
        case 19: *reinterpret_cast<AudioPort*>(_v) = _t->activePortSink(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->muteSource(); break;
        case 21: *reinterpret_cast<uint*>(_v) = _t->cardSource(); break;
        case 22: *reinterpret_cast<double*>(_v) = _t->volumeSource(); break;
        case 23: *reinterpret_cast<AudioPort*>(_v) = _t->activePortSource(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->hasBattery(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 26: *reinterpret_cast<double*>(_v) = _t->volumeMeter(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->audioMono(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setIncreaseVolume(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setReduceNoise(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setPausePlayer(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->SetAudioServer(*reinterpret_cast<QString*>(_v)); break;
        case 25: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 27: _t->setAudioMono(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *SoundDBusProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SoundDBusProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SoundDBusProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SoundDBusProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void SoundDBusProxy::PortEnabledChanged(uint _t1, const QString & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void SoundDBusProxy::BluetoothAudioModeChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void SoundDBusProxy::BluetoothAudioModeOptsChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void SoundDBusProxy::CardsChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void SoundDBusProxy::CardsWithoutUnavailableChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void SoundDBusProxy::DefaultSinkChanged(const QDBusObjectPath & _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void SoundDBusProxy::DefaultSourceChanged(const QDBusObjectPath & _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void SoundDBusProxy::IncreaseVolumeChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void SoundDBusProxy::MaxUIVolumeChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void SoundDBusProxy::ReduceNoiseChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void SoundDBusProxy::PausePlayerChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void SoundDBusProxy::SinkInputsChanged(const QList<QDBusObjectPath> & _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void SoundDBusProxy::SinksChanged(const QList<QDBusObjectPath> & _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void SoundDBusProxy::SourcesChanged(const QList<QDBusObjectPath> & _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void SoundDBusProxy::CurrentAudioServerChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void SoundDBusProxy::AudioServerStateChanged(const bool _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void SoundDBusProxy::EnabledChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void SoundDBusProxy::pendingCallWatcherFinished(QMap<QString,bool> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void SoundDBusProxy::HasBatteryChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void SoundDBusProxy::MuteSinkChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void SoundDBusProxy::BalanceSinkChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void SoundDBusProxy::BaseVolumeSinkChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void SoundDBusProxy::CardSinkChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void SoundDBusProxy::VolumeSinkChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void SoundDBusProxy::ActivePortSinkChanged(AudioPort _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void SoundDBusProxy::MuteSourceChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 25, nullptr, _t1);
}

// SIGNAL 26
void SoundDBusProxy::VolumeSourceChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void SoundDBusProxy::ActivePortSourceChanged(AudioPort _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 27, nullptr, _t1);
}

// SIGNAL 28
void SoundDBusProxy::CardSourceChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 28, nullptr, _t1);
}

// SIGNAL 29
void SoundDBusProxy::VolumeMeterChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 29, nullptr, _t1);
}

// SIGNAL 30
void SoundDBusProxy::AudioMonoChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< SoundDBusProxy *>(this), &staticMetaObject, 30, nullptr, _t1);
}
QT_WARNING_POP
