/****************************************************************************
** Meta object code from reading C++ file 'categorymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-defaultapp/operation/categorymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'categorymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13CategoryModelE_t {};
} // unnamed namespace

template <> constexpr inline auto CategoryModel::qt_create_metaobjectdata<qt_meta_tag_ZN13CategoryModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CategoryModel",
        "requestCreateFile",
        "",
        "category",
        "QFileInfo",
        "info",
        "requestDelUserApp",
        "name",
        "App",
        "item",
        "requestSetDefaultApp",
        "addApp",
        "path",
        "removeApp",
        "id",
        "setDefaultApp",
        "onAddApp",
        "app",
        "onRemoveApp",
        "onDefaultChanged",
        "resetApp"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestCreateFile'
        QtMocHelpers::SignalData<void(const QString &, const QFileInfo &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'requestDelUserApp'
        QtMocHelpers::SignalData<void(const QString &, const App &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'requestSetDefaultApp'
        QtMocHelpers::SignalData<void(const QString &, const App &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot 'addApp'
        QtMocHelpers::SlotData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'removeApp'
        QtMocHelpers::SlotData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'setDefaultApp'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'onAddApp'
        QtMocHelpers::SlotData<void(const App &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 17 },
        }}),
        // Slot 'onRemoveApp'
        QtMocHelpers::SlotData<void(const App &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 17 },
        }}),
        // Slot 'onDefaultChanged'
        QtMocHelpers::SlotData<void(const App &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 17 },
        }}),
        // Slot 'resetApp'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CategoryModel, qt_meta_tag_ZN13CategoryModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CategoryModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13CategoryModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13CategoryModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13CategoryModelE_t>.metaTypes,
    nullptr
} };

void CategoryModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CategoryModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestCreateFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[2]))); break;
        case 1: _t->requestDelUserApp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<App>>(_a[2]))); break;
        case 2: _t->requestSetDefaultApp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<App>>(_a[2]))); break;
        case 3: _t->addApp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->removeApp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->setDefaultApp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->onAddApp((*reinterpret_cast<std::add_pointer_t<App>>(_a[1]))); break;
        case 7: _t->onRemoveApp((*reinterpret_cast<std::add_pointer_t<App>>(_a[1]))); break;
        case 8: _t->onDefaultChanged((*reinterpret_cast<std::add_pointer_t<App>>(_a[1]))); break;
        case 9: _t->resetApp(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFileInfo >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CategoryModel::*)(const QString & , const QFileInfo & )>(_a, &CategoryModel::requestCreateFile, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CategoryModel::*)(const QString & , const App & )>(_a, &CategoryModel::requestDelUserApp, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CategoryModel::*)(const QString & , const App & )>(_a, &CategoryModel::requestSetDefaultApp, 2))
            return;
    }
}

const QMetaObject *CategoryModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CategoryModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13CategoryModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int CategoryModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void CategoryModel::requestCreateFile(const QString & _t1, const QFileInfo & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void CategoryModel::requestDelUserApp(const QString & _t1, const App & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void CategoryModel::requestSetDefaultApp(const QString & _t1, const App & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}
QT_WARNING_POP
