/****************************************************************************
** Meta object code from reading C++ file 'wacomdbusproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-wacom/operation/wacomdbusproxy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'wacomdbusproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14WacomDBusProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto WacomDBusProxy::qt_create_metaobjectdata<qt_meta_tag_ZN14WacomDBusProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WacomDBusProxy",
        "ExistChanged",
        "",
        "value",
        "StylusPressureSensitiveChanged",
        "CursorModeChanged",
        "EraserPressureSensitiveChanged",
        "Exist",
        "StylusPressureSensitive",
        "CursorMode",
        "EraserPressureSensitive"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ExistChanged'
        QtMocHelpers::SignalData<void(bool) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'StylusPressureSensitiveChanged'
        QtMocHelpers::SignalData<void(uint) const>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'CursorModeChanged'
        QtMocHelpers::SignalData<void(bool) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'EraserPressureSensitiveChanged'
        QtMocHelpers::SignalData<void(uint) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Exist'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'StylusPressureSensitive'
        QtMocHelpers::PropertyData<uint>(8, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'CursorMode'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'EraserPressureSensitive'
        QtMocHelpers::PropertyData<uint>(10, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WacomDBusProxy, qt_meta_tag_ZN14WacomDBusProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WacomDBusProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14WacomDBusProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14WacomDBusProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14WacomDBusProxyE_t>.metaTypes,
    nullptr
} };

void WacomDBusProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WacomDBusProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ExistChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->StylusPressureSensitiveChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 2: _t->CursorModeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->EraserPressureSensitiveChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WacomDBusProxy::*)(bool ) const>(_a, &WacomDBusProxy::ExistChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WacomDBusProxy::*)(uint ) const>(_a, &WacomDBusProxy::StylusPressureSensitiveChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WacomDBusProxy::*)(bool ) const>(_a, &WacomDBusProxy::CursorModeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WacomDBusProxy::*)(uint ) const>(_a, &WacomDBusProxy::EraserPressureSensitiveChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->exist(); break;
        case 1: *reinterpret_cast<uint*>(_v) = _t->stylusPressureSensitive(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->cursorMode(); break;
        case 3: *reinterpret_cast<uint*>(_v) = _t->eraserPressureSensitive(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setStylusPressureSensitive(*reinterpret_cast<uint*>(_v)); break;
        case 2: _t->setCursorMode(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setEraserPressureSensitive(*reinterpret_cast<uint*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *WacomDBusProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WacomDBusProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14WacomDBusProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int WacomDBusProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void WacomDBusProxy::ExistChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< WacomDBusProxy *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void WacomDBusProxy::StylusPressureSensitiveChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< WacomDBusProxy *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void WacomDBusProxy::CursorModeChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< WacomDBusProxy *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void WacomDBusProxy::EraserPressureSensitiveChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< WacomDBusProxy *>(this), &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
