/****************************************************************************
** Meta object code from reading C++ file 'dccapp.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/include/dccapp.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dccapp.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6dccV256DccAppE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::DccApp::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV256DccAppE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::DccApp",
        "rootChanged",
        "",
        "DccObject*",
        "root",
        "activeObjectChanged",
        "activeObject",
        "activeItemChanged",
        "QQuickItem*",
        "item",
        "animationModeChanged",
        "AnimationMode",
        "mode",
        "object",
        "name",
        "addObject",
        "obj",
        "removeObject",
        "showPage",
        "url",
        "cmd",
        "mainWindow",
        "QWindow*",
        "navModel",
        "QAbstractItemModel*",
        "searchModel",
        "QSortFilterProxyModel*",
        "width",
        "height",
        "animationMode",
        "UosEdition",
        "UosEditionUnknown",
        "UosProfessional",
        "UosHome",
        "UosCommunity",
        "UosMilitary",
        "UosEnterprise",
        "UosEnterpriseC",
        "UosEuler",
        "UosMilitaryS",
        "UosDeviceEdition",
        "UosEducation",
        "UosEditionCount",
        "AnimationPush",
        "AnimationPop"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'rootChanged'
        QtMocHelpers::SignalData<void(DccObject *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'activeObjectChanged'
        QtMocHelpers::SignalData<void(DccObject *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 6 },
        }}),
        // Signal 'activeItemChanged'
        QtMocHelpers::SignalData<void(QQuickItem *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'animationModeChanged'
        QtMocHelpers::SignalData<void(enum AnimationMode)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'object'
        QtMocHelpers::SlotData<DccObject *(const QString &)>(13, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'addObject'
        QtMocHelpers::SlotData<void(DccObject *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 16 },
        }}),
        // Slot 'removeObject'
        QtMocHelpers::SlotData<void(DccObject *)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 16 },
        }}),
        // Slot 'removeObject'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'showPage'
        QtMocHelpers::SlotData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'showPage'
        QtMocHelpers::SlotData<void(DccObject *, const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 16 }, { QMetaType::QString, 20 },
        }}),
        // Slot 'mainWindow'
        QtMocHelpers::SlotData<QWindow *() const>(21, 2, QMC::AccessPublic, 0x80000000 | 22),
        // Slot 'navModel'
        QtMocHelpers::SlotData<QAbstractItemModel *() const>(23, 2, QMC::AccessPublic, 0x80000000 | 24),
        // Slot 'searchModel'
        QtMocHelpers::SlotData<QSortFilterProxyModel *() const>(25, 2, QMC::AccessPublic, 0x80000000 | 26),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'width'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'height'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'root'
        QtMocHelpers::PropertyData<DccObject*>(4, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'activeObject'
        QtMocHelpers::PropertyData<DccObject*>(6, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'animationMode'
        QtMocHelpers::PropertyData<enum AnimationMode>(29, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'UosEdition'
        QtMocHelpers::EnumData<enum UosEdition>(30, 30, QMC::EnumFlags{}).add({
            {   31, UosEdition::UosEditionUnknown },
            {   32, UosEdition::UosProfessional },
            {   33, UosEdition::UosHome },
            {   34, UosEdition::UosCommunity },
            {   35, UosEdition::UosMilitary },
            {   36, UosEdition::UosEnterprise },
            {   37, UosEdition::UosEnterpriseC },
            {   38, UosEdition::UosEuler },
            {   39, UosEdition::UosMilitaryS },
            {   40, UosEdition::UosDeviceEdition },
            {   41, UosEdition::UosEducation },
            {   42, UosEdition::UosEditionCount },
        }),
        // enum 'AnimationMode'
        QtMocHelpers::EnumData<enum AnimationMode>(11, 11, QMC::EnumFlags{}).add({
            {   43, AnimationMode::AnimationPush },
            {   44, AnimationMode::AnimationPop },
        }),
    };
    return QtMocHelpers::metaObjectData<DccApp, qt_meta_tag_ZN6dccV256DccAppE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dccV25::DccApp::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV256DccAppE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV256DccAppE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV256DccAppE_t>.metaTypes,
    nullptr
} };

void dccV25::DccApp::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DccApp *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->rootChanged((*reinterpret_cast<std::add_pointer_t<DccObject*>>(_a[1]))); break;
        case 1: _t->activeObjectChanged((*reinterpret_cast<std::add_pointer_t<DccObject*>>(_a[1]))); break;
        case 2: _t->activeItemChanged((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1]))); break;
        case 3: _t->animationModeChanged((*reinterpret_cast<std::add_pointer_t<enum AnimationMode>>(_a[1]))); break;
        case 4: { DccObject* _r = _t->object((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DccObject**>(_a[0]) = std::move(_r); }  break;
        case 5: _t->addObject((*reinterpret_cast<std::add_pointer_t<DccObject*>>(_a[1]))); break;
        case 6: _t->removeObject((*reinterpret_cast<std::add_pointer_t<DccObject*>>(_a[1]))); break;
        case 7: _t->removeObject((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->showPage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->showPage((*reinterpret_cast<std::add_pointer_t<DccObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 10: { QWindow* _r = _t->mainWindow();
            if (_a[0]) *reinterpret_cast<QWindow**>(_a[0]) = std::move(_r); }  break;
        case 11: { QAbstractItemModel* _r = _t->navModel();
            if (_a[0]) *reinterpret_cast<QAbstractItemModel**>(_a[0]) = std::move(_r); }  break;
        case 12: { QSortFilterProxyModel* _r = _t->searchModel();
            if (_a[0]) *reinterpret_cast<QSortFilterProxyModel**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DccObject* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DccObject* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickItem* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DccObject* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DccObject* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DccObject* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DccApp::*)(DccObject * )>(_a, &DccApp::rootChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccApp::*)(DccObject * )>(_a, &DccApp::activeObjectChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccApp::*)(QQuickItem * )>(_a, &DccApp::activeItemChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccApp::*)(AnimationMode )>(_a, &DccApp::animationModeChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DccObject* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->width(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->height(); break;
        case 2: *reinterpret_cast<DccObject**>(_v) = _t->root(); break;
        case 3: *reinterpret_cast<DccObject**>(_v) = _t->activeObject(); break;
        case 4: *reinterpret_cast<enum AnimationMode*>(_v) = _t->animationMode(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 4: _t->setAnimationMode(*reinterpret_cast<enum AnimationMode*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *dccV25::DccApp::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::DccApp::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV256DccAppE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dccV25::DccApp::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void dccV25::DccApp::rootChanged(DccObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dccV25::DccApp::activeObjectChanged(DccObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dccV25::DccApp::activeItemChanged(QQuickItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dccV25::DccApp::animationModeChanged(AnimationMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
