/****************************************************************************
** Meta object code from reading C++ file 'keyboarddbusproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-datetime/operation/keyboard/keyboarddbusproxy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keyboarddbusproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17KeyboardDBusProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto KeyboardDBusProxy::qt_create_metaobjectdata<qt_meta_tag_ZN17KeyboardDBusProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KeyboardDBusProxy",
        "CurrentLocaleChanged",
        "",
        "value",
        "LocaleStateChanged",
        "LocalesChanged",
        "langSelectorServiceStartFinished",
        "ret",
        "AddLocale",
        "QDBusPendingReply<>",
        "in0",
        "DeleteLocale",
        "SetLocale",
        "GetLocaleList",
        "QDBusPendingReply<LocaleList>",
        "onLangSelectorStartServiceProcessFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "CurrentLocale",
        "LocaleState",
        "Locales"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'CurrentLocaleChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'LocaleStateChanged'
        QtMocHelpers::SignalData<void(int) const>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'LocalesChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Signal 'langSelectorServiceStartFinished'
        QtMocHelpers::SignalData<void(const quint32) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 7 },
        }}),
        // Slot 'AddLocale'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(8, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'DeleteLocale'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(11, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'SetLocale'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(12, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'GetLocaleList'
        QtMocHelpers::SlotData<QDBusPendingReply<LocaleList>()>(13, 2, QMC::AccessPublic, 0x80000000 | 14),
        // Slot 'onLangSelectorStartServiceProcessFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'CurrentLocale'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'LocaleState'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'Locales'
        QtMocHelpers::PropertyData<QStringList>(20, QMetaType::QStringList, QMC::DefaultPropertyFlags, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KeyboardDBusProxy, qt_meta_tag_ZN17KeyboardDBusProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KeyboardDBusProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KeyboardDBusProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KeyboardDBusProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17KeyboardDBusProxyE_t>.metaTypes,
    nullptr
} };

void KeyboardDBusProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeyboardDBusProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->CurrentLocaleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->LocaleStateChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->LocalesChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 3: _t->langSelectorServiceStartFinished((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 4: { QDBusPendingReply<> _r = _t->AddLocale((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<> _r = _t->DeleteLocale((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<> _r = _t->SetLocale((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<LocaleList> _r = _t->GetLocaleList();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<LocaleList>*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->onLangSelectorStartServiceProcessFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(const QString & ) const>(_a, &KeyboardDBusProxy::CurrentLocaleChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(int ) const>(_a, &KeyboardDBusProxy::LocaleStateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(const QStringList & ) const>(_a, &KeyboardDBusProxy::LocalesChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(const quint32 ) const>(_a, &KeyboardDBusProxy::langSelectorServiceStartFinished, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->currentLocale(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->localeState(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->locales(); break;
        default: break;
        }
    }
}

const QMetaObject *KeyboardDBusProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KeyboardDBusProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KeyboardDBusProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KeyboardDBusProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void KeyboardDBusProxy::CurrentLocaleChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< KeyboardDBusProxy *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KeyboardDBusProxy::LocaleStateChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< KeyboardDBusProxy *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KeyboardDBusProxy::LocalesChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< KeyboardDBusProxy *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KeyboardDBusProxy::langSelectorServiceStartFinished(const quint32 _t1)const
{
    QMetaObject::activate<void>(const_cast< KeyboardDBusProxy *>(this), &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
