/****************************************************************************
** Meta object code from reading C++ file 'mouseworker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-mouse/operation/mouseworker.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mouseworker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13DCC_NAMESPACE11MouseWorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto DCC_NAMESPACE::MouseWorker::qt_create_metaobjectdata<qt_meta_tag_ZN13DCC_NAMESPACE11MouseWorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DCC_NAMESPACE::MouseWorker",
        "requestSetPalmDetect",
        "",
        "palmDetect",
        "requestSetPalmMinWidth",
        "palmMinWidth",
        "requestSetPalmMinz",
        "palmMinz",
        "requestSetScrollSpeed",
        "speed",
        "requestSetLeftHandState",
        "state",
        "requestSetMouseNaturalScrollState",
        "requestSetTouchNaturalScrollState",
        "requestSetDisTyping",
        "requestSetDisTouchPad",
        "requestSetTapClick",
        "requestSetDouClick",
        "value",
        "requestSetMouseMotionAcceleration",
        "requestSetAccelProfile",
        "requestSetTouchpadMotionAcceleration",
        "requestSetTrackPointMotionAcceleration",
        "requestSetTouchpadEnabled",
        "requestSetGesture",
        "name",
        "direction",
        "fingers",
        "action",
        "setMouseExist",
        "exist",
        "setTpadExist",
        "setTpadEnabled",
        "enabled",
        "setRedPointExist",
        "setLeftHandState",
        "setMouseNaturalScrollState",
        "setTouchNaturalScrollState",
        "setDisTyping",
        "setDisTouchPad",
        "setTapClick",
        "setDouClick",
        "setMouseMotionAcceleration",
        "setAccelProfile",
        "setTouchpadMotionAcceleration",
        "setTrackPointMotionAcceleration",
        "setPalmDetect",
        "setPalmMinWidth",
        "setPalmMinz",
        "setScrollSpeed",
        "setGestureData",
        "GestureData",
        "data",
        "onLeftHandStateChanged",
        "onMouseNaturalScrollStateChanged",
        "onTouchNaturalScrollStateChanged",
        "onDisTypingChanged",
        "onDisTouchPadChanged",
        "onTapClick",
        "onDouClickChanged",
        "onMouseMotionAccelerationChanged",
        "onAccelProfileChanged",
        "onTouchpadMotionAccelerationChanged",
        "onTrackPointMotionAccelerationChanged",
        "onPalmDetectChanged",
        "onPalmMinWidthChanged",
        "onPalmMinzChanged",
        "onScrollSpeedChanged",
        "onTouchpadEnabledChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestSetPalmDetect'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'requestSetPalmMinWidth'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'requestSetPalmMinz'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'requestSetScrollSpeed'
        QtMocHelpers::SignalData<void(uint)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 9 },
        }}),
        // Signal 'requestSetLeftHandState'
        QtMocHelpers::SignalData<void(const bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'requestSetMouseNaturalScrollState'
        QtMocHelpers::SignalData<void(const bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'requestSetTouchNaturalScrollState'
        QtMocHelpers::SignalData<void(const bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'requestSetDisTyping'
        QtMocHelpers::SignalData<void(const bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'requestSetDisTouchPad'
        QtMocHelpers::SignalData<void(const bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'requestSetTapClick'
        QtMocHelpers::SignalData<void(const bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'requestSetDouClick'
        QtMocHelpers::SignalData<void(const int &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Signal 'requestSetMouseMotionAcceleration'
        QtMocHelpers::SignalData<void(const double &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 18 },
        }}),
        // Signal 'requestSetAccelProfile'
        QtMocHelpers::SignalData<void(const bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'requestSetTouchpadMotionAcceleration'
        QtMocHelpers::SignalData<void(const double &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 18 },
        }}),
        // Signal 'requestSetTrackPointMotionAcceleration'
        QtMocHelpers::SignalData<void(const double &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 18 },
        }}),
        // Signal 'requestSetTouchpadEnabled'
        QtMocHelpers::SignalData<void(const bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'requestSetGesture'
        QtMocHelpers::SignalData<void(const QString &, const QString &, int, const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 }, { QMetaType::QString, 26 }, { QMetaType::Int, 27 }, { QMetaType::QString, 28 },
        }}),
        // Slot 'setMouseExist'
        QtMocHelpers::SlotData<void(bool)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'setTpadExist'
        QtMocHelpers::SlotData<void(bool)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'setTpadEnabled'
        QtMocHelpers::SlotData<void(bool)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'setRedPointExist'
        QtMocHelpers::SlotData<void(bool)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'setLeftHandState'
        QtMocHelpers::SlotData<void(const bool)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'setMouseNaturalScrollState'
        QtMocHelpers::SlotData<void(const bool)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'setTouchNaturalScrollState'
        QtMocHelpers::SlotData<void(const bool)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'setDisTyping'
        QtMocHelpers::SlotData<void(const bool)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'setDisTouchPad'
        QtMocHelpers::SlotData<void(const bool)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'setTapClick'
        QtMocHelpers::SlotData<void(const bool)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'setDouClick'
        QtMocHelpers::SlotData<void(const int &)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'setMouseMotionAcceleration'
        QtMocHelpers::SlotData<void(const double &)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 18 },
        }}),
        // Slot 'setAccelProfile'
        QtMocHelpers::SlotData<void(const bool)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'setTouchpadMotionAcceleration'
        QtMocHelpers::SlotData<void(const double &)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 18 },
        }}),
        // Slot 'setTrackPointMotionAcceleration'
        QtMocHelpers::SlotData<void(const double &)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 18 },
        }}),
        // Slot 'setPalmDetect'
        QtMocHelpers::SlotData<void(bool)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'setPalmMinWidth'
        QtMocHelpers::SlotData<void(int)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'setPalmMinz'
        QtMocHelpers::SlotData<void(int)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'setScrollSpeed'
        QtMocHelpers::SlotData<void(uint)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 9 },
        }}),
        // Slot 'setGestureData'
        QtMocHelpers::SlotData<void(const GestureData &)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 51, 52 },
        }}),
        // Slot 'onLeftHandStateChanged'
        QtMocHelpers::SlotData<void(const bool)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'onMouseNaturalScrollStateChanged'
        QtMocHelpers::SlotData<void(const bool)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'onTouchNaturalScrollStateChanged'
        QtMocHelpers::SlotData<void(const bool)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'onDisTypingChanged'
        QtMocHelpers::SlotData<void(const bool)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'onDisTouchPadChanged'
        QtMocHelpers::SlotData<void(const bool)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'onTapClick'
        QtMocHelpers::SlotData<void(const bool)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'onDouClickChanged'
        QtMocHelpers::SlotData<void(const int &)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'onMouseMotionAccelerationChanged'
        QtMocHelpers::SlotData<void(const int &)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'onAccelProfileChanged'
        QtMocHelpers::SlotData<void(const bool)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'onTouchpadMotionAccelerationChanged'
        QtMocHelpers::SlotData<void(const int &)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'onTrackPointMotionAccelerationChanged'
        QtMocHelpers::SlotData<void(const int &)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'onPalmDetectChanged'
        QtMocHelpers::SlotData<void(bool)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'onPalmMinWidthChanged'
        QtMocHelpers::SlotData<void(int)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'onPalmMinzChanged'
        QtMocHelpers::SlotData<void(int)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'onScrollSpeedChanged'
        QtMocHelpers::SlotData<void(int)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Slot 'onTouchpadEnabledChanged'
        QtMocHelpers::SlotData<void(const bool)>(68, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MouseWorker, qt_meta_tag_ZN13DCC_NAMESPACE11MouseWorkerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DCC_NAMESPACE::MouseWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DCC_NAMESPACE11MouseWorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DCC_NAMESPACE11MouseWorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13DCC_NAMESPACE11MouseWorkerE_t>.metaTypes,
    nullptr
} };

void DCC_NAMESPACE::MouseWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MouseWorker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestSetPalmDetect((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->requestSetPalmMinWidth((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->requestSetPalmMinz((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->requestSetScrollSpeed((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 4: _t->requestSetLeftHandState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->requestSetMouseNaturalScrollState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->requestSetTouchNaturalScrollState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->requestSetDisTyping((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->requestSetDisTouchPad((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->requestSetTapClick((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->requestSetDouClick((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->requestSetMouseMotionAcceleration((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 12: _t->requestSetAccelProfile((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->requestSetTouchpadMotionAcceleration((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 14: _t->requestSetTrackPointMotionAcceleration((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 15: _t->requestSetTouchpadEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->requestSetGesture((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 17: _t->setMouseExist((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->setTpadExist((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->setTpadEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->setRedPointExist((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->setLeftHandState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->setMouseNaturalScrollState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->setTouchNaturalScrollState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: _t->setDisTyping((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->setDisTouchPad((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->setTapClick((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->setDouClick((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->setMouseMotionAcceleration((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 29: _t->setAccelProfile((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->setTouchpadMotionAcceleration((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 31: _t->setTrackPointMotionAcceleration((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 32: _t->setPalmDetect((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->setPalmMinWidth((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 34: _t->setPalmMinz((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 35: _t->setScrollSpeed((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 36: _t->setGestureData((*reinterpret_cast<std::add_pointer_t<GestureData>>(_a[1]))); break;
        case 37: _t->onLeftHandStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 38: _t->onMouseNaturalScrollStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 39: _t->onTouchNaturalScrollStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 40: _t->onDisTypingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 41: _t->onDisTouchPadChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 42: _t->onTapClick((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 43: _t->onDouClickChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 44: _t->onMouseMotionAccelerationChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 45: _t->onAccelProfileChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 46: _t->onTouchpadMotionAccelerationChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 47: _t->onTrackPointMotionAccelerationChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 48: _t->onPalmDetectChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 49: _t->onPalmMinWidthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 50: _t->onPalmMinzChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 51: _t->onScrollSpeedChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 52: _t->onTouchpadEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MouseWorker::*)(bool )>(_a, &MouseWorker::requestSetPalmDetect, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseWorker::*)(int )>(_a, &MouseWorker::requestSetPalmMinWidth, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseWorker::*)(int )>(_a, &MouseWorker::requestSetPalmMinz, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseWorker::*)(uint )>(_a, &MouseWorker::requestSetScrollSpeed, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseWorker::*)(const bool )>(_a, &MouseWorker::requestSetLeftHandState, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseWorker::*)(const bool )>(_a, &MouseWorker::requestSetMouseNaturalScrollState, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseWorker::*)(const bool )>(_a, &MouseWorker::requestSetTouchNaturalScrollState, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseWorker::*)(const bool )>(_a, &MouseWorker::requestSetDisTyping, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseWorker::*)(const bool )>(_a, &MouseWorker::requestSetDisTouchPad, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseWorker::*)(const bool )>(_a, &MouseWorker::requestSetTapClick, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseWorker::*)(const int & )>(_a, &MouseWorker::requestSetDouClick, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseWorker::*)(const double & )>(_a, &MouseWorker::requestSetMouseMotionAcceleration, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseWorker::*)(const bool )>(_a, &MouseWorker::requestSetAccelProfile, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseWorker::*)(const double & )>(_a, &MouseWorker::requestSetTouchpadMotionAcceleration, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseWorker::*)(const double & )>(_a, &MouseWorker::requestSetTrackPointMotionAcceleration, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseWorker::*)(const bool )>(_a, &MouseWorker::requestSetTouchpadEnabled, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseWorker::*)(const QString & , const QString & , int , const QString & )>(_a, &MouseWorker::requestSetGesture, 16))
            return;
    }
}

const QMetaObject *DCC_NAMESPACE::MouseWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DCC_NAMESPACE::MouseWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DCC_NAMESPACE11MouseWorkerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DCC_NAMESPACE::MouseWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 53)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 53;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 53)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 53;
    }
    return _id;
}

// SIGNAL 0
void DCC_NAMESPACE::MouseWorker::requestSetPalmDetect(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DCC_NAMESPACE::MouseWorker::requestSetPalmMinWidth(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DCC_NAMESPACE::MouseWorker::requestSetPalmMinz(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DCC_NAMESPACE::MouseWorker::requestSetScrollSpeed(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DCC_NAMESPACE::MouseWorker::requestSetLeftHandState(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DCC_NAMESPACE::MouseWorker::requestSetMouseNaturalScrollState(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DCC_NAMESPACE::MouseWorker::requestSetTouchNaturalScrollState(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void DCC_NAMESPACE::MouseWorker::requestSetDisTyping(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void DCC_NAMESPACE::MouseWorker::requestSetDisTouchPad(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void DCC_NAMESPACE::MouseWorker::requestSetTapClick(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void DCC_NAMESPACE::MouseWorker::requestSetDouClick(const int & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void DCC_NAMESPACE::MouseWorker::requestSetMouseMotionAcceleration(const double & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void DCC_NAMESPACE::MouseWorker::requestSetAccelProfile(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void DCC_NAMESPACE::MouseWorker::requestSetTouchpadMotionAcceleration(const double & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void DCC_NAMESPACE::MouseWorker::requestSetTrackPointMotionAcceleration(const double & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void DCC_NAMESPACE::MouseWorker::requestSetTouchpadEnabled(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void DCC_NAMESPACE::MouseWorker::requestSetGesture(const QString & _t1, const QString & _t2, int _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2, _t3, _t4);
}
QT_WARNING_POP
