/****************************************************************************
** Meta object code from reading C++ file 'keyboarddbusproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-keyboard/operation/keyboarddbusproxy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keyboarddbusproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17KeyboardDBusProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto KeyboardDBusProxy::qt_create_metaobjectdata<qt_meta_tag_ZN17KeyboardDBusProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KeyboardDBusProxy",
        "CapslockToggleChanged",
        "",
        "value",
        "CurrentLayoutChanged",
        "CursorBlinkChanged",
        "LayoutScopeChanged",
        "RepeatDelayChanged",
        "RepeatEnabledChanged",
        "RepeatIntervalChanged",
        "UserLayoutListChanged",
        "UserOptionListChanged",
        "CurrentLocaleChanged",
        "LocaleStateChanged",
        "LocalesChanged",
        "NumLockStateChanged",
        "ShortcutSwitchLayoutChanged",
        "Added",
        "in0",
        "in1",
        "Changed",
        "Deleted",
        "KeyEvent",
        "compositingEnabledChanged",
        "enabled",
        "langSelectorServiceStartFinished",
        "ret",
        "KeybindingReset",
        "QDBusPendingReply<>",
        "ListAllShortcuts",
        "QDBusPendingReply<QString>",
        "LookupConflictingShortcut",
        "ClearShortcutKeystrokes",
        "AddShortcutKeystroke",
        "in2",
        "AddCustomShortcut",
        "ModifyCustomShortcut",
        "in3",
        "DeleteCustomShortcut",
        "GrabScreen",
        "SetNumLockState",
        "GetShortcut",
        "SearchShortcuts",
        "Query",
        "SelectKeystroke",
        "LayoutList",
        "QDBusPendingReply<KeyboardLayoutList>",
        "AllLayoutList",
        "AddUserLayout",
        "DeleteUserLayout",
        "GetLayoutDesc",
        "AddLocale",
        "DeleteLocale",
        "SetLocale",
        "GetLocaleList",
        "QDBusPendingReply<LocaleList>",
        "onLangSelectorStartServiceProcessFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "CapslockToggle",
        "CurrentLayout",
        "CursorBlink",
        "LayoutScope",
        "RepeatDelay",
        "RepeatEnabled",
        "RepeatInterval",
        "UserLayoutList",
        "UserOptionList",
        "CurrentLocale",
        "LocaleState",
        "Locales",
        "NumLockState",
        "ShortcutSwitchLayout"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'CapslockToggleChanged'
        QtMocHelpers::SignalData<void(bool) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'CurrentLayoutChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'CursorBlinkChanged'
        QtMocHelpers::SignalData<void(int) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'LayoutScopeChanged'
        QtMocHelpers::SignalData<void(int) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'RepeatDelayChanged'
        QtMocHelpers::SignalData<void(uint) const>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'RepeatEnabledChanged'
        QtMocHelpers::SignalData<void(bool) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'RepeatIntervalChanged'
        QtMocHelpers::SignalData<void(uint) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'UserLayoutListChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Signal 'UserOptionListChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Signal 'CurrentLocaleChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'LocaleStateChanged'
        QtMocHelpers::SignalData<void(int) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'LocalesChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Signal 'NumLockStateChanged'
        QtMocHelpers::SignalData<void(int) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'ShortcutSwitchLayoutChanged'
        QtMocHelpers::SignalData<void(uint) const>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'Added'
        QtMocHelpers::SignalData<void(const QString &, int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 }, { QMetaType::Int, 19 },
        }}),
        // Signal 'Changed'
        QtMocHelpers::SignalData<void(const QString &, int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 }, { QMetaType::Int, 19 },
        }}),
        // Signal 'Deleted'
        QtMocHelpers::SignalData<void(const QString &, int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 }, { QMetaType::Int, 19 },
        }}),
        // Signal 'KeyEvent'
        QtMocHelpers::SignalData<void(bool, const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 }, { QMetaType::QString, 19 },
        }}),
        // Signal 'compositingEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Signal 'langSelectorServiceStartFinished'
        QtMocHelpers::SignalData<void(const quint32) const>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 26 },
        }}),
        // Slot 'KeybindingReset'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(27, 2, QMC::AccessPublic, 0x80000000 | 28),
        // Slot 'ListAllShortcuts'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(29, 2, QMC::AccessPublic, 0x80000000 | 30),
        // Slot 'LookupConflictingShortcut'
        QtMocHelpers::SlotData<QString(const QString &)>(31, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'ClearShortcutKeystrokes'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, int)>(32, 2, QMC::AccessPublic, 0x80000000 | 28, {{
            { QMetaType::QString, 18 }, { QMetaType::Int, 19 },
        }}),
        // Slot 'AddShortcutKeystroke'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, int, const QString &)>(33, 2, QMC::AccessPublic, 0x80000000 | 28, {{
            { QMetaType::QString, 18 }, { QMetaType::Int, 19 }, { QMetaType::QString, 34 },
        }}),
        // Slot 'AddCustomShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QString &)>(35, 2, QMC::AccessPublic, 0x80000000 | 28, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 19 }, { QMetaType::QString, 34 },
        }}),
        // Slot 'ModifyCustomShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QString &, const QString &)>(36, 2, QMC::AccessPublic, 0x80000000 | 28, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 19 }, { QMetaType::QString, 34 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'DeleteCustomShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(38, 2, QMC::AccessPublic, 0x80000000 | 28, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'GrabScreen'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(39, 2, QMC::AccessPublic, 0x80000000 | 28),
        // Slot 'SetNumLockState'
        QtMocHelpers::SlotData<void(int)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'GetShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &, int)>(41, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::QString, 18 }, { QMetaType::Int, 19 },
        }}),
        // Slot 'SearchShortcuts'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(42, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'Query'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &, int)>(43, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::QString, 18 }, { QMetaType::Int, 19 },
        }}),
        // Slot 'SelectKeystroke'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'LayoutList'
        QtMocHelpers::SlotData<QDBusPendingReply<KeyboardLayoutList>()>(45, 2, QMC::AccessPublic, 0x80000000 | 46),
        // Slot 'AllLayoutList'
        QtMocHelpers::SlotData<QDBusPendingReply<KeyboardLayoutList>()>(47, 2, QMC::AccessPublic, 0x80000000 | 46),
        // Slot 'AddUserLayout'
        QtMocHelpers::SlotData<void(const QString &)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'DeleteUserLayout'
        QtMocHelpers::SlotData<void(const QString &)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'GetLayoutDesc'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(50, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'AddLocale'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(51, 2, QMC::AccessPublic, 0x80000000 | 28, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'DeleteLocale'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(52, 2, QMC::AccessPublic, 0x80000000 | 28, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'SetLocale'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(53, 2, QMC::AccessPublic, 0x80000000 | 28, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'GetLocaleList'
        QtMocHelpers::SlotData<QDBusPendingReply<LocaleList>()>(54, 2, QMC::AccessPublic, 0x80000000 | 55),
        // Slot 'onLangSelectorStartServiceProcessFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(56, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 57, 58 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'CapslockToggle'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'CurrentLayout'
        QtMocHelpers::PropertyData<QString>(60, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'CursorBlink'
        QtMocHelpers::PropertyData<int>(61, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'LayoutScope'
        QtMocHelpers::PropertyData<int>(62, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'RepeatDelay'
        QtMocHelpers::PropertyData<uint>(63, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'RepeatEnabled'
        QtMocHelpers::PropertyData<bool>(64, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'RepeatInterval'
        QtMocHelpers::PropertyData<uint>(65, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'UserLayoutList'
        QtMocHelpers::PropertyData<QStringList>(66, QMetaType::QStringList, QMC::DefaultPropertyFlags, 7),
        // property 'UserOptionList'
        QtMocHelpers::PropertyData<QStringList>(67, QMetaType::QStringList, QMC::DefaultPropertyFlags, 8),
        // property 'CurrentLocale'
        QtMocHelpers::PropertyData<QString>(68, QMetaType::QString, QMC::DefaultPropertyFlags, 9),
        // property 'LocaleState'
        QtMocHelpers::PropertyData<int>(69, QMetaType::Int, QMC::DefaultPropertyFlags, 10),
        // property 'Locales'
        QtMocHelpers::PropertyData<QStringList>(70, QMetaType::QStringList, QMC::DefaultPropertyFlags, 11),
        // property 'NumLockState'
        QtMocHelpers::PropertyData<int>(71, QMetaType::Int, QMC::DefaultPropertyFlags, 12),
        // property 'ShortcutSwitchLayout'
        QtMocHelpers::PropertyData<uint>(72, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KeyboardDBusProxy, qt_meta_tag_ZN17KeyboardDBusProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KeyboardDBusProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KeyboardDBusProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KeyboardDBusProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17KeyboardDBusProxyE_t>.metaTypes,
    nullptr
} };

void KeyboardDBusProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeyboardDBusProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->CapslockToggleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->CurrentLayoutChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->CursorBlinkChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->LayoutScopeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->RepeatDelayChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 5: _t->RepeatEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->RepeatIntervalChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 7: _t->UserLayoutListChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 8: _t->UserOptionListChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 9: _t->CurrentLocaleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->LocaleStateChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->LocalesChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 12: _t->NumLockStateChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->ShortcutSwitchLayoutChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 14: _t->Added((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 15: _t->Changed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 16: _t->Deleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 17: _t->KeyEvent((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 18: _t->compositingEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->langSelectorServiceStartFinished((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 20: { QDBusPendingReply<> _r = _t->KeybindingReset();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<QString> _r = _t->ListAllShortcuts();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QString _r = _t->LookupConflictingShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<> _r = _t->ClearShortcutKeystrokes((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<> _r = _t->AddShortcutKeystroke((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<> _r = _t->AddCustomShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 26: { QDBusPendingReply<> _r = _t->ModifyCustomShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 27: { QDBusPendingReply<> _r = _t->DeleteCustomShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 28: { QDBusPendingReply<> _r = _t->GrabScreen();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->SetNumLockState((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 30: { QDBusPendingReply<QString> _r = _t->GetShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 31: { QDBusPendingReply<QString> _r = _t->SearchShortcuts((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 32: { QDBusPendingReply<QString> _r = _t->Query((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 33: _t->SelectKeystroke(); break;
        case 34: { QDBusPendingReply<KeyboardLayoutList> _r = _t->LayoutList();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<KeyboardLayoutList>*>(_a[0]) = std::move(_r); }  break;
        case 35: { QDBusPendingReply<KeyboardLayoutList> _r = _t->AllLayoutList();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<KeyboardLayoutList>*>(_a[0]) = std::move(_r); }  break;
        case 36: _t->AddUserLayout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 37: _t->DeleteUserLayout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 38: { QDBusPendingReply<QString> _r = _t->GetLayoutDesc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 39: { QDBusPendingReply<> _r = _t->AddLocale((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 40: { QDBusPendingReply<> _r = _t->DeleteLocale((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 41: { QDBusPendingReply<> _r = _t->SetLocale((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 42: { QDBusPendingReply<LocaleList> _r = _t->GetLocaleList();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<LocaleList>*>(_a[0]) = std::move(_r); }  break;
        case 43: _t->onLangSelectorStartServiceProcessFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 43:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(bool ) const>(_a, &KeyboardDBusProxy::CapslockToggleChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(const QString & ) const>(_a, &KeyboardDBusProxy::CurrentLayoutChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(int ) const>(_a, &KeyboardDBusProxy::CursorBlinkChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(int ) const>(_a, &KeyboardDBusProxy::LayoutScopeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(uint ) const>(_a, &KeyboardDBusProxy::RepeatDelayChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(bool ) const>(_a, &KeyboardDBusProxy::RepeatEnabledChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(uint ) const>(_a, &KeyboardDBusProxy::RepeatIntervalChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(const QStringList & ) const>(_a, &KeyboardDBusProxy::UserLayoutListChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(const QStringList & ) const>(_a, &KeyboardDBusProxy::UserOptionListChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(const QString & ) const>(_a, &KeyboardDBusProxy::CurrentLocaleChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(int ) const>(_a, &KeyboardDBusProxy::LocaleStateChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(const QStringList & ) const>(_a, &KeyboardDBusProxy::LocalesChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(int ) const>(_a, &KeyboardDBusProxy::NumLockStateChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(uint ) const>(_a, &KeyboardDBusProxy::ShortcutSwitchLayoutChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(const QString & , int )>(_a, &KeyboardDBusProxy::Added, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(const QString & , int )>(_a, &KeyboardDBusProxy::Changed, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(const QString & , int )>(_a, &KeyboardDBusProxy::Deleted, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(bool , const QString & )>(_a, &KeyboardDBusProxy::KeyEvent, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(bool )>(_a, &KeyboardDBusProxy::compositingEnabledChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDBusProxy::*)(const quint32 ) const>(_a, &KeyboardDBusProxy::langSelectorServiceStartFinished, 19))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->capslockToggle(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->currentLayout(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->cursorBlink(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->layoutScope(); break;
        case 4: *reinterpret_cast<uint*>(_v) = _t->repeatDelay(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->repeatEnabled(); break;
        case 6: *reinterpret_cast<uint*>(_v) = _t->repeatInterval(); break;
        case 7: *reinterpret_cast<QStringList*>(_v) = _t->userLayoutList(); break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->userOptionList(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->currentLocale(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->localeState(); break;
        case 11: *reinterpret_cast<QStringList*>(_v) = _t->locales(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->numLockState(); break;
        case 13: *reinterpret_cast<uint*>(_v) = _t->shortcutSwitchLayout(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCapslockToggle(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setCurrentLayout(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setCursorBlink(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setLayoutScope(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setRepeatDelay(*reinterpret_cast<uint*>(_v)); break;
        case 5: _t->setRepeatEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setRepeatInterval(*reinterpret_cast<uint*>(_v)); break;
        case 13: _t->setShortcutSwitchLayout(*reinterpret_cast<uint*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KeyboardDBusProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KeyboardDBusProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KeyboardDBusProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KeyboardDBusProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void KeyboardDBusProxy::CapslockToggleChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< KeyboardDBusProxy *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KeyboardDBusProxy::CurrentLayoutChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< KeyboardDBusProxy *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KeyboardDBusProxy::CursorBlinkChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< KeyboardDBusProxy *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KeyboardDBusProxy::LayoutScopeChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< KeyboardDBusProxy *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KeyboardDBusProxy::RepeatDelayChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< KeyboardDBusProxy *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KeyboardDBusProxy::RepeatEnabledChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< KeyboardDBusProxy *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KeyboardDBusProxy::RepeatIntervalChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< KeyboardDBusProxy *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KeyboardDBusProxy::UserLayoutListChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< KeyboardDBusProxy *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void KeyboardDBusProxy::UserOptionListChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< KeyboardDBusProxy *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void KeyboardDBusProxy::CurrentLocaleChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< KeyboardDBusProxy *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void KeyboardDBusProxy::LocaleStateChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< KeyboardDBusProxy *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void KeyboardDBusProxy::LocalesChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< KeyboardDBusProxy *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void KeyboardDBusProxy::NumLockStateChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< KeyboardDBusProxy *>(this), &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void KeyboardDBusProxy::ShortcutSwitchLayoutChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< KeyboardDBusProxy *>(this), &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void KeyboardDBusProxy::Added(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}

// SIGNAL 15
void KeyboardDBusProxy::Changed(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2);
}

// SIGNAL 16
void KeyboardDBusProxy::Deleted(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2);
}

// SIGNAL 17
void KeyboardDBusProxy::KeyEvent(bool _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2);
}

// SIGNAL 18
void KeyboardDBusProxy::compositingEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void KeyboardDBusProxy::langSelectorServiceStartFinished(const quint32 _t1)const
{
    QMetaObject::activate<void>(const_cast< KeyboardDBusProxy *>(this), &staticMetaObject, 19, nullptr, _t1);
}
QT_WARNING_POP
