/****************************************************************************
** Meta object code from reading C++ file 'mousemodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-mouse/operation/mousemodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mousemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13DCC_NAMESPACE10MouseModelE_t {};
} // unnamed namespace

template <> constexpr inline auto DCC_NAMESPACE::MouseModel::qt_create_metaobjectdata<qt_meta_tag_ZN13DCC_NAMESPACE10MouseModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DCC_NAMESPACE::MouseModel",
        "leftHandStateChanged",
        "",
        "state",
        "disIfTypingStateChanged",
        "tpadExistChanged",
        "tpadExist",
        "mouseExistChanged",
        "mouseExist",
        "redPointExistChanged",
        "rPointExist",
        "doubleSpeedChanged",
        "speed",
        "mouseNaturalScrollChanged",
        "natural",
        "tpadNaturalScrollChanged",
        "mouseMoveSpeedChanged",
        "tpadMoveSpeedChanged",
        "accelProfileChanged",
        "useAdaptiveProfile",
        "redPointMoveSpeedChanged",
        "disTpadChanged",
        "disable",
        "palmDetectChanged",
        "detect",
        "palmMinWidthChanged",
        "palmMinWidth",
        "palmMinzChanged",
        "palmMinz",
        "tapClickChanged",
        "tapClick",
        "tapEnabledChanged",
        "scrollSpeedChanged",
        "disIfTypingChanged",
        "gestureFingerAniPathChanged",
        "gestureActionAniPathChanged",
        "themeTypeChanged",
        "threeFingerGestureModel",
        "GestureModel*",
        "fourFigerGestureModel",
        "setGestures",
        "fingerNum",
        "index",
        "acitonDec",
        "updateFigerGestureAni",
        "scrollSpeed",
        "doubleSpeed",
        "leftHandState",
        "mouseMoveSpeed",
        "accelProfile",
        "disTpad",
        "mouseNaturalScroll",
        "tpadMoveSpeed",
        "tpadNaturalScroll",
        "disIfTyping",
        "tapEnabled",
        "gestureFingerAniPath",
        "gestureActionAniPath"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'leftHandStateChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'disIfTypingStateChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'tpadExistChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'mouseExistChanged'
        QtMocHelpers::SignalData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'redPointExistChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Signal 'doubleSpeedChanged'
        QtMocHelpers::SignalData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Signal 'mouseNaturalScrollChanged'
        QtMocHelpers::SignalData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'tpadNaturalScrollChanged'
        QtMocHelpers::SignalData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'mouseMoveSpeedChanged'
        QtMocHelpers::SignalData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Signal 'tpadMoveSpeedChanged'
        QtMocHelpers::SignalData<void(int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Signal 'accelProfileChanged'
        QtMocHelpers::SignalData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Signal 'redPointMoveSpeedChanged'
        QtMocHelpers::SignalData<void(int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Signal 'disTpadChanged'
        QtMocHelpers::SignalData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Signal 'palmDetectChanged'
        QtMocHelpers::SignalData<void(bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Signal 'palmMinWidthChanged'
        QtMocHelpers::SignalData<void(int)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Signal 'palmMinzChanged'
        QtMocHelpers::SignalData<void(int)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Signal 'tapClickChanged'
        QtMocHelpers::SignalData<void(bool)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Signal 'tapEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Signal 'scrollSpeedChanged'
        QtMocHelpers::SignalData<void(int)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Signal 'disIfTypingChanged'
        QtMocHelpers::SignalData<void(bool)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'gestureFingerAniPathChanged'
        QtMocHelpers::SignalData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gestureActionAniPathChanged'
        QtMocHelpers::SignalData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'themeTypeChanged'
        QtMocHelpers::SignalData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'threeFingerGestureModel'
        QtMocHelpers::MethodData<GestureModel *() const>(37, 2, QMC::AccessPublic, 0x80000000 | 38),
        // Method 'fourFigerGestureModel'
        QtMocHelpers::MethodData<GestureModel *() const>(39, 2, QMC::AccessPublic, 0x80000000 | 38),
        // Method 'setGestures'
        QtMocHelpers::MethodData<void(int, int, QString)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 41 }, { QMetaType::Int, 42 }, { QMetaType::QString, 43 },
        }}),
        // Method 'updateFigerGestureAni'
        QtMocHelpers::MethodData<void(int, int, QString)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 41 }, { QMetaType::Int, 42 }, { QMetaType::QString, 43 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'scrollSpeed'
        QtMocHelpers::PropertyData<int>(45, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 18),
        // property 'doubleSpeed'
        QtMocHelpers::PropertyData<int>(46, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 5),
        // property 'leftHandState'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0),
        // property 'mouseMoveSpeed'
        QtMocHelpers::PropertyData<int>(48, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 8),
        // property 'accelProfile'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 10),
        // property 'disTpad'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 12),
        // property 'tpadExist'
        QtMocHelpers::PropertyData<bool>(6, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 2),
        // property 'mouseNaturalScroll'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 6),
        // property 'tpadMoveSpeed'
        QtMocHelpers::PropertyData<int>(52, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 9),
        // property 'tapClick'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 16),
        // property 'tpadNaturalScroll'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 7),
        // property 'disIfTyping'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 19),
        // property 'tapEnabled'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 17),
        // property 'gestureFingerAniPath'
        QtMocHelpers::PropertyData<QString>(56, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 20),
        // property 'gestureActionAniPath'
        QtMocHelpers::PropertyData<QString>(57, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 21),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MouseModel, qt_meta_tag_ZN13DCC_NAMESPACE10MouseModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DCC_NAMESPACE::MouseModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DCC_NAMESPACE10MouseModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DCC_NAMESPACE10MouseModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13DCC_NAMESPACE10MouseModelE_t>.metaTypes,
    nullptr
} };

void DCC_NAMESPACE::MouseModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MouseModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->leftHandStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->disIfTypingStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->tpadExistChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->mouseExistChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->redPointExistChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->doubleSpeedChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->mouseNaturalScrollChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->tpadNaturalScrollChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->mouseMoveSpeedChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->tpadMoveSpeedChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->accelProfileChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->redPointMoveSpeedChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->disTpadChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->palmDetectChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->palmMinWidthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->palmMinzChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->tapClickChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->tapEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->scrollSpeedChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->disIfTypingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->gestureFingerAniPathChanged(); break;
        case 21: _t->gestureActionAniPathChanged(); break;
        case 22: _t->themeTypeChanged(); break;
        case 23: { GestureModel* _r = _t->threeFingerGestureModel();
            if (_a[0]) *reinterpret_cast<GestureModel**>(_a[0]) = std::move(_r); }  break;
        case 24: { GestureModel* _r = _t->fourFigerGestureModel();
            if (_a[0]) *reinterpret_cast<GestureModel**>(_a[0]) = std::move(_r); }  break;
        case 25: _t->setGestures((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 26: _t->updateFigerGestureAni((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)(bool )>(_a, &MouseModel::leftHandStateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)(bool )>(_a, &MouseModel::disIfTypingStateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)(bool )>(_a, &MouseModel::tpadExistChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)(bool )>(_a, &MouseModel::mouseExistChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)(bool )>(_a, &MouseModel::redPointExistChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)(int )>(_a, &MouseModel::doubleSpeedChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)(bool )>(_a, &MouseModel::mouseNaturalScrollChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)(bool )>(_a, &MouseModel::tpadNaturalScrollChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)(int )>(_a, &MouseModel::mouseMoveSpeedChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)(int )>(_a, &MouseModel::tpadMoveSpeedChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)(bool )>(_a, &MouseModel::accelProfileChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)(int )>(_a, &MouseModel::redPointMoveSpeedChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)(bool )>(_a, &MouseModel::disTpadChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)(bool )>(_a, &MouseModel::palmDetectChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)(int )>(_a, &MouseModel::palmMinWidthChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)(int )>(_a, &MouseModel::palmMinzChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)(bool )>(_a, &MouseModel::tapClickChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)(bool )>(_a, &MouseModel::tapEnabledChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)(int )>(_a, &MouseModel::scrollSpeedChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)(bool )>(_a, &MouseModel::disIfTypingChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)()>(_a, &MouseModel::gestureFingerAniPathChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)()>(_a, &MouseModel::gestureActionAniPathChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseModel::*)()>(_a, &MouseModel::themeTypeChanged, 22))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->scrollSpeed(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->doubleSpeed(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->leftHandState(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->mouseMoveSpeed(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->accelProfile(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->disTpad(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->tpadExist(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->mouseNaturalScroll(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->tpadMoveSpeed(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->tapClick(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->tpadNaturalScroll(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->disIfTyping(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->tapEnabled(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->getGestureFingerAniPath(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->getGestureActionAniPath(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setScrollSpeed(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setDoubleSpeed(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setLeftHandState(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setMouseMoveSpeed(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setAccelProfile(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setDisTpad(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setTpadExist(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setMouseNaturalScroll(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setTpadMoveSpeed(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setTapClick(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setTpadNaturalScroll(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setDisIfTyping(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setTapEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DCC_NAMESPACE::MouseModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DCC_NAMESPACE::MouseModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DCC_NAMESPACE10MouseModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DCC_NAMESPACE::MouseModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 27;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void DCC_NAMESPACE::MouseModel::leftHandStateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DCC_NAMESPACE::MouseModel::disIfTypingStateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DCC_NAMESPACE::MouseModel::tpadExistChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DCC_NAMESPACE::MouseModel::mouseExistChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DCC_NAMESPACE::MouseModel::redPointExistChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DCC_NAMESPACE::MouseModel::doubleSpeedChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DCC_NAMESPACE::MouseModel::mouseNaturalScrollChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void DCC_NAMESPACE::MouseModel::tpadNaturalScrollChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void DCC_NAMESPACE::MouseModel::mouseMoveSpeedChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void DCC_NAMESPACE::MouseModel::tpadMoveSpeedChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void DCC_NAMESPACE::MouseModel::accelProfileChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void DCC_NAMESPACE::MouseModel::redPointMoveSpeedChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void DCC_NAMESPACE::MouseModel::disTpadChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void DCC_NAMESPACE::MouseModel::palmDetectChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void DCC_NAMESPACE::MouseModel::palmMinWidthChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void DCC_NAMESPACE::MouseModel::palmMinzChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void DCC_NAMESPACE::MouseModel::tapClickChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void DCC_NAMESPACE::MouseModel::tapEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void DCC_NAMESPACE::MouseModel::scrollSpeedChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void DCC_NAMESPACE::MouseModel::disIfTypingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void DCC_NAMESPACE::MouseModel::gestureFingerAniPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void DCC_NAMESPACE::MouseModel::gestureActionAniPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void DCC_NAMESPACE::MouseModel::themeTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}
QT_WARNING_POP
